#!/usr/bin/perl
# constants.pm
# the constants module. This module returns the genetic code, restriction site, and other information needed by the program.
# Written by Paul Stothard

package constants;

use strict;
use warnings;
use CGI::Carp qw(fatalsToBrowser);

sub getGeneticCode {
   my $geneticCodeSelection = shift();

   if ($geneticCodeSelection eq 'standard') {
      return '
      gc[acgturyswkmbdhvn]=A,
      [tu]g[ctuy]=C,
      ga[tcuy]=D,
      ga[agr]=E,
      [tu][tu][tcuy]=F,
      gg[acgturyswkmbdhvn]=G,
      ca[tcuy]=H,
      a[tu][atcuwmhy]=I,
      aa[agr]=K,
      c[tu][acgturyswkmbdhvn]|[tu][tu][agr]|[ctuy][tu][agr]=L,
      a[tu]g=M,
      aa[tucy]=N,
      cc[acgturyswkmbdhvn]=P,
      ca[agr]=Q,
      cg[acgturyswkmbdhvn]|ag[agr]|[cam]g[agr]=R,
      [tu]c[acgturyswkmbdhvn]|ag[ct]=S,
      ac[acgturyswkmbdhvn]=T,
      g[tu][acgturyswkmbdhvn]=V,
      [tu]gg=W,
      [tu]a[ctuy]=Y,
      [tu]a[agr]|[tu]ga|[tu][agr]a=Z';
   }
   else {
      die ("The genetic code selection is not available.");
   }
}

sub getRestrictionSites {
   my $restrictionSetSelection = shift();

   if ($restrictionSetSelection eq 'common') {
      return '
      /AatII /gacgtc1 /gacgt|c,
      /AccIII /tccgga5 /t|ccgga,
      /AluI /agct2 /ag|ct,
      /ApaI /gggccc1 /gggcc|c,
      /AvaI /cycgrg5 /c|ycgrg,
      /BamHI /ggatcc5 /g|gatcc,
      /BclI /tgatca5 /t|gatca,
      /BglII /agatct5 /a|gatct,
      /BssHII /gcgcgc5 /g|cgcgc,
      /BstUI /cgcg2 /cg|cg,
      /CfoI /gcgc1 /gcg|c,
      /ClaI /atcgat4 /at|cgat,
      /DdeI /ctnag4 /c|tnag,
      /DraI /tttaaa3 /ttt|aaa,
      /EcoRI /gaattc5 /g|aattc,
      /EcoRV /gatatc3 /gat|atc,
      /HaeIII /ggcc2 /gg|cc,
      /HhaI /gcgc1 /gcg|c,
      /HincII /gtyrac3 /gty|rac,
      /HindIII /aagctt5 /a|agctt,
      /HinfI /gantc4 /g|antc,
      /HpaI /gttaac3 /gtt|aac,
      /HpaII /ccgg3 /c|cgg,
      /KpnI /ggtacc1 /ggtac|c,
      /MboI /ngatcn5 /|gatc,
      /MboII /gaagannnnnnnn0 /gaagannnnnnnn| /nnnnnnnntcttc12 /n|nnnnnnntcttc,
      /MluI /acgcgt5 /a|cgcgt,
      /MseI /ttaa3 /t|taa,
      /MspI /ccgg3 /c|cgg,
      /NaeI /gccggc3 /gcc|ggc,
      /NarI /ggcgcc4 /gg|cgcc,
      /NcoI /ccatgg5 /c|catgg,
      /NdeI /catatg4 /ca|tatg,
      /NdeII /gatc4 /|gatc,
      /NheI /gctagc5 /g|ctagc,
      /NotI /gcggccgc6 /gc|ggccgc,
      /NruI /tcgcga3 /tcg|cga,
      /PstI /ctgcag1 /ctgca|g,
      /PvuI /cgatcg2 /cgat|cg,
      /PvuII /cagctg3 /cag|ctg,
      /RsaI /gtac2 /gt|ac,
      /SacI /gagctc1 /gagct|c,
      /SacII /ccgcgg2 /ccgc|gg,
      /SalI /gtcgac5 /g|tcgac,
      /Sau96I /ggncc4 /g|gncc,
      /ScaI /agtact3 /agt|act,
      /SmaI /cccggg3 /ccc|ggg,
      /SpeI /actagt5 /a|ctagt,
      /SphI /gcatgc1 /gcatg|c,
      /SspI /aatatt3 /aat|att,
      /StuI /aggcct3 /agg|cct,
      /TaqI /tcga3 /t|cga,
      /VspI /attaat4 /at|taat,
      /XbaI /tctaga5 /t|ctaga,
      /XhoI /ctcgag5 /c|tcgag,
      /XmaI /cccggg5 /c|ccggg';
   }
   else {
      die ("The restriction set selection is not available.");
   }
}

sub getNumberLine {
   my $basePerLine = shift();

   if ($basePerLine == 60) {
      return '         ^10       ^20       ^30       ^40       ^50                 ^70       ^80       ^90       ^100      ^110                ^130      ^140      ^150      ^160      ^170                ^190      ^200      ^210      ^220      ^230                ^250      ^260      ^270      ^280      ^290                ^310      ^320      ^330      ^340      ^350                ^370      ^380      ^390      ^400      ^410                ^430      ^440      ^450      ^460      ^470                ^490      ^500      ^510      ^520      ^530                ^550      ^560      ^570      ^580      ^590                ^610      ^620      ^630      ^640      ^650                ^670      ^680      ^690      ^700      ^710                ^730      ^740      ^750      ^760      ^770                ^790      ^800      ^810      ^820      ^830                ^850      ^860      ^870      ^880      ^890                ^910      ^920      ^930      ^940      ^950                ^970      ^980      ^990      ^1000     ^1010               ^1030     ^1040     ^1050     ^1060     ^1070               ^1090     ^1100     ^1110     ^1120     ^1130               ^1150     ^1160     ^1170     ^1180     ^1190               ^1210     ^1220     ^1230     ^1240     ^1250               ^1270     ^1280     ^1290     ^1300     ^1310               ^1330     ^1340     ^1350     ^1360     ^1370               ^1390     ^1400     ^1410     ^1420     ^1430               ^1450     ^1460     ^1470     ^1480     ^1490               ^1510     ^1520     ^1530     ^1540     ^1550               ^1570     ^1580     ^1590     ^1600     ^1610               ^1630     ^1640     ^1650     ^1660     ^1670               ^1690     ^1700     ^1710     ^1720     ^1730               ^1750     ^1760     ^1770     ^1780     ^1790               ^1810     ^1820     ^1830     ^1840     ^1850               ^1870     ^1880     ^1890     ^1900     ^1910               ^1930     ^1940     ^1950     ^1960     ^1970               ^1990     ^2000     ^2010     ^2020     ^2030               ^2050     ^2060     ^2070     ^2080     ^2090               ^2110     ^2120     ^2130     ^2140     ^2150               ^2170     ^2180     ^2190     ^2200     ^2210               ^2230     ^2240     ^2250     ^2260     ^2270               ^2290     ^2300     ^2310     ^2320     ^2330               ^2350     ^2360     ^2370     ^2380     ^2390               ^2410     ^2420     ^2430     ^2440     ^2450               ^2470     ^2480     ^2490     ^2500     ^2510               ^2530     ^2540     ^2550     ^2560     ^2570               ^2590     ^2600     ^2610     ^2620     ^2630               ^2650     ^2660     ^2670     ^2680     ^2690               ^2710     ^2720     ^2730     ^2740     ^2750               ^2770     ^2780     ^2790     ^2800     ^2810               ^2830     ^2840     ^2850     ^2860     ^2870               ^2890     ^2900     ^2910     ^2920     ^2930               ^2950     ^2960     ^2970     ^2980     ^2990               ^3010     ^3020     ^3030     ^3040     ^3050               ^3070     ^3080     ^3090     ^3100     ^3110               ^3130     ^3140     ^3150     ^3160     ^3170               ^3190     ^3200     ^3210     ^3220     ^3230               ^3250     ^3260     ^3270     ^3280     ^3290               ^3310     ^3320     ^3330     ^3340     ^3350               ^3370     ^3380     ^3390     ^3400     ^3410               ^3430     ^3440     ^3450     ^3460     ^3470               ^3490     ^3500     ^3510     ^3520     ^3530               ^3550     ^3560     ^3570     ^3580     ^3590               ^3610     ^3620     ^3630     ^3640     ^3650               ^3670     ^3680     ^3690     ^3700     ^3710               ^3730     ^3740     ^3750     ^3760     ^3770               ^3790     ^3800     ^3810     ^3820     ^3830               ^3850     ^3860     ^3870     ^3880     ^3890               ^3910     ^3920     ^3930     ^3940     ^3950               ^3970     ^3980     ^3990     ^4000     ^4010               ^4030     ^4040     ^4050     ^4060     ^4070               ^4090     ^4100     ^4110     ^4120     ^4130               ^4150     ^4160     ^4170     ^4180     ^4190               ^4210     ^4220     ^4230     ^4240     ^4250               ^4270     ^4280     ^4290     ^4300     ^4310               ^4330     ^4340     ^4350     ^4360     ^4370               ^4390     ^4400     ^4410     ^4420     ^4430               ^4450     ^4460     ^4470     ^4480     ^4490               ^4510     ^4520     ^4530     ^4540     ^4550               ^4570     ^4580     ^4590     ^4600     ^4610               ^4630     ^4640     ^4650     ^4660     ^4670               ^4690     ^4700     ^4710     ^4720     ^4730               ^4750     ^4760     ^4770     ^4780     ^4790               ^4810     ^4820     ^4830     ^4840     ^4850               ^4870     ^4880     ^4890     ^4900     ^4910               ^4930     ^4940     ^4950     ^4960     ^4970               ^4990     ^5000     ^5010     ^5020     ^5030               ^5050     ^5060     ^5070     ^5080     ^5090               ^5110     ^5120     ^5130     ^5140     ^5150               ^5170     ^5180     ^5190     ^5200     ^5210               ^5230     ^5240     ^5250     ^5260     ^5270               ^5290     ^5300     ^5310     ^5320     ^5330               ^5350     ^5360     ^5370     ^5380     ^5390               ^5410     ^5420     ^5430     ^5440     ^5450               ^5470     ^5480     ^5490     ^5500     ^5510               ^5530     ^5540     ^5550     ^5560     ^5570               ^5590     ^5600     ^5610     ^5620     ^5630               ^5650     ^5660     ^5670     ^5680     ^5690               ^5710     ^5720     ^5730     ^5740     ^5750               ^5770     ^5780     ^5790     ^5800     ^5810               ^5830     ^5840     ^5850     ^5860     ^5870               ^5890     ^5900     ^5910     ^5920     ^5930               ^5950     ^5960     ^5970     ^5980     ^5990               ^6010     ^6020     ^6030     ^6040     ^6050               ^6070     ^6080     ^6090     ^6100     ^6110               ^6130     ^6140     ^6150     ^6160     ^6170               ^6190     ^6200     ^6210     ^6220     ^6230               ^6250     ^6260     ^6270     ^6280     ^6290               ^6310     ^6320     ^6330     ^6340     ^6350               ^6370     ^6380     ^6390     ^6400     ^6410               ^6430     ^6440     ^6450     ^6460     ^6470               ^6490     ^6500     ^6510     ^6520     ^6530               ^6550     ^6560     ^6570     ^6580     ^6590               ^6610     ^6620     ^6630     ^6640     ^6650               ^6670     ^6680     ^6690     ^6700     ^6710               ^6730     ^6740     ^6750     ^6760     ^6770               ^6790     ^6800     ^6810     ^6820     ^6830               ^6850     ^6860     ^6870     ^6880     ^6890               ^6910     ^6920     ^6930     ^6940     ^6950               ^6970     ^6980     ^6990     ^7000     ^7010               ^7030     ^7040     ^7050     ^7060     ^7070               ^7090     ^7100     ^7110     ^7120     ^7130               ^7150     ^7160     ^7170     ^7180     ^7190               ^7210     ^7220     ^7230     ^7240     ^7250               ^7270     ^7280     ^7290     ^7300     ^7310               ^7330     ^7340     ^7350     ^7360     ^7370               ^7390     ^7400     ^7410     ^7420     ^7430               ^7450     ^7460     ^7470     ^7480     ^7490               ^7510     ^7520     ^7530     ^7540     ^7550               ^7570     ^7580     ^7590     ^7600     ^7610               ^7630     ^7640     ^7650     ^7660     ^7670               ^7690     ^7700     ^7710     ^7720     ^7730               ^7750     ^7760     ^7770     ^7780     ^7790               ^7810     ^7820     ^7830     ^7840     ^7850               ^7870     ^7880     ^7890     ^7900     ^7910               ^7930     ^7940     ^7950     ^7960     ^7970               ^7990     ^8000     ^8010     ^8020     ^8030               ^8050     ^8060     ^8070     ^8080     ^8090               ^8110     ^8120     ^8130     ^8140     ^8150               ^8170     ^8180     ^8190     ^8200     ^8210               ^8230     ^8240     ^8250     ^8260     ^8270               ^8290     ^8300     ^8310     ^8320     ^8330               ^8350     ^8360     ^8370     ^8380     ^8390               ^8410     ^8420     ^8430     ^8440     ^8450               ^8470     ^8480     ^8490     ^8500     ^8510               ^8530     ^8540     ^8550     ^8560     ^8570               ^8590     ^8600     ^8610     ^8620     ^8630               ^8650     ^8660     ^8670     ^8680     ^8690               ^8710     ^8720     ^8730     ^8740     ^8750               ^8770     ^8780     ^8790     ^8800     ^8810               ^8830     ^8840     ^8850     ^8860     ^8870               ^8890     ^8900     ^8910     ^8920     ^8930               ^8950     ^8960     ^8970     ^8980     ^8990               ^9010     ^9020     ^9030     ^9040     ^9050               ^9070     ^9080     ^9090     ^9100     ^9110               ^9130     ^9140     ^9150     ^9160     ^9170               ^9190     ^9200     ^9210     ^9220     ^9230               ^9250     ^9260     ^9270     ^9280     ^9290               ^9310     ^9320     ^9330     ^9340     ^9350               ^9370     ^9380     ^9390     ^9400     ^9410               ^9430     ^9440     ^9450     ^9460     ^9470               ^9490     ^9500     ^9510     ^9520     ^9530               ^9550     ^9560     ^9570     ^9580     ^9590               ^9610     ^9620     ^9630     ^9640     ^9650               ^9670     ^9680     ^9690     ^9700     ^9710               ^9730     ^9740     ^9750     ^9760     ^9770               ^9790     ^9800     ^9810     ^9820     ^9830               ^9850     ^9860     ^9870     ^9880     ^9890               ^9910     ^9920     ^9930     ^9940     ^9950               ^9970     ^9980     ^9990     ^10000    ^10010              ^10030    ^10040    ^10050    ^10060    ^10070              ^10090    ^10100    ^10110    ^10120    ^10130              ^10150    ^10160    ^10170    ^10180    ^10190              ^10210    ^10220    ^10230    ^10240    ^10250              ^10270    ^10280    ^10290    ^10300    ^10310              ^10330    ^10340    ^10350    ^10360    ^10370              ^10390    ^10400    ^10410    ^10420    ^10430              ^10450    ^10460    ^10470    ^10480    ^10490              ^10510    ^10520    ^10530    ^10540    ^10550              ^10570    ^10580    ^10590    ^10600    ^10610              ^10630    ^10640    ^10650    ^10660    ^10670              ^10690    ^10700    ^10710    ^10720    ^10730              ^10750    ^10760    ^10770    ^10780    ^10790              ^10810    ^10820    ^10830    ^10840    ^10850              ^10870    ^10880    ^10890    ^10900    ^10910              ^10930    ^10940    ^10950    ^10960    ^10970              ^10990    ^11000    ^11010    ^11020    ^11030              ^11050    ^11060    ^11070    ^11080    ^11090              ^11110    ^11120    ^11130    ^11140    ^11150              ^11170    ^11180    ^11190    ^11200    ^11210              ^11230    ^11240    ^11250    ^11260    ^11270              ^11290    ^11300    ^11310    ^11320    ^11330              ^11350    ^11360    ^11370    ^11380    ^11390              ^11410    ^11420    ^11430    ^11440    ^11450              ^11470    ^11480    ^11490    ^11500    ^11510              ^11530    ^11540    ^11550    ^11560    ^11570              ^11590    ^11600    ^11610    ^11620    ^11630              ^11650    ^11660    ^11670    ^11680    ^11690              ^11710    ^11720    ^11730    ^11740    ^11750              ^11770    ^11780    ^11790    ^11800    ^11810              ^11830    ^11840    ^11850    ^11860    ^11870              ^11890    ^11900    ^11910    ^11920    ^11930              ^11950    ^11960    ^11970    ^11980    ^11990              ^12010    ^12020    ^12030    ^12040    ^12050              ^12070    ^12080    ^12090    ^12100    ^12110              ^12130    ^12140    ^12150    ^12160    ^12170              ^12190    ^12200    ^12210    ^12220    ^12230              ^12250    ^12260    ^12270    ^12280    ^12290              ^12310    ^12320    ^12330    ^12340    ^12350              ^12370    ^12380    ^12390    ^12400    ^12410              ^12430    ^12440    ^12450    ^12460    ^12470              ^12490    ^12500    ^12510    ^12520    ^12530              ^12550    ^12560    ^12570    ^12580    ^12590              ^12610    ^12620    ^12630    ^12640    ^12650              ^12670    ^12680    ^12690    ^12700    ^12710              ^12730    ^12740    ^12750    ^12760    ^12770              ^12790    ^12800    ^12810    ^12820    ^12830              ^12850    ^12860    ^12870    ^12880    ^12890              ^12910    ^12920    ^12930    ^12940    ^12950              ^12970    ^12980    ^12990    ^13000    ^13010              ^13030    ^13040    ^13050    ^13060    ^13070              ^13090    ^13100    ^13110    ^13120    ^13130              ^13150    ^13160    ^13170    ^13180    ^13190              ^13210    ^13220    ^13230    ^13240    ^13250              ^13270    ^13280    ^13290    ^13300    ^13310              ^13330    ^13340    ^13350    ^13360    ^13370              ^13390    ^13400    ^13410    ^13420    ^13430              ^13450    ^13460    ^13470    ^13480    ^13490              ^13510    ^13520    ^13530    ^13540    ^13550              ^13570    ^13580    ^13590    ^13600    ^13610              ^13630    ^13640    ^13650    ^13660    ^13670              ^13690    ^13700    ^13710    ^13720    ^13730              ^13750    ^13760    ^13770    ^13780    ^13790              ^13810    ^13820    ^13830    ^13840    ^13850              ^13870    ^13880    ^13890    ^13900    ^13910              ^13930    ^13940    ^13950    ^13960    ^13970              ^13990    ^14000    ^14010    ^14020    ^14030              ^14050    ^14060    ^14070    ^14080    ^14090              ^14110    ^14120    ^14130    ^14140    ^14150              ^14170    ^14180    ^14190    ^14200    ^14210              ^14230    ^14240    ^14250    ^14260    ^14270              ^14290    ^14300    ^14310    ^14320    ^14330              ^14350    ^14360    ^14370    ^14380    ^14390              ^14410    ^14420    ^14430    ^14440    ^14450              ^14470    ^14480    ^14490    ^14500    ^14510              ^14530    ^14540    ^14550    ^14560    ^14570              ^14590    ^14600    ^14610    ^14620    ^14630              ^14650    ^14660    ^14670    ^14680    ^14690              ^14710    ^14720    ^14730    ^14740    ^14750              ^14770    ^14780    ^14790    ^14800    ^14810              ^14830    ^14840    ^14850    ^14860    ^14870              ^14890    ^14900    ^14910    ^14920    ^14930              ^14950    ^14960    ^14970    ^14980    ^14990              ^15010    ^15020    ^15030    ^15040    ^15050              ^15070    ^15080    ^15090    ^15100    ^15110              ^15130    ^15140    ^15150    ^15160    ^15170              ^15190    ^15200    ^15210    ^15220    ^15230              ^15250    ^15260    ^15270    ^15280    ^15290              ^15310    ^15320    ^15330    ^15340    ^15350              ^15370    ^15380    ^15390    ^15400    ^15410              ^15430    ^15440    ^15450    ^15460    ^15470              ^15490    ^15500    ^15510    ^15520    ^15530              ^15550    ^15560    ^15570    ^15580    ^15590              ^15610    ^15620    ^15630    ^15640    ^15650              ^15670    ^15680    ^15690    ^15700    ^15710              ^15730    ^15740    ^15750    ^15760    ^15770              ^15790    ^15800    ^15810    ^15820    ^15830              ^15850    ^15860    ^15870    ^15880    ^15890              ^15910    ^15920    ^15930    ^15940    ^15950              ^15970    ^15980    ^15990    ^16000    ^16010              ^16030    ^16040    ^16050    ^16060    ^16070              ^16090    ^16100    ^16110    ^16120    ^16130              ^16150    ^16160    ^16170    ^16180    ^16190              ^16210    ^16220    ^16230    ^16240    ^16250              ^16270    ^16280    ^16290    ^16300    ^16310              ^16330    ^16340    ^16350    ^16360    ^16370              ^16390    ^16400    ^16410    ^16420    ^16430              ^16450    ^16460    ^16470    ^16480    ^16490              ^16510    ^16520    ^16530    ^16540    ^16550              ^16570    ^16580    ^16590    ^16600    ^16610              ^16630    ^16640    ^16650    ^16660    ^16670              ^16690    ^16700    ^16710    ^16720    ^16730              ^16750    ^16760    ^16770    ^16780    ^16790              ^16810    ^16820    ^16830    ^16840    ^16850              ^16870    ^16880    ^16890    ^16900    ^16910              ^16930    ^16940    ^16950    ^16960    ^16970              ^16990    ^17000    ^17010    ^17020    ^17030              ^17050    ^17060    ^17070    ^17080    ^17090              ^17110    ^17120    ^17130    ^17140    ^17150              ^17170    ^17180    ^17190    ^17200    ^17210              ^17230    ^17240    ^17250    ^17260    ^17270              ^17290    ^17300    ^17310    ^17320    ^17330              ^17350    ^17360    ^17370    ^17380    ^17390              ^17410    ^17420    ^17430    ^17440    ^17450              ^17470    ^17480    ^17490    ^17500    ^17510              ^17530    ^17540    ^17550    ^17560    ^17570              ^17590    ^17600    ^17610    ^17620    ^17630              ^17650    ^17660    ^17670    ^17680    ^17690              ^17710    ^17720    ^17730    ^17740    ^17750              ^17770    ^17780    ^17790    ^17800    ^17810              ^17830    ^17840    ^17850    ^17860    ^17870              ^17890    ^17900    ^17910    ^17920    ^17930              ^17950    ^17960    ^17970    ^17980    ^17990              ^18010    ^18020    ^18030    ^18040    ^18050              ^18070    ^18080    ^18090    ^18100    ^18110              ^18130    ^18140    ^18150    ^18160    ^18170              ^18190    ^18200    ^18210    ^18220    ^18230              ^18250    ^18260    ^18270    ^18280    ^18290              ^18310    ^18320    ^18330    ^18340    ^18350              ^18370    ^18380    ^18390    ^18400    ^18410              ^18430    ^18440    ^18450    ^18460    ^18470              ^18490    ^18500    ^18510    ^18520    ^18530              ^18550    ^18560    ^18570    ^18580    ^18590              ^18610    ^18620    ^18630    ^18640    ^18650              ^18670    ^18680    ^18690    ^18700    ^18710              ^18730    ^18740    ^18750    ^18760    ^18770              ^18790    ^18800    ^18810    ^18820    ^18830              ^18850    ^18860    ^18870    ^18880    ^18890              ^18910    ^18920    ^18930    ^18940    ^18950              ^18970    ^18980    ^18990    ^19000    ^19010              ^19030    ^19040    ^19050    ^19060    ^19070              ^19090    ^19100    ^19110    ^19120    ^19130              ^19150    ^19160    ^19170    ^19180    ^19190              ^19210    ^19220    ^19230    ^19240    ^19250              ^19270    ^19280    ^19290    ^19300    ^19310              ^19330    ^19340    ^19350    ^19360    ^19370              ^19390    ^19400    ^19410    ^19420    ^19430              ^19450    ^19460    ^19470    ^19480    ^19490              ^19510    ^19520    ^19530    ^19540    ^19550              ^19570    ^19580    ^19590    ^19600    ^19610              ^19630    ^19640    ^19650    ^19660    ^19670              ^19690    ^19700    ^19710    ^19720    ^19730              ^19750    ^19760    ^19770    ^19780    ^19790              ^19810    ^19820    ^19830    ^19840    ^19850              ^19870    ^19880    ^19890    ^19900    ^19910              ^19930    ^19940    ^19950    ^19960    ^19970              ^19990    ^20000    ^20010    ^20020    ^20030              ^20050    ^20060    ^20070    ^20080    ^20090              ^20110    ^20120    ^20130    ^20140    ^20150              ^20170    ^20180    ^20190    ^20200    ^20210              ^20230    ^20240    ^20250    ^20260    ^20270              ^20290    ^20300    ^20310    ^20320    ^20330              ^20350    ^20360    ^20370    ^20380    ^20390              ^20410    ^20420    ^20430    ^20440    ^20450              ^20470    ^20480    ^20490    ^20500    ^20510              ^20530    ^20540    ^20550    ^20560    ^20570              ^20590    ^20600    ^20610    ^20620    ^20630              ^20650    ^20660    ^20670    ^20680    ^20690              ^20710    ^20720    ^20730    ^20740    ^20750              ^20770    ^20780    ^20790    ^20800    ^20810              ^20830    ^20840    ^20850    ^20860    ^20870              ^20890    ^20900    ^20910    ^20920    ^20930              ^20950    ^20960    ^20970    ^20980    ^20990              ^21010    ^21020    ^21030    ^21040    ^21050              ^21070    ^21080    ^21090    ^21100    ^21110              ^21130    ^21140    ^21150    ^21160    ^21170              ^21190    ^21200    ^21210    ^21220    ^21230              ^21250    ^21260    ^21270    ^21280    ^21290              ^21310    ^21320    ^21330    ^21340    ^21350              ^21370    ^21380    ^21390    ^21400    ^21410              ^21430    ^21440    ^21450    ^21460    ^21470              ^21490    ^21500    ^21510    ^21520    ^21530              ^21550    ^21560    ^21570    ^21580    ^21590              ^21610    ^21620    ^21630    ^21640    ^21650              ^21670    ^21680    ^21690    ^21700    ^21710              ^21730    ^21740    ^21750    ^21760    ^21770              ^21790    ^21800    ^21810    ^21820    ^21830              ^21850    ^21860    ^21870    ^21880    ^21890              ^21910    ^21920    ^21930    ^21940    ^21950              ^21970    ^21980    ^21990    ^22000    ^22010              ^22030    ^22040    ^22050    ^22060    ^22070              ^22090    ^22100    ^22110    ^22120    ^22130              ^22150    ^22160    ^22170    ^22180    ^22190              ^22210    ^22220    ^22230    ^22240    ^22250              ^22270    ^22280    ^22290    ^22300    ^22310              ^22330    ^22340    ^22350    ^22360    ^22370              ^22390    ^22400    ^22410    ^22420    ^22430              ^22450    ^22460    ^22470    ^22480    ^22490              ^22510    ^22520    ^22530    ^22540    ^22550              ^22570    ^22580    ^22590    ^22600    ^22610              ^22630    ^22640    ^22650    ^22660    ^22670              ^22690    ^22700    ^22710    ^22720    ^22730              ^22750    ^22760    ^22770    ^22780    ^22790              ^22810    ^22820    ^22830    ^22840    ^22850              ^22870    ^22880    ^22890    ^22900    ^22910              ^22930    ^22940    ^22950    ^22960    ^22970              ^22990    ^23000    ^23010    ^23020    ^23030              ^23050    ^23060    ^23070    ^23080    ^23090              ^23110    ^23120    ^23130    ^23140    ^23150              ^23170    ^23180    ^23190    ^23200    ^23210              ^23230    ^23240    ^23250    ^23260    ^23270              ^23290    ^23300    ^23310    ^23320    ^23330              ^23350    ^23360    ^23370    ^23380    ^23390              ^23410    ^23420    ^23430    ^23440    ^23450              ^23470    ^23480    ^23490    ^23500    ^23510              ^23530    ^23540    ^23550    ^23560    ^23570              ^23590    ^23600    ^23610    ^23620    ^23630              ^23650    ^23660    ^23670    ^23680    ^23690              ^23710    ^23720    ^23730    ^23740    ^23750              ^23770    ^23780    ^23790    ^23800    ^23810              ^23830    ^23840    ^23850    ^23860    ^23870              ^23890    ^23900    ^23910    ^23920    ^23930              ^23950    ^23960    ^23970    ^23980    ^23990              ^24010    ^24020    ^24030    ^24040    ^24050              ^24070    ^24080    ^24090    ^24100    ^24110              ^24130    ^24140    ^24150    ^24160    ^24170              ^24190    ^24200    ^24210    ^24220    ^24230              ^24250    ^24260    ^24270    ^24280    ^24290              ^24310    ^24320    ^24330    ^24340    ^24350              ^24370    ^24380    ^24390    ^24400    ^24410              ^24430    ^24440    ^24450    ^24460    ^24470              ^24490    ^24500    ^24510    ^24520    ^24530              ^24550    ^24560    ^24570    ^24580    ^24590              ^24610    ^24620    ^24630    ^24640    ^24650              ^24670    ^24680    ^24690    ^24700    ^24710              ^24730    ^24740    ^24750    ^24760    ^24770              ^24790    ^24800    ^24810    ^24820    ^24830              ^24850    ^24860    ^24870    ^24880    ^24890              ^24910    ^24920    ^24930    ^24940    ^24950              ^24970    ^24980    ^24990    ^25000    ^25010              ^25030    ^25040    ^25050    ^25060    ^25070              ^25090    ^25100    ^25110    ^25120    ^25130              ^25150    ^25160    ^25170    ^25180    ^25190              ^25210    ^25220    ^25230    ^25240    ^25250              ^25270    ^25280    ^25290    ^25300    ^25310              ^25330    ^25340    ^25350    ^25360    ^25370              ^25390    ^25400    ^25410    ^25420    ^25430              ^25450    ^25460    ^25470    ^25480    ^25490              ^25510    ^25520    ^25530    ^25540    ^25550              ^25570    ^25580    ^25590    ^25600    ^25610              ^25630    ^25640    ^25650    ^25660    ^25670              ^25690    ^25700    ^25710    ^25720    ^25730              ^25750    ^25760    ^25770    ^25780    ^25790              ^25810    ^25820    ^25830    ^25840    ^25850              ^25870    ^25880    ^25890    ^25900    ^25910              ^25930    ^25940    ^25950    ^25960    ^25970              ^25990    ^26000    ^26010    ^26020    ^26030              ^26050    ^26060    ^26070    ^26080    ^26090              ^26110    ^26120    ^26130    ^26140    ^26150              ^26170    ^26180    ^26190    ^26200    ^26210              ^26230    ^26240    ^26250    ^26260    ^26270              ^26290    ^26300    ^26310    ^26320    ^26330              ^26350    ^26360    ^26370    ^26380    ^26390              ^26410    ^26420    ^26430    ^26440    ^26450              ^26470    ^26480    ^26490    ^26500    ^26510              ^26530    ^26540    ^26550    ^26560    ^26570              ^26590    ^26600    ^26610    ^26620    ^26630              ^26650    ^26660    ^26670    ^26680    ^26690              ^26710    ^26720    ^26730    ^26740    ^26750              ^26770    ^26780    ^26790    ^26800    ^26810              ^26830    ^26840    ^26850    ^26860    ^26870              ^26890    ^26900    ^26910    ^26920    ^26930              ^26950    ^26960    ^26970    ^26980    ^26990              ^27010    ^27020    ^27030    ^27040    ^27050              ^27070    ^27080    ^27090    ^27100    ^27110              ^27130    ^27140    ^27150    ^27160    ^27170              ^27190    ^27200    ^27210    ^27220    ^27230              ^27250    ^27260    ^27270    ^27280    ^27290              ^27310    ^27320    ^27330    ^27340    ^27350              ^27370    ^27380    ^27390    ^27400    ^27410              ^27430    ^27440    ^27450    ^27460    ^27470              ^27490    ^27500    ^27510    ^27520    ^27530              ^27550    ^27560    ^27570    ^27580    ^27590              ^27610    ^27620    ^27630    ^27640    ^27650              ^27670    ^27680    ^27690    ^27700    ^27710              ^27730    ^27740    ^27750    ^27760    ^27770              ^27790    ^27800    ^27810    ^27820    ^27830              ^27850    ^27860    ^27870    ^27880    ^27890              ^27910    ^27920    ^27930    ^27940    ^27950              ^27970    ^27980    ^27990    ^28000    ^28010              ^28030    ^28040    ^28050    ^28060    ^28070              ^28090    ^28100    ^28110    ^28120    ^28130              ^28150    ^28160    ^28170    ^28180    ^28190              ^28210    ^28220    ^28230    ^28240    ^28250              ^28270    ^28280    ^28290    ^28300    ^28310              ^28330    ^28340    ^28350    ^28360    ^28370              ^28390    ^28400    ^28410    ^28420    ^28430              ^28450    ^28460    ^28470    ^28480    ^28490              ^28510    ^28520    ^28530    ^28540    ^28550              ^28570    ^28580    ^28590    ^28600    ^28610              ^28630    ^28640    ^28650    ^28660    ^28670              ^28690    ^28700    ^28710    ^28720    ^28730              ^28750    ^28760    ^28770    ^28780    ^28790              ^28810    ^28820    ^28830    ^28840    ^28850              ^28870    ^28880    ^28890    ^28900    ^28910              ^28930    ^28940    ^28950    ^28960    ^28970              ^28990    ^29000    ^29010    ^29020    ^29030              ^29050    ^29060    ^29070    ^29080    ^29090              ^29110    ^29120    ^29130    ^29140    ^29150              ^29170    ^29180    ^29190    ^29200    ^29210              ^29230    ^29240    ^29250    ^29260    ^29270              ^29290    ^29300    ^29310    ^29320    ^29330              ^29350    ^29360    ^29370    ^29380    ^29390              ^29410    ^29420    ^29430    ^29440    ^29450              ^29470    ^29480    ^29490    ^29500    ^29510              ^29530    ^29540    ^29550    ^29560    ^29570              ^29590    ^29600    ^29610    ^29620    ^29630              ^29650    ^29660    ^29670    ^29680    ^29690              ^29710    ^29720    ^29730    ^29740    ^29750              ^29770    ^29780    ^29790    ^29800    ^29810              ^29830    ^29840    ^29850    ^29860    ^29870              ^29890    ^29900    ^29910    ^29920    ^29930              ^29950    ^29960    ^29970    ^29980    ^29990              ^30010    ^30020    ^30030    ^30040    ^30050              ^30070    ^30080    ^30090    ^30100    ^30110              ^30130    ^30140    ^30150    ^30160    ^30170              ^30190    ^30200    ^30210    ^30220    ^30230              ^30250    ^30260    ^30270    ^30280    ^30290              ^30310    ^30320    ^30330    ^30340    ^30350              ^30370    ^30380    ^30390    ^30400    ^30410              ^30430    ^30440    ^30450    ^30460    ^30470              ^30490    ^30500    ^30510    ^30520    ^30530              ^30550    ^30560    ^30570    ^30580    ^30590              ^30610    ^30620    ^30630    ^30640    ^30650              ^30670    ^30680    ^30690    ^30700    ^30710              ^30730    ^30740    ^30750    ^30760    ^30770              ^30790    ^30800    ^30810    ^30820    ^30830              ^30850    ^30860    ^30870    ^30880    ^30890              ^30910    ^30920    ^30930    ^30940    ^30950              ^30970    ^30980    ^30990    ^31000    ^31010              ^31030    ^31040    ^31050    ^31060    ^31070              ^31090    ^31100    ^31110    ^31120    ^31130              ^31150    ^31160    ^31170    ^31180    ^31190              ^31210    ^31220    ^31230    ^31240    ^31250              ^31270    ^31280    ^31290    ^31300    ^31310              ^31330    ^31340    ^31350    ^31360    ^31370              ^31390    ^31400    ^31410    ^31420    ^31430              ^31450    ^31460    ^31470    ^31480    ^31490              ^31510    ^31520    ^31530    ^31540    ^31550              ^31570    ^31580    ^31590    ^31600    ^31610              ^31630    ^31640    ^31650    ^31660    ^31670              ^31690    ^31700    ^31710    ^31720    ^31730              ^31750    ^31760    ^31770    ^31780    ^31790              ^31810    ^31820    ^31830    ^31840    ^31850              ^31870    ^31880    ^31890    ^31900    ^31910              ^31930    ^31940    ^31950    ^31960    ^31970              ^31990    ^32000    ^32010    ^32020    ^32030              ^32050    ^32060    ^32070    ^32080    ^32090              ^32110    ^32120    ^32130    ^32140    ^32150              ^32170    ^32180    ^32190    ^32200    ^32210              ^32230    ^32240    ^32250    ^32260    ^32270              ^32290    ^32300    ^32310    ^32320    ^32330              ^32350    ^32360    ^32370    ^32380    ^32390              ^32410    ^32420    ^32430    ^32440    ^32450              ^32470    ^32480    ^32490    ^32500    ^32510              ^32530    ^32540    ^32550    ^32560    ^32570              ^32590    ^32600    ^32610    ^32620    ^32630              ^32650    ^32660    ^32670    ^32680    ^32690              ^32710    ^32720    ^32730    ^32740    ^32750              ^32770    ^32780    ^32790    ^32800    ^32810              ^32830    ^32840    ^32850    ^32860    ^32870              ^32890    ^32900    ^32910    ^32920    ^32930              ^32950    ^32960    ^32970    ^32980    ^32990              ^33010    ^33020    ^33030    ^33040    ^33050              ^33070    ^33080    ^33090    ^33100    ^33110              ^33130    ^33140    ^33150    ^33160    ^33170              ^33190    ^33200    ^33210    ^33220    ^33230              ^33250    ^33260    ^33270    ^33280    ^33290              ^33310    ^33320    ^33330    ^33340    ^33350              ^33370    ^33380    ^33390    ^33400    ^33410              ^33430    ^33440    ^33450    ^33460    ^33470              ^33490    ^33500    ^33510    ^33520    ^33530              ^33550    ^33560    ^33570    ^33580    ^33590              ^33610    ^33620    ^33630    ^33640    ^33650              ^33670    ^33680    ^33690    ^33700    ^33710              ^33730    ^33740    ^33750    ^33760    ^33770              ^33790    ^33800    ^33810    ^33820    ^33830              ^33850    ^33860    ^33870    ^33880    ^33890              ^33910    ^33920    ^33930    ^33940    ^33950              ^33970    ^33980    ^33990    ^34000    ^34010              ^34030    ^34040    ^34050    ^34060    ^34070              ^34090    ^34100    ^34110    ^34120    ^34130              ^34150    ^34160    ^34170    ^34180    ^34190              ^34210    ^34220    ^34230    ^34240    ^34250              ^34270    ^34280    ^34290    ^34300    ^34310              ^34330    ^34340    ^34350    ^34360    ^34370              ^34390    ^34400    ^34410    ^34420    ^34430              ^34450    ^34460    ^34470    ^34480    ^34490              ^34510    ^34520    ^34530    ^34540    ^34550              ^34570    ^34580    ^34590    ^34600    ^34610              ^34630    ^34640    ^34650    ^34660    ^34670              ^34690    ^34700    ^34710    ^34720    ^34730              ^34750    ^34760    ^34770    ^34780    ^34790              ^34810    ^34820    ^34830    ^34840    ^34850              ^34870    ^34880    ^34890    ^34900    ^34910              ^34930    ^34940    ^34950    ^34960    ^34970              ^34990    ^35000    ^35010    ^35020    ^35030              ^35050    ^35060    ^35070    ^35080    ^35090              ^35110    ^35120    ^35130    ^35140    ^35150              ^35170    ^35180    ^35190    ^35200    ^35210              ^35230    ^35240    ^35250    ^35260    ^35270              ^35290    ^35300    ^35310    ^35320    ^35330              ^35350    ^35360    ^35370    ^35380    ^35390              ^35410    ^35420    ^35430    ^35440    ^35450              ^35470    ^35480    ^35490    ^35500    ^35510              ^35530    ^35540    ^35550    ^35560    ^35570              ^35590    ^35600    ^35610    ^35620    ^35630              ^35650    ^35660    ^35670    ^35680    ^35690              ^35710    ^35720    ^35730    ^35740    ^35750              ^35770    ^35780    ^35790    ^35800    ^35810              ^35830    ^35840    ^35850    ^35860    ^35870              ^35890    ^35900    ^35910    ^35920    ^35930              ^35950    ^35960    ^35970    ^35980    ^35990              ^36010    ^36020    ^36030    ^36040    ^36050              ^36070    ^36080    ^36090    ^36100    ^36110              ^36130    ^36140    ^36150    ^36160    ^36170              ^36190    ^36200    ^36210    ^36220    ^36230              ^36250    ^36260    ^36270    ^36280    ^36290              ^36310    ^36320    ^36330    ^36340    ^36350              ^36370    ^36380    ^36390    ^36400    ^36410              ^36430    ^36440    ^36450    ^36460    ^36470              ^36490    ^36500    ^36510    ^36520    ^36530              ^36550    ^36560    ^36570    ^36580    ^36590              ^36610    ^36620    ^36630    ^36640    ^36650              ^36670    ^36680    ^36690    ^36700    ^36710              ^36730    ^36740    ^36750    ^36760    ^36770              ^36790    ^36800    ^36810    ^36820    ^36830              ^36850    ^36860    ^36870    ^36880    ^36890              ^36910    ^36920    ^36930    ^36940    ^36950              ^36970    ^36980    ^36990    ^37000    ^37010              ^37030    ^37040    ^37050    ^37060    ^37070              ^37090    ^37100    ^37110    ^37120    ^37130              ^37150    ^37160    ^37170    ^37180    ^37190              ^37210    ^37220    ^37230    ^37240    ^37250              ^37270    ^37280    ^37290    ^37300    ^37310              ^37330    ^37340    ^37350    ^37360    ^37370              ^37390    ^37400    ^37410    ^37420    ^37430              ^37450    ^37460    ^37470    ^37480    ^37490              ^37510    ^37520    ^37530    ^37540    ^37550              ^37570    ^37580    ^37590    ^37600    ^37610              ^37630    ^37640    ^37650    ^37660    ^37670              ^37690    ^37700    ^37710    ^37720    ^37730              ^37750    ^37760    ^37770    ^37780    ^37790              ^37810    ^37820    ^37830    ^37840    ^37850              ^37870    ^37880    ^37890    ^37900    ^37910              ^37930    ^37940    ^37950    ^37960    ^37970              ^37990    ^38000    ^38010    ^38020    ^38030              ^38050    ^38060    ^38070    ^38080    ^38090              ^38110    ^38120    ^38130    ^38140    ^38150              ^38170    ^38180    ^38190    ^38200    ^38210              ^38230    ^38240    ^38250    ^38260    ^38270              ^38290    ^38300    ^38310    ^38320    ^38330              ^38350    ^38360    ^38370    ^38380    ^38390              ^38410    ^38420    ^38430    ^38440    ^38450              ^38470    ^38480    ^38490    ^38500    ^38510              ^38530    ^38540    ^38550    ^38560    ^38570              ^38590    ^38600    ^38610    ^38620    ^38630              ^38650    ^38660    ^38670    ^38680    ^38690              ^38710    ^38720    ^38730    ^38740    ^38750              ^38770    ^38780    ^38790    ^38800    ^38810              ^38830    ^38840    ^38850    ^38860    ^38870              ^38890    ^38900    ^38910    ^38920    ^38930              ^38950    ^38960    ^38970    ^38980    ^38990              ^39010    ^39020    ^39030    ^39040    ^39050              ^39070    ^39080    ^39090    ^39100    ^39110              ^39130    ^39140    ^39150    ^39160    ^39170              ^39190    ^39200    ^39210    ^39220    ^39230              ^39250    ^39260    ^39270    ^39280    ^39290              ^39310    ^39320    ^39330    ^39340    ^39350              ^39370    ^39380    ^39390    ^39400    ^39410              ^39430    ^39440    ^39450    ^39460    ^39470              ^39490    ^39500    ^39510    ^39520    ^39530              ^39550    ^39560    ^39570    ^39580    ^39590              ^39610    ^39620    ^39630    ^39640    ^39650              ^39670    ^39680    ^39690    ^39700    ^39710              ^39730    ^39740    ^39750    ^39760    ^39770              ^39790    ^39800    ^39810    ^39820    ^39830              ^39850    ^39860    ^39870    ^39880    ^39890              ^39910    ^39920    ^39930    ^39940    ^39950              ^39970    ^39980    ^39990    ^40000    ^40010              ^40030    ^40040    ^40050    ^40060    ^40070              ^40090    ^40100    ^40110    ^40120    ^40130              ^40150    ^40160    ^40170    ^40180    ^40190              ^40210    ^40220    ^40230    ^40240    ^40250              ^40270    ^40280    ^40290    ^40300    ^40310              ^40330    ^40340    ^40350    ^40360    ^40370              ^40390    ^40400    ^40410    ^40420    ^40430              ^40450    ^40460    ^40470    ^40480    ^40490              ^40510    ^40520    ^40530    ^40540    ^40550              ^40570    ^40580    ^40590    ^40600    ^40610              ^40630    ^40640    ^40650    ^40660    ^40670              ^40690    ^40700    ^40710    ^40720    ^40730              ^40750    ^40760    ^40770    ^40780    ^40790              ^40810    ^40820    ^40830    ^40840    ^40850              ^40870    ^40880    ^40890    ^40900    ^40910              ^40930    ^40940    ^40950    ^40960    ^40970              ^40990    ^41000    ^41010    ^41020    ^41030              ^41050    ^41060    ^41070    ^41080    ^41090              ^41110    ^41120    ^41130    ^41140    ^41150              ^41170    ^41180    ^41190    ^41200    ^41210              ^41230    ^41240    ^41250    ^41260    ^41270              ^41290    ^41300    ^41310    ^41320    ^41330              ^41350    ^41360    ^41370    ^41380    ^41390              ^41410    ^41420    ^41430    ^41440    ^41450              ^41470    ^41480    ^41490    ^41500    ^41510              ^41530    ^41540    ^41550    ^41560    ^41570              ^41590    ^41600    ^41610    ^41620    ^41630              ^41650    ^41660    ^41670    ^41680    ^41690              ^41710    ^41720    ^41730    ^41740    ^41750              ^41770    ^41780    ^41790    ^41800    ^41810              ^41830    ^41840    ^41850    ^41860    ^41870              ^41890    ^41900    ^41910    ^41920    ^41930              ^41950    ^41960    ^41970    ^41980    ^41990              ^42010    ^42020    ^42030    ^42040    ^42050              ^42070    ^42080    ^42090    ^42100    ^42110              ^42130    ^42140    ^42150    ^42160    ^42170              ^42190    ^42200    ^42210    ^42220    ^42230              ^42250    ^42260    ^42270    ^42280    ^42290              ^42310    ^42320    ^42330    ^42340    ^42350              ^42370    ^42380    ^42390    ^42400    ^42410              ^42430    ^42440    ^42450    ^42460    ^42470              ^42490    ^42500    ^42510    ^42520    ^42530              ^42550    ^42560    ^42570    ^42580    ^42590              ^42610    ^42620    ^42630    ^42640    ^42650              ^42670    ^42680    ^42690    ^42700    ^42710              ^42730    ^42740    ^42750    ^42760    ^42770              ^42790    ^42800    ^42810    ^42820    ^42830              ^42850    ^42860    ^42870    ^42880    ^42890              ^42910    ^42920    ^42930    ^42940    ^42950              ^42970    ^42980    ^42990    ^43000    ^43010              ^43030    ^43040    ^43050    ^43060    ^43070              ^43090    ^43100    ^43110    ^43120    ^43130              ^43150    ^43160    ^43170    ^43180    ^43190              ^43210    ^43220    ^43230    ^43240    ^43250              ^43270    ^43280    ^43290    ^43300    ^43310              ^43330    ^43340    ^43350    ^43360    ^43370              ^43390    ^43400    ^43410    ^43420    ^43430              ^43450    ^43460    ^43470    ^43480    ^43490              ^43510    ^43520    ^43530    ^43540    ^43550              ^43570    ^43580    ^43590    ^43600    ^43610              ^43630    ^43640    ^43650    ^43660    ^43670              ^43690    ^43700    ^43710    ^43720    ^43730              ^43750    ^43760    ^43770    ^43780    ^43790              ^43810    ^43820    ^43830    ^43840    ^43850              ^43870    ^43880    ^43890    ^43900    ^43910              ^43930    ^43940    ^43950    ^43960    ^43970              ^43990    ^44000    ^44010    ^44020    ^44030              ^44050    ^44060    ^44070    ^44080    ^44090              ^44110    ^44120    ^44130    ^44140    ^44150              ^44170    ^44180    ^44190    ^44200    ^44210              ^44230    ^44240    ^44250    ^44260    ^44270              ^44290    ^44300    ^44310    ^44320    ^44330              ^44350    ^44360    ^44370    ^44380    ^44390              ^44410    ^44420    ^44430    ^44440    ^44450              ^44470    ^44480    ^44490    ^44500    ^44510              ^44530    ^44540    ^44550    ^44560    ^44570              ^44590    ^44600    ^44610    ^44620    ^44630              ^44650    ^44660    ^44670    ^44680    ^44690              ^44710    ^44720    ^44730    ^44740    ^44750              ^44770    ^44780    ^44790    ^44800    ^44810              ^44830    ^44840    ^44850    ^44860    ^44870              ^44890    ^44900    ^44910    ^44920    ^44930              ^44950    ^44960    ^44970    ^44980    ^44990              ^45010    ^45020    ^45030    ^45040    ^45050              ^45070    ^45080    ^45090    ^45100    ^45110              ^45130    ^45140    ^45150    ^45160    ^45170              ^45190    ^45200    ^45210    ^45220    ^45230              ^45250    ^45260    ^45270    ^45280    ^45290              ^45310    ^45320    ^45330    ^45340    ^45350              ^45370    ^45380    ^45390    ^45400    ^45410              ^45430    ^45440    ^45450    ^45460    ^45470              ^45490    ^45500    ^45510    ^45520    ^45530              ^45550    ^45560    ^45570    ^45580    ^45590              ^45610    ^45620    ^45630    ^45640    ^45650              ^45670    ^45680    ^45690    ^45700    ^45710              ^45730    ^45740    ^45750    ^45760    ^45770              ^45790    ^45800    ^45810    ^45820    ^45830              ^45850    ^45860    ^45870    ^45880    ^45890              ^45910    ^45920    ^45930    ^45940    ^45950              ^45970    ^45980    ^45990    ^46000    ^46010              ^46030    ^46040    ^46050    ^46060    ^46070              ^46090    ^46100    ^46110    ^46120    ^46130              ^46150    ^46160    ^46170    ^46180    ^46190              ^46210    ^46220    ^46230    ^46240    ^46250              ^46270    ^46280    ^46290    ^46300    ^46310              ^46330    ^46340    ^46350    ^46360    ^46370              ^46390    ^46400    ^46410    ^46420    ^46430              ^46450    ^46460    ^46470    ^46480    ^46490              ^46510    ^46520    ^46530    ^46540    ^46550              ^46570    ^46580    ^46590    ^46600    ^46610              ^46630    ^46640    ^46650    ^46660    ^46670              ^46690    ^46700    ^46710    ^46720    ^46730              ^46750    ^46760    ^46770    ^46780    ^46790              ^46810    ^46820    ^46830    ^46840    ^46850              ^46870    ^46880    ^46890    ^46900    ^46910              ^46930    ^46940    ^46950    ^46960    ^46970              ^46990    ^47000    ^47010    ^47020    ^47030              ^47050    ^47060    ^47070    ^47080    ^47090              ^47110    ^47120    ^47130    ^47140    ^47150              ^47170    ^47180    ^47190    ^47200    ^47210              ^47230    ^47240    ^47250    ^47260    ^47270              ^47290    ^47300    ^47310    ^47320    ^47330              ^47350    ^47360    ^47370    ^47380    ^47390              ^47410    ^47420    ^47430    ^47440    ^47450              ^47470    ^47480    ^47490    ^47500    ^47510              ^47530    ^47540    ^47550    ^47560    ^47570              ^47590    ^47600    ^47610    ^47620    ^47630              ^47650    ^47660    ^47670    ^47680    ^47690              ^47710    ^47720    ^47730    ^47740    ^47750              ^47770    ^47780    ^47790    ^47800    ^47810              ^47830    ^47840    ^47850    ^47860    ^47870              ^47890    ^47900    ^47910    ^47920    ^47930              ^47950    ^47960    ^47970    ^47980    ^47990              ^48010    ^48020    ^48030    ^48040    ^48050              ^48070    ^48080    ^48090    ^48100    ^48110              ^48130    ^48140    ^48150    ^48160    ^48170              ^48190    ^48200    ^48210    ^48220    ^48230              ^48250    ^48260    ^48270    ^48280    ^48290              ^48310    ^48320    ^48330    ^48340    ^48350              ^48370    ^48380    ^48390    ^48400    ^48410              ^48430    ^48440    ^48450    ^48460    ^48470              ^48490    ^48500    ^48510    ^48520    ^48530              ^48550    ^48560    ^48570    ^48580    ^48590              ^48610    ^48620    ^48630    ^48640    ^48650              ^48670    ^48680    ^48690    ^48700    ^48710              ^48730    ^48740    ^48750    ^48760    ^48770              ^48790    ^48800    ^48810    ^48820    ^48830              ^48850    ^48860    ^48870    ^48880    ^48890              ^48910    ^48920    ^48930    ^48940    ^48950              ^48970    ^48980    ^48990    ^49000    ^49010              ^49030    ^49040    ^49050    ^49060    ^49070              ^49090    ^49100    ^49110    ^49120    ^49130              ^49150    ^49160    ^49170    ^49180    ^49190              ^49210    ^49220    ^49230    ^49240    ^49250              ^49270    ^49280    ^49290    ^49300    ^49310              ^49330    ^49340    ^49350    ^49360    ^49370              ^49390    ^49400    ^49410    ^49420    ^49430              ^49450    ^49460    ^49470    ^49480    ^49490              ^49510    ^49520    ^49530    ^49540    ^49550              ^49570    ^49580    ^49590    ^49600    ^49610              ^49630    ^49640    ^49650    ^49660    ^49670              ^49690    ^49700    ^49710    ^49720    ^49730              ^49750    ^49760    ^49770    ^49780    ^49790              ^49810    ^49820    ^49830    ^49840    ^49850              ^49870    ^49880    ^49890    ^49900    ^49910              ^49930    ^49940    ^49950    ^49960    ^49970              ^49990    ^50000    ^50010    ^50020    ^50030              ^50050    ^50060    ^50070    ^50080    ^50090              ^50110    ^50120    ^50130    ^50140    ^50150              ^50170    ^50180    ^50190    ^50200    ^50210              ^50230    ^50240    ^50250    ^50260    ^50270              ^50290    ^50300    ^50310    ^50320    ^50330              ^50350    ^50360    ^50370    ^50380    ^50390              ^50410    ^50420    ^50430    ^50440    ^50450              ^50470    ^50480    ^50490    ^50500    ^50510              ^50530    ^50540    ^50550    ^50560    ^50570              ^50590    ^50600    ^50610    ^50620    ^50630              ^50650    ^50660    ^50670    ^50680    ^50690              ^50710    ^50720    ^50730    ^50740    ^50750              ^50770    ^50780    ^50790    ^50800    ^50810              ^50830    ^50840    ^50850    ^50860    ^50870              ^50890    ^50900    ^50910    ^50920    ^50930              ^50950    ^50960    ^50970    ^50980    ^50990              ^51010    ^51020    ^51030    ^51040    ^51050              ^51070    ^51080    ^51090    ^51100    ^51110              ^51130    ^51140    ^51150    ^51160    ^51170              ^51190    ^51200    ^51210    ^51220    ^51230              ^51250    ^51260    ^51270    ^51280    ^51290              ^51310    ^51320    ^51330    ^51340    ^51350              ^51370    ^51380    ^51390    ^51400    ^51410              ^51430    ^51440    ^51450    ^51460    ^51470              ^51490    ^51500    ^51510    ^51520    ^51530              ^51550    ^51560    ^51570    ^51580    ^51590              ^51610    ^51620    ^51630    ^51640    ^51650              ^51670    ^51680    ^51690    ^51700    ^51710              ^51730    ^51740    ^51750    ^51760    ^51770              ^51790    ^51800    ^51810    ^51820    ^51830              ^51850    ^51860    ^51870    ^51880    ^51890              ^51910    ^51920    ^51930    ^51940    ^51950              ^51970    ^51980    ^51990    ^52000    ^52010              ^52030    ^52040    ^52050    ^52060    ^52070              ^52090    ^52100    ^52110    ^52120    ^52130              ^52150    ^52160    ^52170    ^52180    ^52190              ^52210    ^52220    ^52230    ^52240    ^52250              ^52270    ^52280    ^52290    ^52300    ^52310              ^52330    ^52340    ^52350    ^52360    ^52370              ^52390    ^52400    ^52410    ^52420    ^52430              ^52450    ^52460    ^52470    ^52480    ^52490              ^52510    ^52520    ^52530    ^52540    ^52550              ^52570    ^52580    ^52590    ^52600    ^52610              ^52630    ^52640    ^52650    ^52660    ^52670              ^52690    ^52700    ^52710    ^52720    ^52730              ^52750    ^52760    ^52770    ^52780    ^52790              ^52810    ^52820    ^52830    ^52840    ^52850              ^52870    ^52880    ^52890    ^52900    ^52910              ^52930    ^52940    ^52950    ^52960    ^52970              ^52990    ^53000    ^53010    ^53020    ^53030              ^53050    ^53060    ^53070    ^53080    ^53090              ^53110    ^53120    ^53130    ^53140    ^53150              ^53170    ^53180    ^53190    ^53200    ^53210              ^53230    ^53240    ^53250    ^53260    ^53270              ^53290    ^53300    ^53310    ^53320    ^53330              ^53350    ^53360    ^53370    ^53380    ^53390              ^53410    ^53420    ^53430    ^53440    ^53450              ^53470    ^53480    ^53490    ^53500    ^53510              ^53530    ^53540    ^53550    ^53560    ^53570              ^53590    ^53600    ^53610    ^53620    ^53630              ^53650    ^53660    ^53670    ^53680    ^53690              ^53710    ^53720    ^53730    ^53740    ^53750              ^53770    ^53780    ^53790    ^53800    ^53810              ^53830    ^53840    ^53850    ^53860    ^53870              ^53890    ^53900    ^53910    ^53920    ^53930              ^53950    ^53960    ^53970    ^53980    ^53990              ^54010    ^54020    ^54030    ^54040    ^54050              ^54070    ^54080    ^54090    ^54100    ^54110              ^54130    ^54140    ^54150    ^54160    ^54170              ^54190    ^54200    ^54210    ^54220    ^54230              ^54250    ^54260    ^54270    ^54280    ^54290              ^54310    ^54320    ^54330    ^54340    ^54350              ^54370    ^54380    ^54390    ^54400    ^54410              ^54430    ^54440    ^54450    ^54460    ^54470              ^54490    ^54500    ^54510    ^54520    ^54530              ^54550    ^54560    ^54570    ^54580    ^54590              ^54610    ^54620    ^54630    ^54640    ^54650              ^54670    ^54680    ^54690    ^54700    ^54710              ^54730    ^54740    ^54750    ^54760    ^54770              ^54790    ^54800    ^54810    ^54820    ^54830              ^54850    ^54860    ^54870    ^54880    ^54890              ^54910    ^54920    ^54930    ^54940    ^54950              ^54970    ^54980    ^54990    ^55000    ^55010              ^55030    ^55040    ^55050    ^55060    ^55070              ^55090    ^55100    ^55110    ^55120    ^55130              ^55150    ^55160    ^55170    ^55180    ^55190              ^55210    ^55220    ^55230    ^55240    ^55250              ^55270    ^55280    ^55290    ^55300    ^55310              ^55330    ^55340    ^55350    ^55360    ^55370              ^55390    ^55400    ^55410    ^55420    ^55430              ^55450    ^55460    ^55470    ^55480    ^55490              ^55510    ^55520    ^55530    ^55540    ^55550              ^55570    ^55580    ^55590    ^55600    ^55610              ^55630    ^55640    ^55650    ^55660    ^55670              ^55690    ^55700    ^55710    ^55720    ^55730              ^55750    ^55760    ^55770    ^55780    ^55790              ^55810    ^55820    ^55830    ^55840    ^55850              ^55870    ^55880    ^55890    ^55900    ^55910              ^55930    ^55940    ^55950    ^55960    ^55970              ^55990    ^56000    ^56010    ^56020    ^56030              ^56050    ^56060    ^56070    ^56080    ^56090              ^56110    ^56120    ^56130    ^56140    ^56150              ^56170    ^56180    ^56190    ^56200    ^56210              ^56230    ^56240    ^56250    ^56260    ^56270              ^56290    ^56300    ^56310    ^56320    ^56330              ^56350    ^56360    ^56370    ^56380    ^56390              ^56410    ^56420    ^56430    ^56440    ^56450              ^56470    ^56480    ^56490    ^56500    ^56510              ^56530    ^56540    ^56550    ^56560    ^56570              ^56590    ^56600    ^56610    ^56620    ^56630              ^56650    ^56660    ^56670    ^56680    ^56690              ^56710    ^56720    ^56730    ^56740    ^56750              ^56770    ^56780    ^56790    ^56800    ^56810              ^56830    ^56840    ^56850    ^56860    ^56870              ^56890    ^56900    ^56910    ^56920    ^56930              ^56950    ^56960    ^56970    ^56980    ^56990              ^57010    ^57020    ^57030    ^57040    ^57050              ^57070    ^57080    ^57090    ^57100    ^57110              ^57130    ^57140    ^57150    ^57160    ^57170              ^57190    ^57200    ^57210    ^57220    ^57230              ^57250    ^57260    ^57270    ^57280    ^57290              ^57310    ^57320    ^57330    ^57340    ^57350              ^57370    ^57380    ^57390    ^57400    ^57410              ^57430    ^57440    ^57450    ^57460    ^57470              ^57490    ^57500    ^57510    ^57520    ^57530              ^57550    ^57560    ^57570    ^57580    ^57590              ^57610    ^57620    ^57630    ^57640    ^57650              ^57670    ^57680    ^57690    ^57700    ^57710              ^57730    ^57740    ^57750    ^57760    ^57770              ^57790    ^57800    ^57810    ^57820    ^57830              ^57850    ^57860    ^57870    ^57880    ^57890              ^57910    ^57920    ^57930    ^57940    ^57950              ^57970    ^57980    ^57990    ^58000    ^58010              ^58030    ^58040    ^58050    ^58060    ^58070              ^58090    ^58100    ^58110    ^58120    ^58130              ^58150    ^58160    ^58170    ^58180    ^58190              ^58210    ^58220    ^58230    ^58240    ^58250              ^58270    ^58280    ^58290    ^58300    ^58310              ^58330    ^58340    ^58350    ^58360    ^58370              ^58390    ^58400    ^58410    ^58420    ^58430              ^58450    ^58460    ^58470    ^58480    ^58490              ^58510    ^58520    ^58530    ^58540    ^58550              ^58570    ^58580    ^58590    ^58600    ^58610              ^58630    ^58640    ^58650    ^58660    ^58670              ^58690    ^58700    ^58710    ^58720    ^58730              ^58750    ^58760    ^58770    ^58780    ^58790              ^58810    ^58820    ^58830    ^58840    ^58850              ^58870    ^58880    ^58890    ^58900    ^58910              ^58930    ^58940    ^58950    ^58960    ^58970              ^58990    ^59000    ^59010    ^59020    ^59030              ^59050    ^59060    ^59070    ^59080    ^59090              ^59110    ^59120    ^59130    ^59140    ^59150              ^59170    ^59180    ^59190    ^59200    ^59210              ^59230    ^59240    ^59250    ^59260    ^59270              ^59290    ^59300    ^59310    ^59320    ^59330              ^59350    ^59360    ^59370    ^59380    ^59390              ^59410    ^59420    ^59430    ^59440    ^59450              ^59470    ^59480    ^59490    ^59500    ^59510              ^59530    ^59540    ^59550    ^59560    ^59570              ^59590    ^59600    ^59610    ^59620    ^59630              ^59650    ^59660    ^59670    ^59680    ^59690              ^59710    ^59720    ^59730    ^59740    ^59750              ^59770    ^59780    ^59790    ^59800    ^59810              ^59830    ^59840    ^59850    ^59860    ^59870              ^59890    ^59900    ^59910    ^59920    ^59930              ^59950    ^59960    ^59970    ^59980    ^59990              ^60010    ^60020    ^60030    ^60040    ^60050              ^60070    ^60080    ^60090    ^60100    ^60110              ^60130    ^60140    ^60150    ^60160    ^60170              ^60190    ^60200    ^60210    ^60220    ^60230              ^60250    ^60260    ^60270    ^60280    ^60290              ^60310    ^60320    ^60330    ^60340    ^60350              ^60370    ^60380    ^60390    ^60400    ^60410              ^60430    ^60440    ^60450    ^60460    ^60470              ^60490    ^60500    ^60510    ^60520    ^60530              ^60550    ^60560    ^60570    ^60580    ^60590              ^60610    ^60620    ^60630    ^60640    ^60650              ^60670    ^60680    ^60690    ^60700    ^60710              ^60730    ^60740    ^60750    ^60760    ^60770              ^60790    ^60800    ^60810    ^60820    ^60830              ^60850    ^60860    ^60870    ^60880    ^60890              ^60910    ^60920    ^60930    ^60940    ^60950              ^60970    ^60980    ^60990    ^61000    ^61010              ^61030    ^61040    ^61050    ^61060    ^61070              ^61090    ^61100    ^61110    ^61120    ^61130              ^61150    ^61160    ^61170    ^61180    ^61190              ^61210    ^61220    ^61230    ^61240    ^61250              ^61270    ^61280    ^61290    ^61300    ^61310              ^61330    ^61340    ^61350    ^61360    ^61370              ^61390    ^61400    ^61410    ^61420    ^61430              ^61450    ^61460    ^61470    ^61480    ^61490              ^61510    ^61520    ^61530    ^61540    ^61550              ^61570    ^61580    ^61590    ^61600    ^61610              ^61630    ^61640    ^61650    ^61660    ^61670              ^61690    ^61700    ^61710    ^61720    ^61730              ^61750    ^61760    ^61770    ^61780    ^61790              ^61810    ^61820    ^61830    ^61840    ^61850              ^61870    ^61880    ^61890    ^61900    ^61910              ^61930    ^61940    ^61950    ^61960    ^61970              ^61990    ^62000    ^62010    ^62020    ^62030              ^62050    ^62060    ^62070    ^62080    ^62090              ^62110    ^62120    ^62130    ^62140    ^62150              ^62170    ^62180    ^62190    ^62200    ^62210              ^62230    ^62240    ^62250    ^62260    ^62270              ^62290    ^62300    ^62310    ^62320    ^62330              ^62350    ^62360    ^62370    ^62380    ^62390              ^62410    ^62420    ^62430    ^62440    ^62450              ^62470    ^62480    ^62490    ^62500    ^62510              ^62530    ^62540    ^62550    ^62560    ^62570              ^62590    ^62600    ^62610    ^62620    ^62630              ^62650    ^62660    ^62670    ^62680    ^62690              ^62710    ^62720    ^62730    ^62740    ^62750              ^62770    ^62780    ^62790    ^62800    ^62810              ^62830    ^62840    ^62850    ^62860    ^62870              ^62890    ^62900    ^62910    ^62920    ^62930              ^62950    ^62960    ^62970    ^62980    ^62990              ^63010    ^63020    ^63030    ^63040    ^63050              ^63070    ^63080    ^63090    ^63100    ^63110              ^63130    ^63140    ^63150    ^63160    ^63170              ^63190    ^63200    ^63210    ^63220    ^63230              ^63250    ^63260    ^63270    ^63280    ^63290              ^63310    ^63320    ^63330    ^63340    ^63350              ^63370    ^63380    ^63390    ^63400    ^63410              ^63430    ^63440    ^63450    ^63460    ^63470              ^63490    ^63500    ^63510    ^63520    ^63530              ^63550    ^63560    ^63570    ^63580    ^63590              ^63610    ^63620    ^63630    ^63640    ^63650              ^63670    ^63680    ^63690    ^63700    ^63710              ^63730    ^63740    ^63750    ^63760    ^63770              ^63790    ^63800    ^63810    ^63820    ^63830              ^63850    ^63860    ^63870    ^63880    ^63890              ^63910    ^63920    ^63930    ^63940    ^63950              ^63970    ^63980    ^63990    ^64000    ^64010              ^64030    ^64040    ^64050    ^64060    ^64070              ^64090    ^64100    ^64110    ^64120    ^64130              ^64150    ^64160    ^64170    ^64180    ^64190              ^64210    ^64220    ^64230    ^64240    ^64250              ^64270    ^64280    ^64290    ^64300    ^64310              ^64330    ^64340    ^64350    ^64360    ^64370              ^64390    ^64400    ^64410    ^64420    ^64430              ^64450    ^64460    ^64470    ^64480    ^64490              ^64510    ^64520    ^64530    ^64540    ^64550              ^64570    ^64580    ^64590    ^64600    ^64610              ^64630    ^64640    ^64650    ^64660    ^64670              ^64690    ^64700    ^64710    ^64720    ^64730              ^64750    ^64760    ^64770    ^64780    ^64790              ^64810    ^64820    ^64830    ^64840    ^64850              ^64870    ^64880    ^64890    ^64900    ^64910              ^64930    ^64940    ^64950    ^64960    ^64970              ^64990    ^65000    ^65010    ^65020    ^65030              ^65050    ^65060    ^65070    ^65080    ^65090              ^65110    ^65120    ^65130    ^65140    ^65150              ^65170    ^65180    ^65190    ^65200    ^65210              ^65230    ^65240    ^65250    ^65260    ^65270              ^65290    ^65300    ^65310    ^65320    ^65330              ^65350    ^65360    ^65370    ^65380    ^65390              ^65410    ^65420    ^65430    ^65440    ^65450              ^65470    ^65480    ^65490    ^65500    ^65510              ^65530    ^65540    ^65550    ^65560    ^65570              ^65590    ^65600    ^65610    ^65620    ^65630              ^65650    ^65660    ^65670    ^65680    ^65690              ^65710    ^65720    ^65730    ^65740    ^65750              ^65770    ^65780    ^65790    ^65800    ^65810              ^65830    ^65840    ^65850    ^65860    ^65870              ^65890    ^65900    ^65910    ^65920    ^65930              ^65950    ^65960    ^65970    ^65980    ^65990              ^66010    ^66020    ^66030    ^66040    ^66050              ^66070    ^66080    ^66090    ^66100    ^66110              ^66130    ^66140    ^66150    ^66160    ^66170              ^66190    ^66200    ^66210    ^66220    ^66230              ^66250    ^66260    ^66270    ^66280    ^66290              ^66310    ^66320    ^66330    ^66340    ^66350              ^66370    ^66380    ^66390    ^66400    ^66410              ^66430    ^66440    ^66450    ^66460    ^66470              ^66490    ^66500    ^66510    ^66520    ^66530              ^66550    ^66560    ^66570    ^66580    ^66590              ^66610    ^66620    ^66630    ^66640    ^66650              ^66670    ^66680    ^66690    ^66700    ^66710              ^66730    ^66740    ^66750    ^66760    ^66770              ^66790    ^66800    ^66810    ^66820    ^66830              ^66850    ^66860    ^66870    ^66880    ^66890              ^66910    ^66920    ^66930    ^66940    ^66950              ^66970    ^66980    ^66990    ^67000    ^67010              ^67030    ^67040    ^67050    ^67060    ^67070              ^67090    ^67100    ^67110    ^67120    ^67130              ^67150    ^67160    ^67170    ^67180    ^67190              ^67210    ^67220    ^67230    ^67240    ^67250              ^67270    ^67280    ^67290    ^67300    ^67310              ^67330    ^67340    ^67350    ^67360    ^67370              ^67390    ^67400    ^67410    ^67420    ^67430              ^67450    ^67460    ^67470    ^67480    ^67490              ^67510    ^67520    ^67530    ^67540    ^67550              ^67570    ^67580    ^67590    ^67600    ^67610              ^67630    ^67640    ^67650    ^67660    ^67670              ^67690    ^67700    ^67710    ^67720    ^67730              ^67750    ^67760    ^67770    ^67780    ^67790              ^67810    ^67820    ^67830    ^67840    ^67850              ^67870    ^67880    ^67890    ^67900    ^67910              ^67930    ^67940    ^67950    ^67960    ^67970              ^67990    ^68000    ^68010    ^68020    ^68030              ^68050    ^68060    ^68070    ^68080    ^68090              ^68110    ^68120    ^68130    ^68140    ^68150              ^68170    ^68180    ^68190    ^68200    ^68210              ^68230    ^68240    ^68250    ^68260    ^68270              ^68290    ^68300    ^68310    ^68320    ^68330              ^68350    ^68360    ^68370    ^68380    ^68390              ^68410    ^68420    ^68430    ^68440    ^68450              ^68470    ^68480    ^68490    ^68500    ^68510              ^68530    ^68540    ^68550    ^68560    ^68570              ^68590    ^68600    ^68610    ^68620    ^68630              ^68650    ^68660    ^68670    ^68680    ^68690              ^68710    ^68720    ^68730    ^68740    ^68750              ^68770    ^68780    ^68790    ^68800    ^68810              ^68830    ^68840    ^68850    ^68860    ^68870              ^68890    ^68900    ^68910    ^68920    ^68930              ^68950    ^68960    ^68970    ^68980    ^68990              ^69010    ^69020    ^69030    ^69040    ^69050              ^69070    ^69080    ^69090    ^69100    ^69110              ^69130    ^69140    ^69150    ^69160    ^69170              ^69190    ^69200    ^69210    ^69220    ^69230              ^69250    ^69260    ^69270    ^69280    ^69290              ^69310    ^69320    ^69330    ^69340    ^69350              ^69370    ^69380    ^69390    ^69400    ^69410              ^69430    ^69440    ^69450    ^69460    ^69470              ^69490    ^69500    ^69510    ^69520    ^69530              ^69550    ^69560    ^69570    ^69580    ^69590              ^69610    ^69620    ^69630    ^69640    ^69650              ^69670    ^69680    ^69690    ^69700    ^69710              ^69730    ^69740    ^69750    ^69760    ^69770              ^69790    ^69800    ^69810    ^69820    ^69830              ^69850    ^69860    ^69870    ^69880    ^69890              ^69910    ^69920    ^69930    ^69940    ^69950              ^69970    ^69980    ^69990    ^70000    ^70010              ^70030    ^70040    ^70050    ^70060    ^70070              ^70090    ^70100    ^70110    ^70120    ^70130              ^70150    ^70160    ^70170    ^70180    ^70190              ^70210    ^70220    ^70230    ^70240    ^70250              ^70270    ^70280    ^70290    ^70300    ^70310              ^70330    ^70340    ^70350    ^70360    ^70370              ^70390    ^70400    ^70410    ^70420    ^70430              ^70450    ^70460    ^70470    ^70480    ^70490              ^70510    ^70520    ^70530    ^70540    ^70550              ^70570    ^70580    ^70590    ^70600    ^70610              ^70630    ^70640    ^70650    ^70660    ^70670              ^70690    ^70700    ^70710    ^70720    ^70730              ^70750    ^70760    ^70770    ^70780    ^70790              ^70810    ^70820    ^70830    ^70840    ^70850              ^70870    ^70880    ^70890    ^70900    ^70910              ^70930    ^70940    ^70950    ^70960    ^70970              ^70990    ^71000    ^71010    ^71020    ^71030              ^71050    ^71060    ^71070    ^71080    ^71090              ^71110    ^71120    ^71130    ^71140    ^71150              ^71170    ^71180    ^71190    ^71200    ^71210              ^71230    ^71240    ^71250    ^71260    ^71270              ^71290    ^71300    ^71310    ^71320    ^71330              ^71350    ^71360    ^71370    ^71380    ^71390              ^71410    ^71420    ^71430    ^71440    ^71450              ^71470    ^71480    ^71490    ^71500    ^71510              ^71530    ^71540    ^71550    ^71560    ^71570              ^71590    ^71600    ^71610    ^71620    ^71630              ^71650    ^71660    ^71670    ^71680    ^71690              ^71710    ^71720    ^71730    ^71740    ^71750              ^71770    ^71780    ^71790    ^71800    ^71810              ^71830    ^71840    ^71850    ^71860    ^71870              ^71890    ^71900    ^71910    ^71920    ^71930              ^71950    ^71960    ^71970    ^71980    ^71990              ^72010    ^72020    ^72030    ^72040    ^72050              ^72070    ^72080    ^72090    ^72100    ^72110              ^72130    ^72140    ^72150    ^72160    ^72170              ^72190    ^72200    ^72210    ^72220    ^72230              ^72250    ^72260    ^72270    ^72280    ^72290              ^72310    ^72320    ^72330    ^72340    ^72350              ^72370    ^72380    ^72390    ^72400    ^72410              ^72430    ^72440    ^72450    ^72460    ^72470              ^72490    ^72500    ^72510    ^72520    ^72530              ^72550    ^72560    ^72570    ^72580    ^72590              ^72610    ^72620    ^72630    ^72640    ^72650              ^72670    ^72680    ^72690    ^72700    ^72710              ^72730    ^72740    ^72750    ^72760    ^72770              ^72790    ^72800    ^72810    ^72820    ^72830              ^72850    ^72860    ^72870    ^72880    ^72890              ^72910    ^72920    ^72930    ^72940    ^72950              ^72970    ^72980    ^72990    ^73000    ^73010              ^73030    ^73040    ^73050    ^73060    ^73070              ^73090    ^73100    ^73110    ^73120    ^73130              ^73150    ^73160    ^73170    ^73180    ^73190              ^73210    ^73220    ^73230    ^73240    ^73250              ^73270    ^73280    ^73290    ^73300    ^73310              ^73330    ^73340    ^73350    ^73360    ^73370              ^73390    ^73400    ^73410    ^73420    ^73430              ^73450    ^73460    ^73470    ^73480    ^73490              ^73510    ^73520    ^73530    ^73540    ^73550              ^73570    ^73580    ^73590    ^73600    ^73610              ^73630    ^73640    ^73650    ^73660    ^73670              ^73690    ^73700    ^73710    ^73720    ^73730              ^73750    ^73760    ^73770    ^73780    ^73790              ^73810    ^73820    ^73830    ^73840    ^73850              ^73870    ^73880    ^73890    ^73900    ^73910              ^73930    ^73940    ^73950    ^73960    ^73970              ^73990    ^74000    ^74010    ^74020    ^74030              ^74050    ^74060    ^74070    ^74080    ^74090              ^74110    ^74120    ^74130    ^74140    ^74150              ^74170    ^74180    ^74190    ^74200    ^74210              ^74230    ^74240    ^74250    ^74260    ^74270              ^74290    ^74300    ^74310    ^74320    ^74330              ^74350    ^74360    ^74370    ^74380    ^74390              ^74410    ^74420    ^74430    ^74440    ^74450              ^74470    ^74480    ^74490    ^74500    ^74510              ^74530    ^74540    ^74550    ^74560    ^74570              ^74590    ^74600    ^74610    ^74620    ^74630              ^74650    ^74660    ^74670    ^74680    ^74690              ^74710    ^74720    ^74730    ^74740    ^74750              ^74770    ^74780    ^74790    ^74800    ^74810              ^74830    ^74840    ^74850    ^74860    ^74870              ^74890    ^74900    ^74910    ^74920    ^74930              ^74950    ^74960    ^74970    ^74980    ^74990              ^75010    ^75020    ^75030    ^75040    ^75050              ^75070    ^75080    ^75090    ^75100    ^75110              ^75130    ^75140    ^75150    ^75160    ^75170              ^75190    ^75200    ^75210    ^75220    ^75230              ^75250    ^75260    ^75270    ^75280    ^75290              ^75310    ^75320    ^75330    ^75340    ^75350              ^75370    ^75380    ^75390    ^75400    ^75410              ^75430    ^75440    ^75450    ^75460    ^75470              ^75490    ^75500    ^75510    ^75520    ^75530              ^75550    ^75560    ^75570    ^75580    ^75590              ^75610    ^75620    ^75630    ^75640    ^75650              ^75670    ^75680    ^75690    ^75700    ^75710              ^75730    ^75740    ^75750    ^75760    ^75770              ^75790    ^75800    ^75810    ^75820    ^75830              ^75850    ^75860    ^75870    ^75880    ^75890              ^75910    ^75920    ^75930    ^75940    ^75950              ^75970    ^75980    ^75990    ^76000    ^76010              ^76030    ^76040    ^76050    ^76060    ^76070              ^76090    ^76100    ^76110    ^76120    ^76130              ^76150    ^76160    ^76170    ^76180    ^76190              ^76210    ^76220    ^76230    ^76240    ^76250              ^76270    ^76280    ^76290    ^76300    ^76310              ^76330    ^76340    ^76350    ^76360    ^76370              ^76390    ^76400    ^76410    ^76420    ^76430              ^76450    ^76460    ^76470    ^76480    ^76490              ^76510    ^76520    ^76530    ^76540    ^76550              ^76570    ^76580    ^76590    ^76600    ^76610              ^76630    ^76640    ^76650    ^76660    ^76670              ^76690    ^76700    ^76710    ^76720    ^76730              ^76750    ^76760    ^76770    ^76780    ^76790              ^76810    ^76820    ^76830    ^76840    ^76850              ^76870    ^76880    ^76890    ^76900    ^76910              ^76930    ^76940    ^76950    ^76960    ^76970              ^76990    ^77000    ^77010    ^77020    ^77030              ^77050    ^77060    ^77070    ^77080    ^77090              ^77110    ^77120    ^77130    ^77140    ^77150              ^77170    ^77180    ^77190    ^77200    ^77210              ^77230    ^77240    ^77250    ^77260    ^77270              ^77290    ^77300    ^77310    ^77320    ^77330              ^77350    ^77360    ^77370    ^77380    ^77390              ^77410    ^77420    ^77430    ^77440    ^77450              ^77470    ^77480    ^77490    ^77500    ^77510              ^77530    ^77540    ^77550    ^77560    ^77570              ^77590    ^77600    ^77610    ^77620    ^77630              ^77650    ^77660    ^77670    ^77680    ^77690              ^77710    ^77720    ^77730    ^77740    ^77750              ^77770    ^77780    ^77790    ^77800    ^77810              ^77830    ^77840    ^77850    ^77860    ^77870              ^77890    ^77900    ^77910    ^77920    ^77930              ^77950    ^77960    ^77970    ^77980    ^77990              ^78010    ^78020    ^78030    ^78040    ^78050              ^78070    ^78080    ^78090    ^78100    ^78110              ^78130    ^78140    ^78150    ^78160    ^78170              ^78190    ^78200    ^78210    ^78220    ^78230              ^78250    ^78260    ^78270    ^78280    ^78290              ^78310    ^78320    ^78330    ^78340    ^78350              ^78370    ^78380    ^78390    ^78400    ^78410              ^78430    ^78440    ^78450    ^78460    ^78470              ^78490    ^78500    ^78510    ^78520    ^78530              ^78550    ^78560    ^78570    ^78580    ^78590              ^78610    ^78620    ^78630    ^78640    ^78650              ^78670    ^78680    ^78690    ^78700    ^78710              ^78730    ^78740    ^78750    ^78760    ^78770              ^78790    ^78800    ^78810    ^78820    ^78830              ^78850    ^78860    ^78870    ^78880    ^78890              ^78910    ^78920    ^78930    ^78940    ^78950              ^78970    ^78980    ^78990    ^79000    ^79010              ^79030    ^79040    ^79050    ^79060    ^79070              ^79090    ^79100    ^79110    ^79120    ^79130              ^79150    ^79160    ^79170    ^79180    ^79190              ^79210    ^79220    ^79230    ^79240    ^79250              ^79270    ^79280    ^79290    ^79300    ^79310              ^79330    ^79340    ^79350    ^79360    ^79370              ^79390    ^79400    ^79410    ^79420    ^79430              ^79450    ^79460    ^79470    ^79480    ^79490              ^79510    ^79520    ^79530    ^79540    ^79550              ^79570    ^79580    ^79590    ^79600    ^79610              ^79630    ^79640    ^79650    ^79660    ^79670              ^79690    ^79700    ^79710    ^79720    ^79730              ^79750    ^79760    ^79770    ^79780    ^79790              ^79810    ^79820    ^79830    ^79840    ^79850              ^79870    ^79880    ^79890    ^79900    ^79910              ^79930    ^79940    ^79950    ^79960    ^79970              ^79990    ^80000    ^80010    ^80020    ^80030              ^80050    ^80060    ^80070    ^80080    ^80090              ^80110    ^80120    ^80130    ^80140    ^80150              ^80170    ^80180    ^80190    ^80200    ^80210              ^80230    ^80240    ^80250    ^80260    ^80270              ^80290    ^80300    ^80310    ^80320    ^80330              ^80350    ^80360    ^80370    ^80380    ^80390              ^80410    ^80420    ^80430    ^80440    ^80450              ^80470    ^80480    ^80490    ^80500    ^80510              ^80530    ^80540    ^80550    ^80560    ^80570              ^80590    ^80600    ^80610    ^80620    ^80630              ^80650    ^80660    ^80670    ^80680    ^80690              ^80710    ^80720    ^80730    ^80740    ^80750              ^80770    ^80780    ^80790    ^80800    ^80810              ^80830    ^80840    ^80850    ^80860    ^80870              ^80890    ^80900    ^80910    ^80920    ^80930              ^80950    ^80960    ^80970    ^80980    ^80990              ^81010    ^81020    ^81030    ^81040    ^81050              ^81070    ^81080    ^81090    ^81100    ^81110              ^81130    ^81140    ^81150    ^81160    ^81170              ^81190    ^81200    ^81210    ^81220    ^81230              ^81250    ^81260    ^81270    ^81280    ^81290              ^81310    ^81320    ^81330    ^81340    ^81350              ^81370    ^81380    ^81390    ^81400    ^81410              ^81430    ^81440    ^81450    ^81460    ^81470              ^81490    ^81500    ^81510    ^81520    ^81530              ^81550    ^81560    ^81570    ^81580    ^81590              ^81610    ^81620    ^81630    ^81640    ^81650              ^81670    ^81680    ^81690    ^81700    ^81710              ^81730    ^81740    ^81750    ^81760    ^81770              ^81790    ^81800    ^81810    ^81820    ^81830              ^81850    ^81860    ^81870    ^81880    ^81890              ^81910    ^81920    ^81930    ^81940    ^81950              ^81970    ^81980    ^81990    ^82000    ^82010              ^82030    ^82040    ^82050    ^82060    ^82070              ^82090    ^82100    ^82110    ^82120    ^82130              ^82150    ^82160    ^82170    ^82180    ^82190              ^82210    ^82220    ^82230    ^82240    ^82250              ^82270    ^82280    ^82290    ^82300    ^82310              ^82330    ^82340    ^82350    ^82360    ^82370              ^82390    ^82400    ^82410    ^82420    ^82430              ^82450    ^82460    ^82470    ^82480    ^82490              ^82510    ^82520    ^82530    ^82540    ^82550              ^82570    ^82580    ^82590    ^82600    ^82610              ^82630    ^82640    ^82650    ^82660    ^82670              ^82690    ^82700    ^82710    ^82720    ^82730              ^82750    ^82760    ^82770    ^82780    ^82790              ^82810    ^82820    ^82830    ^82840    ^82850              ^82870    ^82880    ^82890    ^82900    ^82910              ^82930    ^82940    ^82950    ^82960    ^82970              ^82990    ^83000    ^83010    ^83020    ^83030              ^83050    ^83060    ^83070    ^83080    ^83090              ^83110    ^83120    ^83130    ^83140    ^83150              ^83170    ^83180    ^83190    ^83200    ^83210              ^83230    ^83240    ^83250    ^83260    ^83270              ^83290    ^83300    ^83310    ^83320    ^83330              ^83350    ^83360    ^83370    ^83380    ^83390              ^83410    ^83420    ^83430    ^83440    ^83450              ^83470    ^83480    ^83490    ^83500    ^83510              ^83530    ^83540    ^83550    ^83560    ^83570              ^83590    ^83600    ^83610    ^83620    ^83630              ^83650    ^83660    ^83670    ^83680    ^83690              ^83710    ^83720    ^83730    ^83740    ^83750              ^83770    ^83780    ^83790    ^83800    ^83810              ^83830    ^83840    ^83850    ^83860    ^83870              ^83890    ^83900    ^83910    ^83920    ^83930              ^83950    ^83960    ^83970    ^83980    ^83990              ^84010    ^84020    ^84030    ^84040    ^84050              ^84070    ^84080    ^84090    ^84100    ^84110              ^84130    ^84140    ^84150    ^84160    ^84170              ^84190    ^84200    ^84210    ^84220    ^84230              ^84250    ^84260    ^84270    ^84280    ^84290              ^84310    ^84320    ^84330    ^84340    ^84350              ^84370    ^84380    ^84390    ^84400    ^84410              ^84430    ^84440    ^84450    ^84460    ^84470              ^84490    ^84500    ^84510    ^84520    ^84530              ^84550    ^84560    ^84570    ^84580    ^84590              ^84610    ^84620    ^84630    ^84640    ^84650              ^84670    ^84680    ^84690    ^84700    ^84710              ^84730    ^84740    ^84750    ^84760    ^84770              ^84790    ^84800    ^84810    ^84820    ^84830              ^84850    ^84860    ^84870    ^84880    ^84890              ^84910    ^84920    ^84930    ^84940    ^84950              ^84970    ^84980    ^84990    ^85000    ^85010              ^85030    ^85040    ^85050    ^85060    ^85070              ^85090    ^85100    ^85110    ^85120    ^85130              ^85150    ^85160    ^85170    ^85180    ^85190              ^85210    ^85220    ^85230    ^85240    ^85250              ^85270    ^85280    ^85290    ^85300    ^85310              ^85330    ^85340    ^85350    ^85360    ^85370              ^85390    ^85400    ^85410    ^85420    ^85430              ^85450    ^85460    ^85470    ^85480    ^85490              ^85510    ^85520    ^85530    ^85540    ^85550              ^85570    ^85580    ^85590    ^85600    ^85610              ^85630    ^85640    ^85650    ^85660    ^85670              ^85690    ^85700    ^85710    ^85720    ^85730              ^85750    ^85760    ^85770    ^85780    ^85790              ^85810    ^85820    ^85830    ^85840    ^85850              ^85870    ^85880    ^85890    ^85900    ^85910              ^85930    ^85940    ^85950    ^85960    ^85970              ^85990    ^86000    ^86010    ^86020    ^86030              ^86050    ^86060    ^86070    ^86080    ^86090              ^86110    ^86120    ^86130    ^86140    ^86150              ^86170    ^86180    ^86190    ^86200    ^86210              ^86230    ^86240    ^86250    ^86260    ^86270              ^86290    ^86300    ^86310    ^86320    ^86330              ^86350    ^86360    ^86370    ^86380    ^86390              ^86410    ^86420    ^86430    ^86440    ^86450              ^86470    ^86480    ^86490    ^86500    ^86510              ^86530    ^86540    ^86550    ^86560    ^86570              ^86590    ^86600    ^86610    ^86620    ^86630              ^86650    ^86660    ^86670    ^86680    ^86690              ^86710    ^86720    ^86730    ^86740    ^86750              ^86770    ^86780    ^86790    ^86800    ^86810              ^86830    ^86840    ^86850    ^86860    ^86870              ^86890    ^86900    ^86910    ^86920    ^86930              ^86950    ^86960    ^86970    ^86980    ^86990              ^87010    ^87020    ^87030    ^87040    ^87050              ^87070    ^87080    ^87090    ^87100    ^87110              ^87130    ^87140    ^87150    ^87160    ^87170              ^87190    ^87200    ^87210    ^87220    ^87230              ^87250    ^87260    ^87270    ^87280    ^87290              ^87310    ^87320    ^87330    ^87340    ^87350              ^87370    ^87380    ^87390    ^87400    ^87410              ^87430    ^87440    ^87450    ^87460    ^87470              ^87490    ^87500    ^87510    ^87520    ^87530              ^87550    ^87560    ^87570    ^87580    ^87590              ^87610    ^87620    ^87630    ^87640    ^87650              ^87670    ^87680    ^87690    ^87700    ^87710              ^87730    ^87740    ^87750    ^87760    ^87770              ^87790    ^87800    ^87810    ^87820    ^87830              ^87850    ^87860    ^87870    ^87880    ^87890              ^87910    ^87920    ^87930    ^87940    ^87950              ^87970    ^87980    ^87990    ^88000    ^88010              ^88030    ^88040    ^88050    ^88060    ^88070              ^88090    ^88100    ^88110    ^88120    ^88130              ^88150    ^88160    ^88170    ^88180    ^88190              ^88210    ^88220    ^88230    ^88240    ^88250              ^88270    ^88280    ^88290    ^88300    ^88310              ^88330    ^88340    ^88350    ^88360    ^88370              ^88390    ^88400    ^88410    ^88420    ^88430              ^88450    ^88460    ^88470    ^88480    ^88490              ^88510    ^88520    ^88530    ^88540    ^88550              ^88570    ^88580    ^88590    ^88600    ^88610              ^88630    ^88640    ^88650    ^88660    ^88670              ^88690    ^88700    ^88710    ^88720    ^88730              ^88750    ^88760    ^88770    ^88780    ^88790              ^88810    ^88820    ^88830    ^88840    ^88850              ^88870    ^88880    ^88890    ^88900    ^88910              ^88930    ^88940    ^88950    ^88960    ^88970              ^88990    ^89000    ^89010    ^89020    ^89030              ^89050    ^89060    ^89070    ^89080    ^89090              ^89110    ^89120    ^89130    ^89140    ^89150              ^89170    ^89180    ^89190    ^89200    ^89210              ^89230    ^89240    ^89250    ^89260    ^89270              ^89290    ^89300    ^89310    ^89320    ^89330              ^89350    ^89360    ^89370    ^89380    ^89390              ^89410    ^89420    ^89430    ^89440    ^89450              ^89470    ^89480    ^89490    ^89500    ^89510              ^89530    ^89540    ^89550    ^89560    ^89570              ^89590    ^89600    ^89610    ^89620    ^89630              ^89650    ^89660    ^89670    ^89680    ^89690              ^89710    ^89720    ^89730    ^89740    ^89750              ^89770    ^89780    ^89790    ^89800    ^89810              ^89830    ^89840    ^89850    ^89860    ^89870              ^89890    ^89900    ^89910    ^89920    ^89930              ^89950    ^89960    ^89970    ^89980    ^89990              ^90010    ^90020    ^90030    ^90040    ^90050              ^90070    ^90080    ^90090    ^90100    ^90110              ^90130    ^90140    ^90150    ^90160    ^90170              ^90190    ^90200    ^90210    ^90220    ^90230              ^90250    ^90260    ^90270    ^90280    ^90290              ^90310    ^90320    ^90330    ^90340    ^90350              ^90370    ^90380    ^90390    ^90400    ^90410              ^90430    ^90440    ^90450    ^90460    ^90470              ^90490    ^90500    ^90510    ^90520    ^90530              ^90550    ^90560    ^90570    ^90580    ^90590              ^90610    ^90620    ^90630    ^90640    ^90650              ^90670    ^90680    ^90690    ^90700    ^90710              ^90730    ^90740    ^90750    ^90760    ^90770              ^90790    ^90800    ^90810    ^90820    ^90830              ^90850    ^90860    ^90870    ^90880    ^90890              ^90910    ^90920    ^90930    ^90940    ^90950              ^90970    ^90980    ^90990    ^91000    ^91010              ^91030    ^91040    ^91050    ^91060    ^91070              ^91090    ^91100    ^91110    ^91120    ^91130              ^91150    ^91160    ^91170    ^91180    ^91190              ^91210    ^91220    ^91230    ^91240    ^91250              ^91270    ^91280    ^91290    ^91300    ^91310              ^91330    ^91340    ^91350    ^91360    ^91370              ^91390    ^91400    ^91410    ^91420    ^91430              ^91450    ^91460    ^91470    ^91480    ^91490              ^91510    ^91520    ^91530    ^91540    ^91550              ^91570    ^91580    ^91590    ^91600    ^91610              ^91630    ^91640    ^91650    ^91660    ^91670              ^91690    ^91700    ^91710    ^91720    ^91730              ^91750    ^91760    ^91770    ^91780    ^91790              ^91810    ^91820    ^91830    ^91840    ^91850              ^91870    ^91880    ^91890    ^91900    ^91910              ^91930    ^91940    ^91950    ^91960    ^91970              ^91990    ^92000    ^92010    ^92020    ^92030              ^92050    ^92060    ^92070    ^92080    ^92090              ^92110    ^92120    ^92130    ^92140    ^92150              ^92170    ^92180    ^92190    ^92200    ^92210              ^92230    ^92240    ^92250    ^92260    ^92270              ^92290    ^92300    ^92310    ^92320    ^92330              ^92350    ^92360    ^92370    ^92380    ^92390              ^92410    ^92420    ^92430    ^92440    ^92450              ^92470    ^92480    ^92490    ^92500    ^92510              ^92530    ^92540    ^92550    ^92560    ^92570              ^92590    ^92600    ^92610    ^92620    ^92630              ^92650    ^92660    ^92670    ^92680    ^92690              ^92710    ^92720    ^92730    ^92740    ^92750              ^92770    ^92780    ^92790    ^92800    ^92810              ^92830    ^92840    ^92850    ^92860    ^92870              ^92890    ^92900    ^92910    ^92920    ^92930              ^92950    ^92960    ^92970    ^92980    ^92990              ^93010    ^93020    ^93030    ^93040    ^93050              ^93070    ^93080    ^93090    ^93100    ^93110              ^93130    ^93140    ^93150    ^93160    ^93170              ^93190    ^93200    ^93210    ^93220    ^93230              ^93250    ^93260    ^93270    ^93280    ^93290              ^93310    ^93320    ^93330    ^93340    ^93350              ^93370    ^93380    ^93390    ^93400    ^93410              ^93430    ^93440    ^93450    ^93460    ^93470              ^93490    ^93500    ^93510    ^93520    ^93530              ^93550    ^93560    ^93570    ^93580    ^93590              ^93610    ^93620    ^93630    ^93640    ^93650              ^93670    ^93680    ^93690    ^93700    ^93710              ^93730    ^93740    ^93750    ^93760    ^93770              ^93790    ^93800    ^93810    ^93820    ^93830              ^93850    ^93860    ^93870    ^93880    ^93890              ^93910    ^93920    ^93930    ^93940    ^93950              ^93970    ^93980    ^93990    ^94000    ^94010              ^94030    ^94040    ^94050    ^94060    ^94070              ^94090    ^94100    ^94110    ^94120    ^94130              ^94150    ^94160    ^94170    ^94180    ^94190              ^94210    ^94220    ^94230    ^94240    ^94250              ^94270    ^94280    ^94290    ^94300    ^94310              ^94330    ^94340    ^94350    ^94360    ^94370              ^94390    ^94400    ^94410    ^94420    ^94430              ^94450    ^94460    ^94470    ^94480    ^94490              ^94510    ^94520    ^94530    ^94540    ^94550              ^94570    ^94580    ^94590    ^94600    ^94610              ^94630    ^94640    ^94650    ^94660    ^94670              ^94690    ^94700    ^94710    ^94720    ^94730              ^94750    ^94760    ^94770    ^94780    ^94790              ^94810    ^94820    ^94830    ^94840    ^94850              ^94870    ^94880    ^94890    ^94900    ^94910              ^94930    ^94940    ^94950    ^94960    ^94970              ^94990    ^95000    ^95010    ^95020    ^95030              ^95050    ^95060    ^95070    ^95080    ^95090              ^95110    ^95120    ^95130    ^95140    ^95150              ^95170    ^95180    ^95190    ^95200    ^95210              ^95230    ^95240    ^95250    ^95260    ^95270              ^95290    ^95300    ^95310    ^95320    ^95330              ^95350    ^95360    ^95370    ^95380    ^95390              ^95410    ^95420    ^95430    ^95440    ^95450              ^95470    ^95480    ^95490    ^95500    ^95510              ^95530    ^95540    ^95550    ^95560    ^95570              ^95590    ^95600    ^95610    ^95620    ^95630              ^95650    ^95660    ^95670    ^95680    ^95690              ^95710    ^95720    ^95730    ^95740    ^95750              ^95770    ^95780    ^95790    ^95800    ^95810              ^95830    ^95840    ^95850    ^95860    ^95870              ^95890    ^95900    ^95910    ^95920    ^95930              ^95950    ^95960    ^95970    ^95980    ^95990              ^96010    ^96020    ^96030    ^96040    ^96050              ^96070    ^96080    ^96090    ^96100    ^96110              ^96130    ^96140    ^96150    ^96160    ^96170              ^96190    ^96200    ^96210    ^96220    ^96230              ^96250    ^96260    ^96270    ^96280    ^96290              ^96310    ^96320    ^96330    ^96340    ^96350              ^96370    ^96380    ^96390    ^96400    ^96410              ^96430    ^96440    ^96450    ^96460    ^96470              ^96490    ^96500    ^96510    ^96520    ^96530              ^96550    ^96560    ^96570    ^96580    ^96590              ^96610    ^96620    ^96630    ^96640    ^96650              ^96670    ^96680    ^96690    ^96700    ^96710              ^96730    ^96740    ^96750    ^96760    ^96770              ^96790    ^96800    ^96810    ^96820    ^96830              ^96850    ^96860    ^96870    ^96880    ^96890              ^96910    ^96920    ^96930    ^96940    ^96950              ^96970    ^96980    ^96990    ^97000    ^97010              ^97030    ^97040    ^97050    ^97060    ^97070              ^97090    ^97100    ^97110    ^97120    ^97130              ^97150    ^97160    ^97170    ^97180    ^97190              ^97210    ^97220    ^97230    ^97240    ^97250              ^97270    ^97280    ^97290    ^97300    ^97310              ^97330    ^97340    ^97350    ^97360    ^97370              ^97390    ^97400    ^97410    ^97420    ^97430              ^97450    ^97460    ^97470    ^97480    ^97490              ^97510    ^97520    ^97530    ^97540    ^97550              ^97570    ^97580    ^97590    ^97600    ^97610              ^97630    ^97640    ^97650    ^97660    ^97670              ^97690    ^97700    ^97710    ^97720    ^97730              ^97750    ^97760    ^97770    ^97780    ^97790              ^97810    ^97820    ^97830    ^97840    ^97850              ^97870    ^97880    ^97890    ^97900    ^97910              ^97930    ^97940    ^97950    ^97960    ^97970              ^97990    ^98000    ^98010    ^98020    ^98030              ^98050    ^98060    ^98070    ^98080    ^98090              ^98110    ^98120    ^98130    ^98140    ^98150              ^98170    ^98180    ^98190    ^98200    ^98210              ^98230    ^98240    ^98250    ^98260    ^98270              ^98290    ^98300    ^98310    ^98320    ^98330              ^98350    ^98360    ^98370    ^98380    ^98390              ^98410    ^98420    ^98430    ^98440    ^98450              ^98470    ^98480    ^98490    ^98500    ^98510              ^98530    ^98540    ^98550    ^98560    ^98570              ^98590    ^98600    ^98610    ^98620    ^98630              ^98650    ^98660    ^98670    ^98680    ^98690              ^98710    ^98720    ^98730    ^98740    ^98750              ^98770    ^98780    ^98790    ^98800    ^98810              ^98830    ^98840    ^98850    ^98860    ^98870              ^98890    ^98900    ^98910    ^98920    ^98930              ^98950    ^98960    ^98970    ^98980    ^98990              ^99010    ^99020    ^99030    ^99040    ^99050              ^99070    ^99080    ^99090    ^99100    ^99110              ^99130    ^99140    ^99150    ^99160    ^99170              ^99190    ^99200    ^99210    ^99220    ^99230              ^99250    ^99260    ^99270    ^99280    ^99290              ^99310    ^99320    ^99330    ^99340    ^99350              ^99370    ^99380    ^99390    ^99400    ^99410              ^99430    ^99440    ^99450    ^99460    ^99470              ^99490    ^99500    ^99510    ^99520    ^99530              ^99550    ^99560    ^99570    ^99580    ^99590              ^99610    ^99620    ^99630    ^99640    ^99650              ^99670    ^99680    ^99690    ^99700    ^99710              ^99730    ^99740    ^99750    ^99760    ^99770              ^99790    ^99800    ^99810    ^99820    ^99830              ^99850    ^99860    ^99870    ^99880    ^99890              ^99910    ^99920    ^99930    ^99940    ^99950              ^99970    ^99980    ^99990    ^100000 ';
   }
   elsif ($basePerLine == 80) {
      return '         ^10       ^20       ^30       ^40       ^50       ^60       ^70                 ^90       ^100      ^110      ^120      ^130      ^140      ^150                ^170      ^180      ^190      ^200      ^210      ^220      ^230                ^250      ^260      ^270      ^280      ^290      ^300      ^310                ^330      ^340      ^350      ^360      ^370      ^380      ^390                ^410      ^420      ^430      ^440      ^450      ^460      ^470                ^490      ^500      ^510      ^520      ^530      ^540      ^550                ^570      ^580      ^590      ^600      ^610      ^620      ^630                ^650      ^660      ^670      ^680      ^690      ^700      ^710                ^730      ^740      ^750      ^760      ^770      ^780      ^790                ^810      ^820      ^830      ^840      ^850      ^860      ^870                ^890      ^900      ^910      ^920      ^930      ^940      ^950                ^970      ^980      ^990      ^1000     ^1010     ^1020     ^1030               ^1050     ^1060     ^1070     ^1080     ^1090     ^1100     ^1110               ^1130     ^1140     ^1150     ^1160     ^1170     ^1180     ^1190               ^1210     ^1220     ^1230     ^1240     ^1250     ^1260     ^1270               ^1290     ^1300     ^1310     ^1320     ^1330     ^1340     ^1350               ^1370     ^1380     ^1390     ^1400     ^1410     ^1420     ^1430               ^1450     ^1460     ^1470     ^1480     ^1490     ^1500     ^1510               ^1530     ^1540     ^1550     ^1560     ^1570     ^1580     ^1590               ^1610     ^1620     ^1630     ^1640     ^1650     ^1660     ^1670               ^1690     ^1700     ^1710     ^1720     ^1730     ^1740     ^1750               ^1770     ^1780     ^1790     ^1800     ^1810     ^1820     ^1830               ^1850     ^1860     ^1870     ^1880     ^1890     ^1900     ^1910               ^1930     ^1940     ^1950     ^1960     ^1970     ^1980     ^1990               ^2010     ^2020     ^2030     ^2040     ^2050     ^2060     ^2070               ^2090     ^2100     ^2110     ^2120     ^2130     ^2140     ^2150               ^2170     ^2180     ^2190     ^2200     ^2210     ^2220     ^2230               ^2250     ^2260     ^2270     ^2280     ^2290     ^2300     ^2310               ^2330     ^2340     ^2350     ^2360     ^2370     ^2380     ^2390               ^2410     ^2420     ^2430     ^2440     ^2450     ^2460     ^2470               ^2490     ^2500     ^2510     ^2520     ^2530     ^2540     ^2550               ^2570     ^2580     ^2590     ^2600     ^2610     ^2620     ^2630               ^2650     ^2660     ^2670     ^2680     ^2690     ^2700     ^2710               ^2730     ^2740     ^2750     ^2760     ^2770     ^2780     ^2790               ^2810     ^2820     ^2830     ^2840     ^2850     ^2860     ^2870               ^2890     ^2900     ^2910     ^2920     ^2930     ^2940     ^2950               ^2970     ^2980     ^2990     ^3000     ^3010     ^3020     ^3030               ^3050     ^3060     ^3070     ^3080     ^3090     ^3100     ^3110               ^3130     ^3140     ^3150     ^3160     ^3170     ^3180     ^3190               ^3210     ^3220     ^3230     ^3240     ^3250     ^3260     ^3270               ^3290     ^3300     ^3310     ^3320     ^3330     ^3340     ^3350               ^3370     ^3380     ^3390     ^3400     ^3410     ^3420     ^3430               ^3450     ^3460     ^3470     ^3480     ^3490     ^3500     ^3510               ^3530     ^3540     ^3550     ^3560     ^3570     ^3580     ^3590               ^3610     ^3620     ^3630     ^3640     ^3650     ^3660     ^3670               ^3690     ^3700     ^3710     ^3720     ^3730     ^3740     ^3750               ^3770     ^3780     ^3790     ^3800     ^3810     ^3820     ^3830               ^3850     ^3860     ^3870     ^3880     ^3890     ^3900     ^3910               ^3930     ^3940     ^3950     ^3960     ^3970     ^3980     ^3990               ^4010     ^4020     ^4030     ^4040     ^4050     ^4060     ^4070               ^4090     ^4100     ^4110     ^4120     ^4130     ^4140     ^4150               ^4170     ^4180     ^4190     ^4200     ^4210     ^4220     ^4230               ^4250     ^4260     ^4270     ^4280     ^4290     ^4300     ^4310               ^4330     ^4340     ^4350     ^4360     ^4370     ^4380     ^4390               ^4410     ^4420     ^4430     ^4440     ^4450     ^4460     ^4470               ^4490     ^4500     ^4510     ^4520     ^4530     ^4540     ^4550               ^4570     ^4580     ^4590     ^4600     ^4610     ^4620     ^4630               ^4650     ^4660     ^4670     ^4680     ^4690     ^4700     ^4710               ^4730     ^4740     ^4750     ^4760     ^4770     ^4780     ^4790               ^4810     ^4820     ^4830     ^4840     ^4850     ^4860     ^4870               ^4890     ^4900     ^4910     ^4920     ^4930     ^4940     ^4950               ^4970     ^4980     ^4990     ^5000     ^5010     ^5020     ^5030               ^5050     ^5060     ^5070     ^5080     ^5090     ^5100     ^5110               ^5130     ^5140     ^5150     ^5160     ^5170     ^5180     ^5190               ^5210     ^5220     ^5230     ^5240     ^5250     ^5260     ^5270               ^5290     ^5300     ^5310     ^5320     ^5330     ^5340     ^5350               ^5370     ^5380     ^5390     ^5400     ^5410     ^5420     ^5430               ^5450     ^5460     ^5470     ^5480     ^5490     ^5500     ^5510               ^5530     ^5540     ^5550     ^5560     ^5570     ^5580     ^5590               ^5610     ^5620     ^5630     ^5640     ^5650     ^5660     ^5670               ^5690     ^5700     ^5710     ^5720     ^5730     ^5740     ^5750               ^5770     ^5780     ^5790     ^5800     ^5810     ^5820     ^5830               ^5850     ^5860     ^5870     ^5880     ^5890     ^5900     ^5910               ^5930     ^5940     ^5950     ^5960     ^5970     ^5980     ^5990               ^6010     ^6020     ^6030     ^6040     ^6050     ^6060     ^6070               ^6090     ^6100     ^6110     ^6120     ^6130     ^6140     ^6150               ^6170     ^6180     ^6190     ^6200     ^6210     ^6220     ^6230               ^6250     ^6260     ^6270     ^6280     ^6290     ^6300     ^6310               ^6330     ^6340     ^6350     ^6360     ^6370     ^6380     ^6390               ^6410     ^6420     ^6430     ^6440     ^6450     ^6460     ^6470               ^6490     ^6500     ^6510     ^6520     ^6530     ^6540     ^6550               ^6570     ^6580     ^6590     ^6600     ^6610     ^6620     ^6630               ^6650     ^6660     ^6670     ^6680     ^6690     ^6700     ^6710               ^6730     ^6740     ^6750     ^6760     ^6770     ^6780     ^6790               ^6810     ^6820     ^6830     ^6840     ^6850     ^6860     ^6870               ^6890     ^6900     ^6910     ^6920     ^6930     ^6940     ^6950               ^6970     ^6980     ^6990     ^7000     ^7010     ^7020     ^7030               ^7050     ^7060     ^7070     ^7080     ^7090     ^7100     ^7110               ^7130     ^7140     ^7150     ^7160     ^7170     ^7180     ^7190               ^7210     ^7220     ^7230     ^7240     ^7250     ^7260     ^7270               ^7290     ^7300     ^7310     ^7320     ^7330     ^7340     ^7350               ^7370     ^7380     ^7390     ^7400     ^7410     ^7420     ^7430               ^7450     ^7460     ^7470     ^7480     ^7490     ^7500     ^7510               ^7530     ^7540     ^7550     ^7560     ^7570     ^7580     ^7590               ^7610     ^7620     ^7630     ^7640     ^7650     ^7660     ^7670               ^7690     ^7700     ^7710     ^7720     ^7730     ^7740     ^7750               ^7770     ^7780     ^7790     ^7800     ^7810     ^7820     ^7830               ^7850     ^7860     ^7870     ^7880     ^7890     ^7900     ^7910               ^7930     ^7940     ^7950     ^7960     ^7970     ^7980     ^7990               ^8010     ^8020     ^8030     ^8040     ^8050     ^8060     ^8070               ^8090     ^8100     ^8110     ^8120     ^8130     ^8140     ^8150               ^8170     ^8180     ^8190     ^8200     ^8210     ^8220     ^8230               ^8250     ^8260     ^8270     ^8280     ^8290     ^8300     ^8310               ^8330     ^8340     ^8350     ^8360     ^8370     ^8380     ^8390               ^8410     ^8420     ^8430     ^8440     ^8450     ^8460     ^8470               ^8490     ^8500     ^8510     ^8520     ^8530     ^8540     ^8550               ^8570     ^8580     ^8590     ^8600     ^8610     ^8620     ^8630               ^8650     ^8660     ^8670     ^8680     ^8690     ^8700     ^8710               ^8730     ^8740     ^8750     ^8760     ^8770     ^8780     ^8790               ^8810     ^8820     ^8830     ^8840     ^8850     ^8860     ^8870               ^8890     ^8900     ^8910     ^8920     ^8930     ^8940     ^8950               ^8970     ^8980     ^8990     ^9000     ^9010     ^9020     ^9030               ^9050     ^9060     ^9070     ^9080     ^9090     ^9100     ^9110               ^9130     ^9140     ^9150     ^9160     ^9170     ^9180     ^9190               ^9210     ^9220     ^9230     ^9240     ^9250     ^9260     ^9270               ^9290     ^9300     ^9310     ^9320     ^9330     ^9340     ^9350               ^9370     ^9380     ^9390     ^9400     ^9410     ^9420     ^9430               ^9450     ^9460     ^9470     ^9480     ^9490     ^9500     ^9510               ^9530     ^9540     ^9550     ^9560     ^9570     ^9580     ^9590               ^9610     ^9620     ^9630     ^9640     ^9650     ^9660     ^9670               ^9690     ^9700     ^9710     ^9720     ^9730     ^9740     ^9750               ^9770     ^9780     ^9790     ^9800     ^9810     ^9820     ^9830               ^9850     ^9860     ^9870     ^9880     ^9890     ^9900     ^9910               ^9930     ^9940     ^9950     ^9960     ^9970     ^9980     ^9990               ^10010    ^10020    ^10030    ^10040    ^10050    ^10060    ^10070              ^10090    ^10100    ^10110    ^10120    ^10130    ^10140    ^10150              ^10170    ^10180    ^10190    ^10200    ^10210    ^10220    ^10230              ^10250    ^10260    ^10270    ^10280    ^10290    ^10300    ^10310              ^10330    ^10340    ^10350    ^10360    ^10370    ^10380    ^10390              ^10410    ^10420    ^10430    ^10440    ^10450    ^10460    ^10470              ^10490    ^10500    ^10510    ^10520    ^10530    ^10540    ^10550              ^10570    ^10580    ^10590    ^10600    ^10610    ^10620    ^10630              ^10650    ^10660    ^10670    ^10680    ^10690    ^10700    ^10710              ^10730    ^10740    ^10750    ^10760    ^10770    ^10780    ^10790              ^10810    ^10820    ^10830    ^10840    ^10850    ^10860    ^10870              ^10890    ^10900    ^10910    ^10920    ^10930    ^10940    ^10950              ^10970    ^10980    ^10990    ^11000    ^11010    ^11020    ^11030              ^11050    ^11060    ^11070    ^11080    ^11090    ^11100    ^11110              ^11130    ^11140    ^11150    ^11160    ^11170    ^11180    ^11190              ^11210    ^11220    ^11230    ^11240    ^11250    ^11260    ^11270              ^11290    ^11300    ^11310    ^11320    ^11330    ^11340    ^11350              ^11370    ^11380    ^11390    ^11400    ^11410    ^11420    ^11430              ^11450    ^11460    ^11470    ^11480    ^11490    ^11500    ^11510              ^11530    ^11540    ^11550    ^11560    ^11570    ^11580    ^11590              ^11610    ^11620    ^11630    ^11640    ^11650    ^11660    ^11670              ^11690    ^11700    ^11710    ^11720    ^11730    ^11740    ^11750              ^11770    ^11780    ^11790    ^11800    ^11810    ^11820    ^11830              ^11850    ^11860    ^11870    ^11880    ^11890    ^11900    ^11910              ^11930    ^11940    ^11950    ^11960    ^11970    ^11980    ^11990              ^12010    ^12020    ^12030    ^12040    ^12050    ^12060    ^12070              ^12090    ^12100    ^12110    ^12120    ^12130    ^12140    ^12150              ^12170    ^12180    ^12190    ^12200    ^12210    ^12220    ^12230              ^12250    ^12260    ^12270    ^12280    ^12290    ^12300    ^12310              ^12330    ^12340    ^12350    ^12360    ^12370    ^12380    ^12390              ^12410    ^12420    ^12430    ^12440    ^12450    ^12460    ^12470              ^12490    ^12500    ^12510    ^12520    ^12530    ^12540    ^12550              ^12570    ^12580    ^12590    ^12600    ^12610    ^12620    ^12630              ^12650    ^12660    ^12670    ^12680    ^12690    ^12700    ^12710              ^12730    ^12740    ^12750    ^12760    ^12770    ^12780    ^12790              ^12810    ^12820    ^12830    ^12840    ^12850    ^12860    ^12870              ^12890    ^12900    ^12910    ^12920    ^12930    ^12940    ^12950              ^12970    ^12980    ^12990    ^13000    ^13010    ^13020    ^13030              ^13050    ^13060    ^13070    ^13080    ^13090    ^13100    ^13110              ^13130    ^13140    ^13150    ^13160    ^13170    ^13180    ^13190              ^13210    ^13220    ^13230    ^13240    ^13250    ^13260    ^13270              ^13290    ^13300    ^13310    ^13320    ^13330    ^13340    ^13350              ^13370    ^13380    ^13390    ^13400    ^13410    ^13420    ^13430              ^13450    ^13460    ^13470    ^13480    ^13490    ^13500    ^13510              ^13530    ^13540    ^13550    ^13560    ^13570    ^13580    ^13590              ^13610    ^13620    ^13630    ^13640    ^13650    ^13660    ^13670              ^13690    ^13700    ^13710    ^13720    ^13730    ^13740    ^13750              ^13770    ^13780    ^13790    ^13800    ^13810    ^13820    ^13830              ^13850    ^13860    ^13870    ^13880    ^13890    ^13900    ^13910              ^13930    ^13940    ^13950    ^13960    ^13970    ^13980    ^13990              ^14010    ^14020    ^14030    ^14040    ^14050    ^14060    ^14070              ^14090    ^14100    ^14110    ^14120    ^14130    ^14140    ^14150              ^14170    ^14180    ^14190    ^14200    ^14210    ^14220    ^14230              ^14250    ^14260    ^14270    ^14280    ^14290    ^14300    ^14310              ^14330    ^14340    ^14350    ^14360    ^14370    ^14380    ^14390              ^14410    ^14420    ^14430    ^14440    ^14450    ^14460    ^14470              ^14490    ^14500    ^14510    ^14520    ^14530    ^14540    ^14550              ^14570    ^14580    ^14590    ^14600    ^14610    ^14620    ^14630              ^14650    ^14660    ^14670    ^14680    ^14690    ^14700    ^14710              ^14730    ^14740    ^14750    ^14760    ^14770    ^14780    ^14790              ^14810    ^14820    ^14830    ^14840    ^14850    ^14860    ^14870              ^14890    ^14900    ^14910    ^14920    ^14930    ^14940    ^14950              ^14970    ^14980    ^14990    ^15000    ^15010    ^15020    ^15030              ^15050    ^15060    ^15070    ^15080    ^15090    ^15100    ^15110              ^15130    ^15140    ^15150    ^15160    ^15170    ^15180    ^15190              ^15210    ^15220    ^15230    ^15240    ^15250    ^15260    ^15270              ^15290    ^15300    ^15310    ^15320    ^15330    ^15340    ^15350              ^15370    ^15380    ^15390    ^15400    ^15410    ^15420    ^15430              ^15450    ^15460    ^15470    ^15480    ^15490    ^15500    ^15510              ^15530    ^15540    ^15550    ^15560    ^15570    ^15580    ^15590              ^15610    ^15620    ^15630    ^15640    ^15650    ^15660    ^15670              ^15690    ^15700    ^15710    ^15720    ^15730    ^15740    ^15750              ^15770    ^15780    ^15790    ^15800    ^15810    ^15820    ^15830              ^15850    ^15860    ^15870    ^15880    ^15890    ^15900    ^15910              ^15930    ^15940    ^15950    ^15960    ^15970    ^15980    ^15990              ^16010    ^16020    ^16030    ^16040    ^16050    ^16060    ^16070              ^16090    ^16100    ^16110    ^16120    ^16130    ^16140    ^16150              ^16170    ^16180    ^16190    ^16200    ^16210    ^16220    ^16230              ^16250    ^16260    ^16270    ^16280    ^16290    ^16300    ^16310              ^16330    ^16340    ^16350    ^16360    ^16370    ^16380    ^16390              ^16410    ^16420    ^16430    ^16440    ^16450    ^16460    ^16470              ^16490    ^16500    ^16510    ^16520    ^16530    ^16540    ^16550              ^16570    ^16580    ^16590    ^16600    ^16610    ^16620    ^16630              ^16650    ^16660    ^16670    ^16680    ^16690    ^16700    ^16710              ^16730    ^16740    ^16750    ^16760    ^16770    ^16780    ^16790              ^16810    ^16820    ^16830    ^16840    ^16850    ^16860    ^16870              ^16890    ^16900    ^16910    ^16920    ^16930    ^16940    ^16950              ^16970    ^16980    ^16990    ^17000    ^17010    ^17020    ^17030              ^17050    ^17060    ^17070    ^17080    ^17090    ^17100    ^17110              ^17130    ^17140    ^17150    ^17160    ^17170    ^17180    ^17190              ^17210    ^17220    ^17230    ^17240    ^17250    ^17260    ^17270              ^17290    ^17300    ^17310    ^17320    ^17330    ^17340    ^17350              ^17370    ^17380    ^17390    ^17400    ^17410    ^17420    ^17430              ^17450    ^17460    ^17470    ^17480    ^17490    ^17500    ^17510              ^17530    ^17540    ^17550    ^17560    ^17570    ^17580    ^17590              ^17610    ^17620    ^17630    ^17640    ^17650    ^17660    ^17670              ^17690    ^17700    ^17710    ^17720    ^17730    ^17740    ^17750              ^17770    ^17780    ^17790    ^17800    ^17810    ^17820    ^17830              ^17850    ^17860    ^17870    ^17880    ^17890    ^17900    ^17910              ^17930    ^17940    ^17950    ^17960    ^17970    ^17980    ^17990              ^18010    ^18020    ^18030    ^18040    ^18050    ^18060    ^18070              ^18090    ^18100    ^18110    ^18120    ^18130    ^18140    ^18150              ^18170    ^18180    ^18190    ^18200    ^18210    ^18220    ^18230              ^18250    ^18260    ^18270    ^18280    ^18290    ^18300    ^18310              ^18330    ^18340    ^18350    ^18360    ^18370    ^18380    ^18390              ^18410    ^18420    ^18430    ^18440    ^18450    ^18460    ^18470              ^18490    ^18500    ^18510    ^18520    ^18530    ^18540    ^18550              ^18570    ^18580    ^18590    ^18600    ^18610    ^18620    ^18630              ^18650    ^18660    ^18670    ^18680    ^18690    ^18700    ^18710              ^18730    ^18740    ^18750    ^18760    ^18770    ^18780    ^18790              ^18810    ^18820    ^18830    ^18840    ^18850    ^18860    ^18870              ^18890    ^18900    ^18910    ^18920    ^18930    ^18940    ^18950              ^18970    ^18980    ^18990    ^19000    ^19010    ^19020    ^19030              ^19050    ^19060    ^19070    ^19080    ^19090    ^19100    ^19110              ^19130    ^19140    ^19150    ^19160    ^19170    ^19180    ^19190              ^19210    ^19220    ^19230    ^19240    ^19250    ^19260    ^19270              ^19290    ^19300    ^19310    ^19320    ^19330    ^19340    ^19350              ^19370    ^19380    ^19390    ^19400    ^19410    ^19420    ^19430              ^19450    ^19460    ^19470    ^19480    ^19490    ^19500    ^19510              ^19530    ^19540    ^19550    ^19560    ^19570    ^19580    ^19590              ^19610    ^19620    ^19630    ^19640    ^19650    ^19660    ^19670              ^19690    ^19700    ^19710    ^19720    ^19730    ^19740    ^19750              ^19770    ^19780    ^19790    ^19800    ^19810    ^19820    ^19830              ^19850    ^19860    ^19870    ^19880    ^19890    ^19900    ^19910              ^19930    ^19940    ^19950    ^19960    ^19970    ^19980    ^19990              ^20010    ^20020    ^20030    ^20040    ^20050    ^20060    ^20070              ^20090    ^20100    ^20110    ^20120    ^20130    ^20140    ^20150              ^20170    ^20180    ^20190    ^20200    ^20210    ^20220    ^20230              ^20250    ^20260    ^20270    ^20280    ^20290    ^20300    ^20310              ^20330    ^20340    ^20350    ^20360    ^20370    ^20380    ^20390              ^20410    ^20420    ^20430    ^20440    ^20450    ^20460    ^20470              ^20490    ^20500    ^20510    ^20520    ^20530    ^20540    ^20550              ^20570    ^20580    ^20590    ^20600    ^20610    ^20620    ^20630              ^20650    ^20660    ^20670    ^20680    ^20690    ^20700    ^20710              ^20730    ^20740    ^20750    ^20760    ^20770    ^20780    ^20790              ^20810    ^20820    ^20830    ^20840    ^20850    ^20860    ^20870              ^20890    ^20900    ^20910    ^20920    ^20930    ^20940    ^20950              ^20970    ^20980    ^20990    ^21000    ^21010    ^21020    ^21030              ^21050    ^21060    ^21070    ^21080    ^21090    ^21100    ^21110              ^21130    ^21140    ^21150    ^21160    ^21170    ^21180    ^21190              ^21210    ^21220    ^21230    ^21240    ^21250    ^21260    ^21270              ^21290    ^21300    ^21310    ^21320    ^21330    ^21340    ^21350              ^21370    ^21380    ^21390    ^21400    ^21410    ^21420    ^21430              ^21450    ^21460    ^21470    ^21480    ^21490    ^21500    ^21510              ^21530    ^21540    ^21550    ^21560    ^21570    ^21580    ^21590              ^21610    ^21620    ^21630    ^21640    ^21650    ^21660    ^21670              ^21690    ^21700    ^21710    ^21720    ^21730    ^21740    ^21750              ^21770    ^21780    ^21790    ^21800    ^21810    ^21820    ^21830              ^21850    ^21860    ^21870    ^21880    ^21890    ^21900    ^21910              ^21930    ^21940    ^21950    ^21960    ^21970    ^21980    ^21990              ^22010    ^22020    ^22030    ^22040    ^22050    ^22060    ^22070              ^22090    ^22100    ^22110    ^22120    ^22130    ^22140    ^22150              ^22170    ^22180    ^22190    ^22200    ^22210    ^22220    ^22230              ^22250    ^22260    ^22270    ^22280    ^22290    ^22300    ^22310              ^22330    ^22340    ^22350    ^22360    ^22370    ^22380    ^22390              ^22410    ^22420    ^22430    ^22440    ^22450    ^22460    ^22470              ^22490    ^22500    ^22510    ^22520    ^22530    ^22540    ^22550              ^22570    ^22580    ^22590    ^22600    ^22610    ^22620    ^22630              ^22650    ^22660    ^22670    ^22680    ^22690    ^22700    ^22710              ^22730    ^22740    ^22750    ^22760    ^22770    ^22780    ^22790              ^22810    ^22820    ^22830    ^22840    ^22850    ^22860    ^22870              ^22890    ^22900    ^22910    ^22920    ^22930    ^22940    ^22950              ^22970    ^22980    ^22990    ^23000    ^23010    ^23020    ^23030              ^23050    ^23060    ^23070    ^23080    ^23090    ^23100    ^23110              ^23130    ^23140    ^23150    ^23160    ^23170    ^23180    ^23190              ^23210    ^23220    ^23230    ^23240    ^23250    ^23260    ^23270              ^23290    ^23300    ^23310    ^23320    ^23330    ^23340    ^23350              ^23370    ^23380    ^23390    ^23400    ^23410    ^23420    ^23430              ^23450    ^23460    ^23470    ^23480    ^23490    ^23500    ^23510              ^23530    ^23540    ^23550    ^23560    ^23570    ^23580    ^23590              ^23610    ^23620    ^23630    ^23640    ^23650    ^23660    ^23670              ^23690    ^23700    ^23710    ^23720    ^23730    ^23740    ^23750              ^23770    ^23780    ^23790    ^23800    ^23810    ^23820    ^23830              ^23850    ^23860    ^23870    ^23880    ^23890    ^23900    ^23910              ^23930    ^23940    ^23950    ^23960    ^23970    ^23980    ^23990              ^24010    ^24020    ^24030    ^24040    ^24050    ^24060    ^24070              ^24090    ^24100    ^24110    ^24120    ^24130    ^24140    ^24150              ^24170    ^24180    ^24190    ^24200    ^24210    ^24220    ^24230              ^24250    ^24260    ^24270    ^24280    ^24290    ^24300    ^24310              ^24330    ^24340    ^24350    ^24360    ^24370    ^24380    ^24390              ^24410    ^24420    ^24430    ^24440    ^24450    ^24460    ^24470              ^24490    ^24500    ^24510    ^24520    ^24530    ^24540    ^24550              ^24570    ^24580    ^24590    ^24600    ^24610    ^24620    ^24630              ^24650    ^24660    ^24670    ^24680    ^24690    ^24700    ^24710              ^24730    ^24740    ^24750    ^24760    ^24770    ^24780    ^24790              ^24810    ^24820    ^24830    ^24840    ^24850    ^24860    ^24870              ^24890    ^24900    ^24910    ^24920    ^24930    ^24940    ^24950              ^24970    ^24980    ^24990    ^25000    ^25010    ^25020    ^25030              ^25050    ^25060    ^25070    ^25080    ^25090    ^25100    ^25110              ^25130    ^25140    ^25150    ^25160    ^25170    ^25180    ^25190              ^25210    ^25220    ^25230    ^25240    ^25250    ^25260    ^25270              ^25290    ^25300    ^25310    ^25320    ^25330    ^25340    ^25350              ^25370    ^25380    ^25390    ^25400    ^25410    ^25420    ^25430              ^25450    ^25460    ^25470    ^25480    ^25490    ^25500    ^25510              ^25530    ^25540    ^25550    ^25560    ^25570    ^25580    ^25590              ^25610    ^25620    ^25630    ^25640    ^25650    ^25660    ^25670              ^25690    ^25700    ^25710    ^25720    ^25730    ^25740    ^25750              ^25770    ^25780    ^25790    ^25800    ^25810    ^25820    ^25830              ^25850    ^25860    ^25870    ^25880    ^25890    ^25900    ^25910              ^25930    ^25940    ^25950    ^25960    ^25970    ^25980    ^25990              ^26010    ^26020    ^26030    ^26040    ^26050    ^26060    ^26070              ^26090    ^26100    ^26110    ^26120    ^26130    ^26140    ^26150              ^26170    ^26180    ^26190    ^26200    ^26210    ^26220    ^26230              ^26250    ^26260    ^26270    ^26280    ^26290    ^26300    ^26310              ^26330    ^26340    ^26350    ^26360    ^26370    ^26380    ^26390              ^26410    ^26420    ^26430    ^26440    ^26450    ^26460    ^26470              ^26490    ^26500    ^26510    ^26520    ^26530    ^26540    ^26550              ^26570    ^26580    ^26590    ^26600    ^26610    ^26620    ^26630              ^26650    ^26660    ^26670    ^26680    ^26690    ^26700    ^26710              ^26730    ^26740    ^26750    ^26760    ^26770    ^26780    ^26790              ^26810    ^26820    ^26830    ^26840    ^26850    ^26860    ^26870              ^26890    ^26900    ^26910    ^26920    ^26930    ^26940    ^26950              ^26970    ^26980    ^26990    ^27000    ^27010    ^27020    ^27030              ^27050    ^27060    ^27070    ^27080    ^27090    ^27100    ^27110              ^27130    ^27140    ^27150    ^27160    ^27170    ^27180    ^27190              ^27210    ^27220    ^27230    ^27240    ^27250    ^27260    ^27270              ^27290    ^27300    ^27310    ^27320    ^27330    ^27340    ^27350              ^27370    ^27380    ^27390    ^27400    ^27410    ^27420    ^27430              ^27450    ^27460    ^27470    ^27480    ^27490    ^27500    ^27510              ^27530    ^27540    ^27550    ^27560    ^27570    ^27580    ^27590              ^27610    ^27620    ^27630    ^27640    ^27650    ^27660    ^27670              ^27690    ^27700    ^27710    ^27720    ^27730    ^27740    ^27750              ^27770    ^27780    ^27790    ^27800    ^27810    ^27820    ^27830              ^27850    ^27860    ^27870    ^27880    ^27890    ^27900    ^27910              ^27930    ^27940    ^27950    ^27960    ^27970    ^27980    ^27990              ^28010    ^28020    ^28030    ^28040    ^28050    ^28060    ^28070              ^28090    ^28100    ^28110    ^28120    ^28130    ^28140    ^28150              ^28170    ^28180    ^28190    ^28200    ^28210    ^28220    ^28230              ^28250    ^28260    ^28270    ^28280    ^28290    ^28300    ^28310              ^28330    ^28340    ^28350    ^28360    ^28370    ^28380    ^28390              ^28410    ^28420    ^28430    ^28440    ^28450    ^28460    ^28470              ^28490    ^28500    ^28510    ^28520    ^28530    ^28540    ^28550              ^28570    ^28580    ^28590    ^28600    ^28610    ^28620    ^28630              ^28650    ^28660    ^28670    ^28680    ^28690    ^28700    ^28710              ^28730    ^28740    ^28750    ^28760    ^28770    ^28780    ^28790              ^28810    ^28820    ^28830    ^28840    ^28850    ^28860    ^28870              ^28890    ^28900    ^28910    ^28920    ^28930    ^28940    ^28950              ^28970    ^28980    ^28990    ^29000    ^29010    ^29020    ^29030              ^29050    ^29060    ^29070    ^29080    ^29090    ^29100    ^29110              ^29130    ^29140    ^29150    ^29160    ^29170    ^29180    ^29190              ^29210    ^29220    ^29230    ^29240    ^29250    ^29260    ^29270              ^29290    ^29300    ^29310    ^29320    ^29330    ^29340    ^29350              ^29370    ^29380    ^29390    ^29400    ^29410    ^29420    ^29430              ^29450    ^29460    ^29470    ^29480    ^29490    ^29500    ^29510              ^29530    ^29540    ^29550    ^29560    ^29570    ^29580    ^29590              ^29610    ^29620    ^29630    ^29640    ^29650    ^29660    ^29670              ^29690    ^29700    ^29710    ^29720    ^29730    ^29740    ^29750              ^29770    ^29780    ^29790    ^29800    ^29810    ^29820    ^29830              ^29850    ^29860    ^29870    ^29880    ^29890    ^29900    ^29910              ^29930    ^29940    ^29950    ^29960    ^29970    ^29980    ^29990              ^30010    ^30020    ^30030    ^30040    ^30050    ^30060    ^30070              ^30090    ^30100    ^30110    ^30120    ^30130    ^30140    ^30150              ^30170    ^30180    ^30190    ^30200    ^30210    ^30220    ^30230              ^30250    ^30260    ^30270    ^30280    ^30290    ^30300    ^30310              ^30330    ^30340    ^30350    ^30360    ^30370    ^30380    ^30390              ^30410    ^30420    ^30430    ^30440    ^30450    ^30460    ^30470              ^30490    ^30500    ^30510    ^30520    ^30530    ^30540    ^30550              ^30570    ^30580    ^30590    ^30600    ^30610    ^30620    ^30630              ^30650    ^30660    ^30670    ^30680    ^30690    ^30700    ^30710              ^30730    ^30740    ^30750    ^30760    ^30770    ^30780    ^30790              ^30810    ^30820    ^30830    ^30840    ^30850    ^30860    ^30870              ^30890    ^30900    ^30910    ^30920    ^30930    ^30940    ^30950              ^30970    ^30980    ^30990    ^31000    ^31010    ^31020    ^31030              ^31050    ^31060    ^31070    ^31080    ^31090    ^31100    ^31110              ^31130    ^31140    ^31150    ^31160    ^31170    ^31180    ^31190              ^31210    ^31220    ^31230    ^31240    ^31250    ^31260    ^31270              ^31290    ^31300    ^31310    ^31320    ^31330    ^31340    ^31350              ^31370    ^31380    ^31390    ^31400    ^31410    ^31420    ^31430              ^31450    ^31460    ^31470    ^31480    ^31490    ^31500    ^31510              ^31530    ^31540    ^31550    ^31560    ^31570    ^31580    ^31590              ^31610    ^31620    ^31630    ^31640    ^31650    ^31660    ^31670              ^31690    ^31700    ^31710    ^31720    ^31730    ^31740    ^31750              ^31770    ^31780    ^31790    ^31800    ^31810    ^31820    ^31830              ^31850    ^31860    ^31870    ^31880    ^31890    ^31900    ^31910              ^31930    ^31940    ^31950    ^31960    ^31970    ^31980    ^31990              ^32010    ^32020    ^32030    ^32040    ^32050    ^32060    ^32070              ^32090    ^32100    ^32110    ^32120    ^32130    ^32140    ^32150              ^32170    ^32180    ^32190    ^32200    ^32210    ^32220    ^32230              ^32250    ^32260    ^32270    ^32280    ^32290    ^32300    ^32310              ^32330    ^32340    ^32350    ^32360    ^32370    ^32380    ^32390              ^32410    ^32420    ^32430    ^32440    ^32450    ^32460    ^32470              ^32490    ^32500    ^32510    ^32520    ^32530    ^32540    ^32550              ^32570    ^32580    ^32590    ^32600    ^32610    ^32620    ^32630              ^32650    ^32660    ^32670    ^32680    ^32690    ^32700    ^32710              ^32730    ^32740    ^32750    ^32760    ^32770    ^32780    ^32790              ^32810    ^32820    ^32830    ^32840    ^32850    ^32860    ^32870              ^32890    ^32900    ^32910    ^32920    ^32930    ^32940    ^32950              ^32970    ^32980    ^32990    ^33000    ^33010    ^33020    ^33030              ^33050    ^33060    ^33070    ^33080    ^33090    ^33100    ^33110              ^33130    ^33140    ^33150    ^33160    ^33170    ^33180    ^33190              ^33210    ^33220    ^33230    ^33240    ^33250    ^33260    ^33270              ^33290    ^33300    ^33310    ^33320    ^33330    ^33340    ^33350              ^33370    ^33380    ^33390    ^33400    ^33410    ^33420    ^33430              ^33450    ^33460    ^33470    ^33480    ^33490    ^33500    ^33510              ^33530    ^33540    ^33550    ^33560    ^33570    ^33580    ^33590              ^33610    ^33620    ^33630    ^33640    ^33650    ^33660    ^33670              ^33690    ^33700    ^33710    ^33720    ^33730    ^33740    ^33750              ^33770    ^33780    ^33790    ^33800    ^33810    ^33820    ^33830              ^33850    ^33860    ^33870    ^33880    ^33890    ^33900    ^33910              ^33930    ^33940    ^33950    ^33960    ^33970    ^33980    ^33990              ^34010    ^34020    ^34030    ^34040    ^34050    ^34060    ^34070              ^34090    ^34100    ^34110    ^34120    ^34130    ^34140    ^34150              ^34170    ^34180    ^34190    ^34200    ^34210    ^34220    ^34230              ^34250    ^34260    ^34270    ^34280    ^34290    ^34300    ^34310              ^34330    ^34340    ^34350    ^34360    ^34370    ^34380    ^34390              ^34410    ^34420    ^34430    ^34440    ^34450    ^34460    ^34470              ^34490    ^34500    ^34510    ^34520    ^34530    ^34540    ^34550              ^34570    ^34580    ^34590    ^34600    ^34610    ^34620    ^34630              ^34650    ^34660    ^34670    ^34680    ^34690    ^34700    ^34710              ^34730    ^34740    ^34750    ^34760    ^34770    ^34780    ^34790              ^34810    ^34820    ^34830    ^34840    ^34850    ^34860    ^34870              ^34890    ^34900    ^34910    ^34920    ^34930    ^34940    ^34950              ^34970    ^34980    ^34990    ^35000    ^35010    ^35020    ^35030              ^35050    ^35060    ^35070    ^35080    ^35090    ^35100    ^35110              ^35130    ^35140    ^35150    ^35160    ^35170    ^35180    ^35190              ^35210    ^35220    ^35230    ^35240    ^35250    ^35260    ^35270              ^35290    ^35300    ^35310    ^35320    ^35330    ^35340    ^35350              ^35370    ^35380    ^35390    ^35400    ^35410    ^35420    ^35430              ^35450    ^35460    ^35470    ^35480    ^35490    ^35500    ^35510              ^35530    ^35540    ^35550    ^35560    ^35570    ^35580    ^35590              ^35610    ^35620    ^35630    ^35640    ^35650    ^35660    ^35670              ^35690    ^35700    ^35710    ^35720    ^35730    ^35740    ^35750              ^35770    ^35780    ^35790    ^35800    ^35810    ^35820    ^35830              ^35850    ^35860    ^35870    ^35880    ^35890    ^35900    ^35910              ^35930    ^35940    ^35950    ^35960    ^35970    ^35980    ^35990              ^36010    ^36020    ^36030    ^36040    ^36050    ^36060    ^36070              ^36090    ^36100    ^36110    ^36120    ^36130    ^36140    ^36150              ^36170    ^36180    ^36190    ^36200    ^36210    ^36220    ^36230              ^36250    ^36260    ^36270    ^36280    ^36290    ^36300    ^36310              ^36330    ^36340    ^36350    ^36360    ^36370    ^36380    ^36390              ^36410    ^36420    ^36430    ^36440    ^36450    ^36460    ^36470              ^36490    ^36500    ^36510    ^36520    ^36530    ^36540    ^36550              ^36570    ^36580    ^36590    ^36600    ^36610    ^36620    ^36630              ^36650    ^36660    ^36670    ^36680    ^36690    ^36700    ^36710              ^36730    ^36740    ^36750    ^36760    ^36770    ^36780    ^36790              ^36810    ^36820    ^36830    ^36840    ^36850    ^36860    ^36870              ^36890    ^36900    ^36910    ^36920    ^36930    ^36940    ^36950              ^36970    ^36980    ^36990    ^37000    ^37010    ^37020    ^37030              ^37050    ^37060    ^37070    ^37080    ^37090    ^37100    ^37110              ^37130    ^37140    ^37150    ^37160    ^37170    ^37180    ^37190              ^37210    ^37220    ^37230    ^37240    ^37250    ^37260    ^37270              ^37290    ^37300    ^37310    ^37320    ^37330    ^37340    ^37350              ^37370    ^37380    ^37390    ^37400    ^37410    ^37420    ^37430              ^37450    ^37460    ^37470    ^37480    ^37490    ^37500    ^37510              ^37530    ^37540    ^37550    ^37560    ^37570    ^37580    ^37590              ^37610    ^37620    ^37630    ^37640    ^37650    ^37660    ^37670              ^37690    ^37700    ^37710    ^37720    ^37730    ^37740    ^37750              ^37770    ^37780    ^37790    ^37800    ^37810    ^37820    ^37830              ^37850    ^37860    ^37870    ^37880    ^37890    ^37900    ^37910              ^37930    ^37940    ^37950    ^37960    ^37970    ^37980    ^37990              ^38010    ^38020    ^38030    ^38040    ^38050    ^38060    ^38070              ^38090    ^38100    ^38110    ^38120    ^38130    ^38140    ^38150              ^38170    ^38180    ^38190    ^38200    ^38210    ^38220    ^38230              ^38250    ^38260    ^38270    ^38280    ^38290    ^38300    ^38310              ^38330    ^38340    ^38350    ^38360    ^38370    ^38380    ^38390              ^38410    ^38420    ^38430    ^38440    ^38450    ^38460    ^38470              ^38490    ^38500    ^38510    ^38520    ^38530    ^38540    ^38550              ^38570    ^38580    ^38590    ^38600    ^38610    ^38620    ^38630              ^38650    ^38660    ^38670    ^38680    ^38690    ^38700    ^38710              ^38730    ^38740    ^38750    ^38760    ^38770    ^38780    ^38790              ^38810    ^38820    ^38830    ^38840    ^38850    ^38860    ^38870              ^38890    ^38900    ^38910    ^38920    ^38930    ^38940    ^38950              ^38970    ^38980    ^38990    ^39000    ^39010    ^39020    ^39030              ^39050    ^39060    ^39070    ^39080    ^39090    ^39100    ^39110              ^39130    ^39140    ^39150    ^39160    ^39170    ^39180    ^39190              ^39210    ^39220    ^39230    ^39240    ^39250    ^39260    ^39270              ^39290    ^39300    ^39310    ^39320    ^39330    ^39340    ^39350              ^39370    ^39380    ^39390    ^39400    ^39410    ^39420    ^39430              ^39450    ^39460    ^39470    ^39480    ^39490    ^39500    ^39510              ^39530    ^39540    ^39550    ^39560    ^39570    ^39580    ^39590              ^39610    ^39620    ^39630    ^39640    ^39650    ^39660    ^39670              ^39690    ^39700    ^39710    ^39720    ^39730    ^39740    ^39750              ^39770    ^39780    ^39790    ^39800    ^39810    ^39820    ^39830              ^39850    ^39860    ^39870    ^39880    ^39890    ^39900    ^39910              ^39930    ^39940    ^39950    ^39960    ^39970    ^39980    ^39990              ^40010    ^40020    ^40030    ^40040    ^40050    ^40060    ^40070              ^40090    ^40100    ^40110    ^40120    ^40130    ^40140    ^40150              ^40170    ^40180    ^40190    ^40200    ^40210    ^40220    ^40230              ^40250    ^40260    ^40270    ^40280    ^40290    ^40300    ^40310              ^40330    ^40340    ^40350    ^40360    ^40370    ^40380    ^40390              ^40410    ^40420    ^40430    ^40440    ^40450    ^40460    ^40470              ^40490    ^40500    ^40510    ^40520    ^40530    ^40540    ^40550              ^40570    ^40580    ^40590    ^40600    ^40610    ^40620    ^40630              ^40650    ^40660    ^40670    ^40680    ^40690    ^40700    ^40710              ^40730    ^40740    ^40750    ^40760    ^40770    ^40780    ^40790              ^40810    ^40820    ^40830    ^40840    ^40850    ^40860    ^40870              ^40890    ^40900    ^40910    ^40920    ^40930    ^40940    ^40950              ^40970    ^40980    ^40990    ^41000    ^41010    ^41020    ^41030              ^41050    ^41060    ^41070    ^41080    ^41090    ^41100    ^41110              ^41130    ^41140    ^41150    ^41160    ^41170    ^41180    ^41190              ^41210    ^41220    ^41230    ^41240    ^41250    ^41260    ^41270              ^41290    ^41300    ^41310    ^41320    ^41330    ^41340    ^41350              ^41370    ^41380    ^41390    ^41400    ^41410    ^41420    ^41430              ^41450    ^41460    ^41470    ^41480    ^41490    ^41500    ^41510              ^41530    ^41540    ^41550    ^41560    ^41570    ^41580    ^41590              ^41610    ^41620    ^41630    ^41640    ^41650    ^41660    ^41670              ^41690    ^41700    ^41710    ^41720    ^41730    ^41740    ^41750              ^41770    ^41780    ^41790    ^41800    ^41810    ^41820    ^41830              ^41850    ^41860    ^41870    ^41880    ^41890    ^41900    ^41910              ^41930    ^41940    ^41950    ^41960    ^41970    ^41980    ^41990              ^42010    ^42020    ^42030    ^42040    ^42050    ^42060    ^42070              ^42090    ^42100    ^42110    ^42120    ^42130    ^42140    ^42150              ^42170    ^42180    ^42190    ^42200    ^42210    ^42220    ^42230              ^42250    ^42260    ^42270    ^42280    ^42290    ^42300    ^42310              ^42330    ^42340    ^42350    ^42360    ^42370    ^42380    ^42390              ^42410    ^42420    ^42430    ^42440    ^42450    ^42460    ^42470              ^42490    ^42500    ^42510    ^42520    ^42530    ^42540    ^42550              ^42570    ^42580    ^42590    ^42600    ^42610    ^42620    ^42630              ^42650    ^42660    ^42670    ^42680    ^42690    ^42700    ^42710              ^42730    ^42740    ^42750    ^42760    ^42770    ^42780    ^42790              ^42810    ^42820    ^42830    ^42840    ^42850    ^42860    ^42870              ^42890    ^42900    ^42910    ^42920    ^42930    ^42940    ^42950              ^42970    ^42980    ^42990    ^43000    ^43010    ^43020    ^43030              ^43050    ^43060    ^43070    ^43080    ^43090    ^43100    ^43110              ^43130    ^43140    ^43150    ^43160    ^43170    ^43180    ^43190              ^43210    ^43220    ^43230    ^43240    ^43250    ^43260    ^43270              ^43290    ^43300    ^43310    ^43320    ^43330    ^43340    ^43350              ^43370    ^43380    ^43390    ^43400    ^43410    ^43420    ^43430              ^43450    ^43460    ^43470    ^43480    ^43490    ^43500    ^43510              ^43530    ^43540    ^43550    ^43560    ^43570    ^43580    ^43590              ^43610    ^43620    ^43630    ^43640    ^43650    ^43660    ^43670              ^43690    ^43700    ^43710    ^43720    ^43730    ^43740    ^43750              ^43770    ^43780    ^43790    ^43800    ^43810    ^43820    ^43830              ^43850    ^43860    ^43870    ^43880    ^43890    ^43900    ^43910              ^43930    ^43940    ^43950    ^43960    ^43970    ^43980    ^43990              ^44010    ^44020    ^44030    ^44040    ^44050    ^44060    ^44070              ^44090    ^44100    ^44110    ^44120    ^44130    ^44140    ^44150              ^44170    ^44180    ^44190    ^44200    ^44210    ^44220    ^44230              ^44250    ^44260    ^44270    ^44280    ^44290    ^44300    ^44310              ^44330    ^44340    ^44350    ^44360    ^44370    ^44380    ^44390              ^44410    ^44420    ^44430    ^44440    ^44450    ^44460    ^44470              ^44490    ^44500    ^44510    ^44520    ^44530    ^44540    ^44550              ^44570    ^44580    ^44590    ^44600    ^44610    ^44620    ^44630              ^44650    ^44660    ^44670    ^44680    ^44690    ^44700    ^44710              ^44730    ^44740    ^44750    ^44760    ^44770    ^44780    ^44790              ^44810    ^44820    ^44830    ^44840    ^44850    ^44860    ^44870              ^44890    ^44900    ^44910    ^44920    ^44930    ^44940    ^44950              ^44970    ^44980    ^44990    ^45000    ^45010    ^45020    ^45030              ^45050    ^45060    ^45070    ^45080    ^45090    ^45100    ^45110              ^45130    ^45140    ^45150    ^45160    ^45170    ^45180    ^45190              ^45210    ^45220    ^45230    ^45240    ^45250    ^45260    ^45270              ^45290    ^45300    ^45310    ^45320    ^45330    ^45340    ^45350              ^45370    ^45380    ^45390    ^45400    ^45410    ^45420    ^45430              ^45450    ^45460    ^45470    ^45480    ^45490    ^45500    ^45510              ^45530    ^45540    ^45550    ^45560    ^45570    ^45580    ^45590              ^45610    ^45620    ^45630    ^45640    ^45650    ^45660    ^45670              ^45690    ^45700    ^45710    ^45720    ^45730    ^45740    ^45750              ^45770    ^45780    ^45790    ^45800    ^45810    ^45820    ^45830              ^45850    ^45860    ^45870    ^45880    ^45890    ^45900    ^45910              ^45930    ^45940    ^45950    ^45960    ^45970    ^45980    ^45990              ^46010    ^46020    ^46030    ^46040    ^46050    ^46060    ^46070              ^46090    ^46100    ^46110    ^46120    ^46130    ^46140    ^46150              ^46170    ^46180    ^46190    ^46200    ^46210    ^46220    ^46230              ^46250    ^46260    ^46270    ^46280    ^46290    ^46300    ^46310              ^46330    ^46340    ^46350    ^46360    ^46370    ^46380    ^46390              ^46410    ^46420    ^46430    ^46440    ^46450    ^46460    ^46470              ^46490    ^46500    ^46510    ^46520    ^46530    ^46540    ^46550              ^46570    ^46580    ^46590    ^46600    ^46610    ^46620    ^46630              ^46650    ^46660    ^46670    ^46680    ^46690    ^46700    ^46710              ^46730    ^46740    ^46750    ^46760    ^46770    ^46780    ^46790              ^46810    ^46820    ^46830    ^46840    ^46850    ^46860    ^46870              ^46890    ^46900    ^46910    ^46920    ^46930    ^46940    ^46950              ^46970    ^46980    ^46990    ^47000    ^47010    ^47020    ^47030              ^47050    ^47060    ^47070    ^47080    ^47090    ^47100    ^47110              ^47130    ^47140    ^47150    ^47160    ^47170    ^47180    ^47190              ^47210    ^47220    ^47230    ^47240    ^47250    ^47260    ^47270              ^47290    ^47300    ^47310    ^47320    ^47330    ^47340    ^47350              ^47370    ^47380    ^47390    ^47400    ^47410    ^47420    ^47430              ^47450    ^47460    ^47470    ^47480    ^47490    ^47500    ^47510              ^47530    ^47540    ^47550    ^47560    ^47570    ^47580    ^47590              ^47610    ^47620    ^47630    ^47640    ^47650    ^47660    ^47670              ^47690    ^47700    ^47710    ^47720    ^47730    ^47740    ^47750              ^47770    ^47780    ^47790    ^47800    ^47810    ^47820    ^47830              ^47850    ^47860    ^47870    ^47880    ^47890    ^47900    ^47910              ^47930    ^47940    ^47950    ^47960    ^47970    ^47980    ^47990              ^48010    ^48020    ^48030    ^48040    ^48050    ^48060    ^48070              ^48090    ^48100    ^48110    ^48120    ^48130    ^48140    ^48150              ^48170    ^48180    ^48190    ^48200    ^48210    ^48220    ^48230              ^48250    ^48260    ^48270    ^48280    ^48290    ^48300    ^48310              ^48330    ^48340    ^48350    ^48360    ^48370    ^48380    ^48390              ^48410    ^48420    ^48430    ^48440    ^48450    ^48460    ^48470              ^48490    ^48500    ^48510    ^48520    ^48530    ^48540    ^48550              ^48570    ^48580    ^48590    ^48600    ^48610    ^48620    ^48630              ^48650    ^48660    ^48670    ^48680    ^48690    ^48700    ^48710              ^48730    ^48740    ^48750    ^48760    ^48770    ^48780    ^48790              ^48810    ^48820    ^48830    ^48840    ^48850    ^48860    ^48870              ^48890    ^48900    ^48910    ^48920    ^48930    ^48940    ^48950              ^48970    ^48980    ^48990    ^49000    ^49010    ^49020    ^49030              ^49050    ^49060    ^49070    ^49080    ^49090    ^49100    ^49110              ^49130    ^49140    ^49150    ^49160    ^49170    ^49180    ^49190              ^49210    ^49220    ^49230    ^49240    ^49250    ^49260    ^49270              ^49290    ^49300    ^49310    ^49320    ^49330    ^49340    ^49350              ^49370    ^49380    ^49390    ^49400    ^49410    ^49420    ^49430              ^49450    ^49460    ^49470    ^49480    ^49490    ^49500    ^49510              ^49530    ^49540    ^49550    ^49560    ^49570    ^49580    ^49590              ^49610    ^49620    ^49630    ^49640    ^49650    ^49660    ^49670              ^49690    ^49700    ^49710    ^49720    ^49730    ^49740    ^49750              ^49770    ^49780    ^49790    ^49800    ^49810    ^49820    ^49830              ^49850    ^49860    ^49870    ^49880    ^49890    ^49900    ^49910              ^49930    ^49940    ^49950    ^49960    ^49970    ^49980    ^49990              ^50010    ^50020    ^50030    ^50040    ^50050    ^50060    ^50070              ^50090    ^50100    ^50110    ^50120    ^50130    ^50140    ^50150              ^50170    ^50180    ^50190    ^50200    ^50210    ^50220    ^50230              ^50250    ^50260    ^50270    ^50280    ^50290    ^50300    ^50310              ^50330    ^50340    ^50350    ^50360    ^50370    ^50380    ^50390              ^50410    ^50420    ^50430    ^50440    ^50450    ^50460    ^50470              ^50490    ^50500    ^50510    ^50520    ^50530    ^50540    ^50550              ^50570    ^50580    ^50590    ^50600    ^50610    ^50620    ^50630              ^50650    ^50660    ^50670    ^50680    ^50690    ^50700    ^50710              ^50730    ^50740    ^50750    ^50760    ^50770    ^50780    ^50790              ^50810    ^50820    ^50830    ^50840    ^50850    ^50860    ^50870              ^50890    ^50900    ^50910    ^50920    ^50930    ^50940    ^50950              ^50970    ^50980    ^50990    ^51000    ^51010    ^51020    ^51030              ^51050    ^51060    ^51070    ^51080    ^51090    ^51100    ^51110              ^51130    ^51140    ^51150    ^51160    ^51170    ^51180    ^51190              ^51210    ^51220    ^51230    ^51240    ^51250    ^51260    ^51270              ^51290    ^51300    ^51310    ^51320    ^51330    ^51340    ^51350              ^51370    ^51380    ^51390    ^51400    ^51410    ^51420    ^51430              ^51450    ^51460    ^51470    ^51480    ^51490    ^51500    ^51510              ^51530    ^51540    ^51550    ^51560    ^51570    ^51580    ^51590              ^51610    ^51620    ^51630    ^51640    ^51650    ^51660    ^51670              ^51690    ^51700    ^51710    ^51720    ^51730    ^51740    ^51750              ^51770    ^51780    ^51790    ^51800    ^51810    ^51820    ^51830              ^51850    ^51860    ^51870    ^51880    ^51890    ^51900    ^51910              ^51930    ^51940    ^51950    ^51960    ^51970    ^51980    ^51990              ^52010    ^52020    ^52030    ^52040    ^52050    ^52060    ^52070              ^52090    ^52100    ^52110    ^52120    ^52130    ^52140    ^52150              ^52170    ^52180    ^52190    ^52200    ^52210    ^52220    ^52230              ^52250    ^52260    ^52270    ^52280    ^52290    ^52300    ^52310              ^52330    ^52340    ^52350    ^52360    ^52370    ^52380    ^52390              ^52410    ^52420    ^52430    ^52440    ^52450    ^52460    ^52470              ^52490    ^52500    ^52510    ^52520    ^52530    ^52540    ^52550              ^52570    ^52580    ^52590    ^52600    ^52610    ^52620    ^52630              ^52650    ^52660    ^52670    ^52680    ^52690    ^52700    ^52710              ^52730    ^52740    ^52750    ^52760    ^52770    ^52780    ^52790              ^52810    ^52820    ^52830    ^52840    ^52850    ^52860    ^52870              ^52890    ^52900    ^52910    ^52920    ^52930    ^52940    ^52950              ^52970    ^52980    ^52990    ^53000    ^53010    ^53020    ^53030              ^53050    ^53060    ^53070    ^53080    ^53090    ^53100    ^53110              ^53130    ^53140    ^53150    ^53160    ^53170    ^53180    ^53190              ^53210    ^53220    ^53230    ^53240    ^53250    ^53260    ^53270              ^53290    ^53300    ^53310    ^53320    ^53330    ^53340    ^53350              ^53370    ^53380    ^53390    ^53400    ^53410    ^53420    ^53430              ^53450    ^53460    ^53470    ^53480    ^53490    ^53500    ^53510              ^53530    ^53540    ^53550    ^53560    ^53570    ^53580    ^53590              ^53610    ^53620    ^53630    ^53640    ^53650    ^53660    ^53670              ^53690    ^53700    ^53710    ^53720    ^53730    ^53740    ^53750              ^53770    ^53780    ^53790    ^53800    ^53810    ^53820    ^53830              ^53850    ^53860    ^53870    ^53880    ^53890    ^53900    ^53910              ^53930    ^53940    ^53950    ^53960    ^53970    ^53980    ^53990              ^54010    ^54020    ^54030    ^54040    ^54050    ^54060    ^54070              ^54090    ^54100    ^54110    ^54120    ^54130    ^54140    ^54150              ^54170    ^54180    ^54190    ^54200    ^54210    ^54220    ^54230              ^54250    ^54260    ^54270    ^54280    ^54290    ^54300    ^54310              ^54330    ^54340    ^54350    ^54360    ^54370    ^54380    ^54390              ^54410    ^54420    ^54430    ^54440    ^54450    ^54460    ^54470              ^54490    ^54500    ^54510    ^54520    ^54530    ^54540    ^54550              ^54570    ^54580    ^54590    ^54600    ^54610    ^54620    ^54630              ^54650    ^54660    ^54670    ^54680    ^54690    ^54700    ^54710              ^54730    ^54740    ^54750    ^54760    ^54770    ^54780    ^54790              ^54810    ^54820    ^54830    ^54840    ^54850    ^54860    ^54870              ^54890    ^54900    ^54910    ^54920    ^54930    ^54940    ^54950              ^54970    ^54980    ^54990    ^55000    ^55010    ^55020    ^55030              ^55050    ^55060    ^55070    ^55080    ^55090    ^55100    ^55110              ^55130    ^55140    ^55150    ^55160    ^55170    ^55180    ^55190              ^55210    ^55220    ^55230    ^55240    ^55250    ^55260    ^55270              ^55290    ^55300    ^55310    ^55320    ^55330    ^55340    ^55350              ^55370    ^55380    ^55390    ^55400    ^55410    ^55420    ^55430              ^55450    ^55460    ^55470    ^55480    ^55490    ^55500    ^55510              ^55530    ^55540    ^55550    ^55560    ^55570    ^55580    ^55590              ^55610    ^55620    ^55630    ^55640    ^55650    ^55660    ^55670              ^55690    ^55700    ^55710    ^55720    ^55730    ^55740    ^55750              ^55770    ^55780    ^55790    ^55800    ^55810    ^55820    ^55830              ^55850    ^55860    ^55870    ^55880    ^55890    ^55900    ^55910              ^55930    ^55940    ^55950    ^55960    ^55970    ^55980    ^55990              ^56010    ^56020    ^56030    ^56040    ^56050    ^56060    ^56070              ^56090    ^56100    ^56110    ^56120    ^56130    ^56140    ^56150              ^56170    ^56180    ^56190    ^56200    ^56210    ^56220    ^56230              ^56250    ^56260    ^56270    ^56280    ^56290    ^56300    ^56310              ^56330    ^56340    ^56350    ^56360    ^56370    ^56380    ^56390              ^56410    ^56420    ^56430    ^56440    ^56450    ^56460    ^56470              ^56490    ^56500    ^56510    ^56520    ^56530    ^56540    ^56550              ^56570    ^56580    ^56590    ^56600    ^56610    ^56620    ^56630              ^56650    ^56660    ^56670    ^56680    ^56690    ^56700    ^56710              ^56730    ^56740    ^56750    ^56760    ^56770    ^56780    ^56790              ^56810    ^56820    ^56830    ^56840    ^56850    ^56860    ^56870              ^56890    ^56900    ^56910    ^56920    ^56930    ^56940    ^56950              ^56970    ^56980    ^56990    ^57000    ^57010    ^57020    ^57030              ^57050    ^57060    ^57070    ^57080    ^57090    ^57100    ^57110              ^57130    ^57140    ^57150    ^57160    ^57170    ^57180    ^57190              ^57210    ^57220    ^57230    ^57240    ^57250    ^57260    ^57270              ^57290    ^57300    ^57310    ^57320    ^57330    ^57340    ^57350              ^57370    ^57380    ^57390    ^57400    ^57410    ^57420    ^57430              ^57450    ^57460    ^57470    ^57480    ^57490    ^57500    ^57510              ^57530    ^57540    ^57550    ^57560    ^57570    ^57580    ^57590              ^57610    ^57620    ^57630    ^57640    ^57650    ^57660    ^57670              ^57690    ^57700    ^57710    ^57720    ^57730    ^57740    ^57750              ^57770    ^57780    ^57790    ^57800    ^57810    ^57820    ^57830              ^57850    ^57860    ^57870    ^57880    ^57890    ^57900    ^57910              ^57930    ^57940    ^57950    ^57960    ^57970    ^57980    ^57990              ^58010    ^58020    ^58030    ^58040    ^58050    ^58060    ^58070              ^58090    ^58100    ^58110    ^58120    ^58130    ^58140    ^58150              ^58170    ^58180    ^58190    ^58200    ^58210    ^58220    ^58230              ^58250    ^58260    ^58270    ^58280    ^58290    ^58300    ^58310              ^58330    ^58340    ^58350    ^58360    ^58370    ^58380    ^58390              ^58410    ^58420    ^58430    ^58440    ^58450    ^58460    ^58470              ^58490    ^58500    ^58510    ^58520    ^58530    ^58540    ^58550              ^58570    ^58580    ^58590    ^58600    ^58610    ^58620    ^58630              ^58650    ^58660    ^58670    ^58680    ^58690    ^58700    ^58710              ^58730    ^58740    ^58750    ^58760    ^58770    ^58780    ^58790              ^58810    ^58820    ^58830    ^58840    ^58850    ^58860    ^58870              ^58890    ^58900    ^58910    ^58920    ^58930    ^58940    ^58950              ^58970    ^58980    ^58990    ^59000    ^59010    ^59020    ^59030              ^59050    ^59060    ^59070    ^59080    ^59090    ^59100    ^59110              ^59130    ^59140    ^59150    ^59160    ^59170    ^59180    ^59190              ^59210    ^59220    ^59230    ^59240    ^59250    ^59260    ^59270              ^59290    ^59300    ^59310    ^59320    ^59330    ^59340    ^59350              ^59370    ^59380    ^59390    ^59400    ^59410    ^59420    ^59430              ^59450    ^59460    ^59470    ^59480    ^59490    ^59500    ^59510              ^59530    ^59540    ^59550    ^59560    ^59570    ^59580    ^59590              ^59610    ^59620    ^59630    ^59640    ^59650    ^59660    ^59670              ^59690    ^59700    ^59710    ^59720    ^59730    ^59740    ^59750              ^59770    ^59780    ^59790    ^59800    ^59810    ^59820    ^59830              ^59850    ^59860    ^59870    ^59880    ^59890    ^59900    ^59910              ^59930    ^59940    ^59950    ^59960    ^59970    ^59980    ^59990              ^60010    ^60020    ^60030    ^60040    ^60050    ^60060    ^60070              ^60090    ^60100    ^60110    ^60120    ^60130    ^60140    ^60150              ^60170    ^60180    ^60190    ^60200    ^60210    ^60220    ^60230              ^60250    ^60260    ^60270    ^60280    ^60290    ^60300    ^60310              ^60330    ^60340    ^60350    ^60360    ^60370    ^60380    ^60390              ^60410    ^60420    ^60430    ^60440    ^60450    ^60460    ^60470              ^60490    ^60500    ^60510    ^60520    ^60530    ^60540    ^60550              ^60570    ^60580    ^60590    ^60600    ^60610    ^60620    ^60630              ^60650    ^60660    ^60670    ^60680    ^60690    ^60700    ^60710              ^60730    ^60740    ^60750    ^60760    ^60770    ^60780    ^60790              ^60810    ^60820    ^60830    ^60840    ^60850    ^60860    ^60870              ^60890    ^60900    ^60910    ^60920    ^60930    ^60940    ^60950              ^60970    ^60980    ^60990    ^61000    ^61010    ^61020    ^61030              ^61050    ^61060    ^61070    ^61080    ^61090    ^61100    ^61110              ^61130    ^61140    ^61150    ^61160    ^61170    ^61180    ^61190              ^61210    ^61220    ^61230    ^61240    ^61250    ^61260    ^61270              ^61290    ^61300    ^61310    ^61320    ^61330    ^61340    ^61350              ^61370    ^61380    ^61390    ^61400    ^61410    ^61420    ^61430              ^61450    ^61460    ^61470    ^61480    ^61490    ^61500    ^61510              ^61530    ^61540    ^61550    ^61560    ^61570    ^61580    ^61590              ^61610    ^61620    ^61630    ^61640    ^61650    ^61660    ^61670              ^61690    ^61700    ^61710    ^61720    ^61730    ^61740    ^61750              ^61770    ^61780    ^61790    ^61800    ^61810    ^61820    ^61830              ^61850    ^61860    ^61870    ^61880    ^61890    ^61900    ^61910              ^61930    ^61940    ^61950    ^61960    ^61970    ^61980    ^61990              ^62010    ^62020    ^62030    ^62040    ^62050    ^62060    ^62070              ^62090    ^62100    ^62110    ^62120    ^62130    ^62140    ^62150              ^62170    ^62180    ^62190    ^62200    ^62210    ^62220    ^62230              ^62250    ^62260    ^62270    ^62280    ^62290    ^62300    ^62310              ^62330    ^62340    ^62350    ^62360    ^62370    ^62380    ^62390              ^62410    ^62420    ^62430    ^62440    ^62450    ^62460    ^62470              ^62490    ^62500    ^62510    ^62520    ^62530    ^62540    ^62550              ^62570    ^62580    ^62590    ^62600    ^62610    ^62620    ^62630              ^62650    ^62660    ^62670    ^62680    ^62690    ^62700    ^62710              ^62730    ^62740    ^62750    ^62760    ^62770    ^62780    ^62790              ^62810    ^62820    ^62830    ^62840    ^62850    ^62860    ^62870              ^62890    ^62900    ^62910    ^62920    ^62930    ^62940    ^62950              ^62970    ^62980    ^62990    ^63000    ^63010    ^63020    ^63030              ^63050    ^63060    ^63070    ^63080    ^63090    ^63100    ^63110              ^63130    ^63140    ^63150    ^63160    ^63170    ^63180    ^63190              ^63210    ^63220    ^63230    ^63240    ^63250    ^63260    ^63270              ^63290    ^63300    ^63310    ^63320    ^63330    ^63340    ^63350              ^63370    ^63380    ^63390    ^63400    ^63410    ^63420    ^63430              ^63450    ^63460    ^63470    ^63480    ^63490    ^63500    ^63510              ^63530    ^63540    ^63550    ^63560    ^63570    ^63580    ^63590              ^63610    ^63620    ^63630    ^63640    ^63650    ^63660    ^63670              ^63690    ^63700    ^63710    ^63720    ^63730    ^63740    ^63750              ^63770    ^63780    ^63790    ^63800    ^63810    ^63820    ^63830              ^63850    ^63860    ^63870    ^63880    ^63890    ^63900    ^63910              ^63930    ^63940    ^63950    ^63960    ^63970    ^63980    ^63990              ^64010    ^64020    ^64030    ^64040    ^64050    ^64060    ^64070              ^64090    ^64100    ^64110    ^64120    ^64130    ^64140    ^64150              ^64170    ^64180    ^64190    ^64200    ^64210    ^64220    ^64230              ^64250    ^64260    ^64270    ^64280    ^64290    ^64300    ^64310              ^64330    ^64340    ^64350    ^64360    ^64370    ^64380    ^64390              ^64410    ^64420    ^64430    ^64440    ^64450    ^64460    ^64470              ^64490    ^64500    ^64510    ^64520    ^64530    ^64540    ^64550              ^64570    ^64580    ^64590    ^64600    ^64610    ^64620    ^64630              ^64650    ^64660    ^64670    ^64680    ^64690    ^64700    ^64710              ^64730    ^64740    ^64750    ^64760    ^64770    ^64780    ^64790              ^64810    ^64820    ^64830    ^64840    ^64850    ^64860    ^64870              ^64890    ^64900    ^64910    ^64920    ^64930    ^64940    ^64950              ^64970    ^64980    ^64990    ^65000    ^65010    ^65020    ^65030              ^65050    ^65060    ^65070    ^65080    ^65090    ^65100    ^65110              ^65130    ^65140    ^65150    ^65160    ^65170    ^65180    ^65190              ^65210    ^65220    ^65230    ^65240    ^65250    ^65260    ^65270              ^65290    ^65300    ^65310    ^65320    ^65330    ^65340    ^65350              ^65370    ^65380    ^65390    ^65400    ^65410    ^65420    ^65430              ^65450    ^65460    ^65470    ^65480    ^65490    ^65500    ^65510              ^65530    ^65540    ^65550    ^65560    ^65570    ^65580    ^65590              ^65610    ^65620    ^65630    ^65640    ^65650    ^65660    ^65670              ^65690    ^65700    ^65710    ^65720    ^65730    ^65740    ^65750              ^65770    ^65780    ^65790    ^65800    ^65810    ^65820    ^65830              ^65850    ^65860    ^65870    ^65880    ^65890    ^65900    ^65910              ^65930    ^65940    ^65950    ^65960    ^65970    ^65980    ^65990              ^66010    ^66020    ^66030    ^66040    ^66050    ^66060    ^66070              ^66090    ^66100    ^66110    ^66120    ^66130    ^66140    ^66150              ^66170    ^66180    ^66190    ^66200    ^66210    ^66220    ^66230              ^66250    ^66260    ^66270    ^66280    ^66290    ^66300    ^66310              ^66330    ^66340    ^66350    ^66360    ^66370    ^66380    ^66390              ^66410    ^66420    ^66430    ^66440    ^66450    ^66460    ^66470              ^66490    ^66500    ^66510    ^66520    ^66530    ^66540    ^66550              ^66570    ^66580    ^66590    ^66600    ^66610    ^66620    ^66630              ^66650    ^66660    ^66670    ^66680    ^66690    ^66700    ^66710              ^66730    ^66740    ^66750    ^66760    ^66770    ^66780    ^66790              ^66810    ^66820    ^66830    ^66840    ^66850    ^66860    ^66870              ^66890    ^66900    ^66910    ^66920    ^66930    ^66940    ^66950              ^66970    ^66980    ^66990    ^67000    ^67010    ^67020    ^67030              ^67050    ^67060    ^67070    ^67080    ^67090    ^67100    ^67110              ^67130    ^67140    ^67150    ^67160    ^67170    ^67180    ^67190              ^67210    ^67220    ^67230    ^67240    ^67250    ^67260    ^67270              ^67290    ^67300    ^67310    ^67320    ^67330    ^67340    ^67350              ^67370    ^67380    ^67390    ^67400    ^67410    ^67420    ^67430              ^67450    ^67460    ^67470    ^67480    ^67490    ^67500    ^67510              ^67530    ^67540    ^67550    ^67560    ^67570    ^67580    ^67590              ^67610    ^67620    ^67630    ^67640    ^67650    ^67660    ^67670              ^67690    ^67700    ^67710    ^67720    ^67730    ^67740    ^67750              ^67770    ^67780    ^67790    ^67800    ^67810    ^67820    ^67830              ^67850    ^67860    ^67870    ^67880    ^67890    ^67900    ^67910              ^67930    ^67940    ^67950    ^67960    ^67970    ^67980    ^67990              ^68010    ^68020    ^68030    ^68040    ^68050    ^68060    ^68070              ^68090    ^68100    ^68110    ^68120    ^68130    ^68140    ^68150              ^68170    ^68180    ^68190    ^68200    ^68210    ^68220    ^68230              ^68250    ^68260    ^68270    ^68280    ^68290    ^68300    ^68310              ^68330    ^68340    ^68350    ^68360    ^68370    ^68380    ^68390              ^68410    ^68420    ^68430    ^68440    ^68450    ^68460    ^68470              ^68490    ^68500    ^68510    ^68520    ^68530    ^68540    ^68550              ^68570    ^68580    ^68590    ^68600    ^68610    ^68620    ^68630              ^68650    ^68660    ^68670    ^68680    ^68690    ^68700    ^68710              ^68730    ^68740    ^68750    ^68760    ^68770    ^68780    ^68790              ^68810    ^68820    ^68830    ^68840    ^68850    ^68860    ^68870              ^68890    ^68900    ^68910    ^68920    ^68930    ^68940    ^68950              ^68970    ^68980    ^68990    ^69000    ^69010    ^69020    ^69030              ^69050    ^69060    ^69070    ^69080    ^69090    ^69100    ^69110              ^69130    ^69140    ^69150    ^69160    ^69170    ^69180    ^69190              ^69210    ^69220    ^69230    ^69240    ^69250    ^69260    ^69270              ^69290    ^69300    ^69310    ^69320    ^69330    ^69340    ^69350              ^69370    ^69380    ^69390    ^69400    ^69410    ^69420    ^69430              ^69450    ^69460    ^69470    ^69480    ^69490    ^69500    ^69510              ^69530    ^69540    ^69550    ^69560    ^69570    ^69580    ^69590              ^69610    ^69620    ^69630    ^69640    ^69650    ^69660    ^69670              ^69690    ^69700    ^69710    ^69720    ^69730    ^69740    ^69750              ^69770    ^69780    ^69790    ^69800    ^69810    ^69820    ^69830              ^69850    ^69860    ^69870    ^69880    ^69890    ^69900    ^69910              ^69930    ^69940    ^69950    ^69960    ^69970    ^69980    ^69990              ^70010    ^70020    ^70030    ^70040    ^70050    ^70060    ^70070              ^70090    ^70100    ^70110    ^70120    ^70130    ^70140    ^70150              ^70170    ^70180    ^70190    ^70200    ^70210    ^70220    ^70230              ^70250    ^70260    ^70270    ^70280    ^70290    ^70300    ^70310              ^70330    ^70340    ^70350    ^70360    ^70370    ^70380    ^70390              ^70410    ^70420    ^70430    ^70440    ^70450    ^70460    ^70470              ^70490    ^70500    ^70510    ^70520    ^70530    ^70540    ^70550              ^70570    ^70580    ^70590    ^70600    ^70610    ^70620    ^70630              ^70650    ^70660    ^70670    ^70680    ^70690    ^70700    ^70710              ^70730    ^70740    ^70750    ^70760    ^70770    ^70780    ^70790              ^70810    ^70820    ^70830    ^70840    ^70850    ^70860    ^70870              ^70890    ^70900    ^70910    ^70920    ^70930    ^70940    ^70950              ^70970    ^70980    ^70990    ^71000    ^71010    ^71020    ^71030              ^71050    ^71060    ^71070    ^71080    ^71090    ^71100    ^71110              ^71130    ^71140    ^71150    ^71160    ^71170    ^71180    ^71190              ^71210    ^71220    ^71230    ^71240    ^71250    ^71260    ^71270              ^71290    ^71300    ^71310    ^71320    ^71330    ^71340    ^71350              ^71370    ^71380    ^71390    ^71400    ^71410    ^71420    ^71430              ^71450    ^71460    ^71470    ^71480    ^71490    ^71500    ^71510              ^71530    ^71540    ^71550    ^71560    ^71570    ^71580    ^71590              ^71610    ^71620    ^71630    ^71640    ^71650    ^71660    ^71670              ^71690    ^71700    ^71710    ^71720    ^71730    ^71740    ^71750              ^71770    ^71780    ^71790    ^71800    ^71810    ^71820    ^71830              ^71850    ^71860    ^71870    ^71880    ^71890    ^71900    ^71910              ^71930    ^71940    ^71950    ^71960    ^71970    ^71980    ^71990              ^72010    ^72020    ^72030    ^72040    ^72050    ^72060    ^72070              ^72090    ^72100    ^72110    ^72120    ^72130    ^72140    ^72150              ^72170    ^72180    ^72190    ^72200    ^72210    ^72220    ^72230              ^72250    ^72260    ^72270    ^72280    ^72290    ^72300    ^72310              ^72330    ^72340    ^72350    ^72360    ^72370    ^72380    ^72390              ^72410    ^72420    ^72430    ^72440    ^72450    ^72460    ^72470              ^72490    ^72500    ^72510    ^72520    ^72530    ^72540    ^72550              ^72570    ^72580    ^72590    ^72600    ^72610    ^72620    ^72630              ^72650    ^72660    ^72670    ^72680    ^72690    ^72700    ^72710              ^72730    ^72740    ^72750    ^72760    ^72770    ^72780    ^72790              ^72810    ^72820    ^72830    ^72840    ^72850    ^72860    ^72870              ^72890    ^72900    ^72910    ^72920    ^72930    ^72940    ^72950              ^72970    ^72980    ^72990    ^73000    ^73010    ^73020    ^73030              ^73050    ^73060    ^73070    ^73080    ^73090    ^73100    ^73110              ^73130    ^73140    ^73150    ^73160    ^73170    ^73180    ^73190              ^73210    ^73220    ^73230    ^73240    ^73250    ^73260    ^73270              ^73290    ^73300    ^73310    ^73320    ^73330    ^73340    ^73350              ^73370    ^73380    ^73390    ^73400    ^73410    ^73420    ^73430              ^73450    ^73460    ^73470    ^73480    ^73490    ^73500    ^73510              ^73530    ^73540    ^73550    ^73560    ^73570    ^73580    ^73590              ^73610    ^73620    ^73630    ^73640    ^73650    ^73660    ^73670              ^73690    ^73700    ^73710    ^73720    ^73730    ^73740    ^73750              ^73770    ^73780    ^73790    ^73800    ^73810    ^73820    ^73830              ^73850    ^73860    ^73870    ^73880    ^73890    ^73900    ^73910              ^73930    ^73940    ^73950    ^73960    ^73970    ^73980    ^73990              ^74010    ^74020    ^74030    ^74040    ^74050    ^74060    ^74070              ^74090    ^74100    ^74110    ^74120    ^74130    ^74140    ^74150              ^74170    ^74180    ^74190    ^74200    ^74210    ^74220    ^74230              ^74250    ^74260    ^74270    ^74280    ^74290    ^74300    ^74310              ^74330    ^74340    ^74350    ^74360    ^74370    ^74380    ^74390              ^74410    ^74420    ^74430    ^74440    ^74450    ^74460    ^74470              ^74490    ^74500    ^74510    ^74520    ^74530    ^74540    ^74550              ^74570    ^74580    ^74590    ^74600    ^74610    ^74620    ^74630              ^74650    ^74660    ^74670    ^74680    ^74690    ^74700    ^74710              ^74730    ^74740    ^74750    ^74760    ^74770    ^74780    ^74790              ^74810    ^74820    ^74830    ^74840    ^74850    ^74860    ^74870              ^74890    ^74900    ^74910    ^74920    ^74930    ^74940    ^74950              ^74970    ^74980    ^74990    ^75000    ^75010    ^75020    ^75030              ^75050    ^75060    ^75070    ^75080    ^75090    ^75100    ^75110              ^75130    ^75140    ^75150    ^75160    ^75170    ^75180    ^75190              ^75210    ^75220    ^75230    ^75240    ^75250    ^75260    ^75270              ^75290    ^75300    ^75310    ^75320    ^75330    ^75340    ^75350              ^75370    ^75380    ^75390    ^75400    ^75410    ^75420    ^75430              ^75450    ^75460    ^75470    ^75480    ^75490    ^75500    ^75510              ^75530    ^75540    ^75550    ^75560    ^75570    ^75580    ^75590              ^75610    ^75620    ^75630    ^75640    ^75650    ^75660    ^75670              ^75690    ^75700    ^75710    ^75720    ^75730    ^75740    ^75750              ^75770    ^75780    ^75790    ^75800    ^75810    ^75820    ^75830              ^75850    ^75860    ^75870    ^75880    ^75890    ^75900    ^75910              ^75930    ^75940    ^75950    ^75960    ^75970    ^75980    ^75990              ^76010    ^76020    ^76030    ^76040    ^76050    ^76060    ^76070              ^76090    ^76100    ^76110    ^76120    ^76130    ^76140    ^76150              ^76170    ^76180    ^76190    ^76200    ^76210    ^76220    ^76230              ^76250    ^76260    ^76270    ^76280    ^76290    ^76300    ^76310              ^76330    ^76340    ^76350    ^76360    ^76370    ^76380    ^76390              ^76410    ^76420    ^76430    ^76440    ^76450    ^76460    ^76470              ^76490    ^76500    ^76510    ^76520    ^76530    ^76540    ^76550              ^76570    ^76580    ^76590    ^76600    ^76610    ^76620    ^76630              ^76650    ^76660    ^76670    ^76680    ^76690    ^76700    ^76710              ^76730    ^76740    ^76750    ^76760    ^76770    ^76780    ^76790              ^76810    ^76820    ^76830    ^76840    ^76850    ^76860    ^76870              ^76890    ^76900    ^76910    ^76920    ^76930    ^76940    ^76950              ^76970    ^76980    ^76990    ^77000    ^77010    ^77020    ^77030              ^77050    ^77060    ^77070    ^77080    ^77090    ^77100    ^77110              ^77130    ^77140    ^77150    ^77160    ^77170    ^77180    ^77190              ^77210    ^77220    ^77230    ^77240    ^77250    ^77260    ^77270              ^77290    ^77300    ^77310    ^77320    ^77330    ^77340    ^77350              ^77370    ^77380    ^77390    ^77400    ^77410    ^77420    ^77430              ^77450    ^77460    ^77470    ^77480    ^77490    ^77500    ^77510              ^77530    ^77540    ^77550    ^77560    ^77570    ^77580    ^77590              ^77610    ^77620    ^77630    ^77640    ^77650    ^77660    ^77670              ^77690    ^77700    ^77710    ^77720    ^77730    ^77740    ^77750              ^77770    ^77780    ^77790    ^77800    ^77810    ^77820    ^77830              ^77850    ^77860    ^77870    ^77880    ^77890    ^77900    ^77910              ^77930    ^77940    ^77950    ^77960    ^77970    ^77980    ^77990              ^78010    ^78020    ^78030    ^78040    ^78050    ^78060    ^78070              ^78090    ^78100    ^78110    ^78120    ^78130    ^78140    ^78150              ^78170    ^78180    ^78190    ^78200    ^78210    ^78220    ^78230              ^78250    ^78260    ^78270    ^78280    ^78290    ^78300    ^78310              ^78330    ^78340    ^78350    ^78360    ^78370    ^78380    ^78390              ^78410    ^78420    ^78430    ^78440    ^78450    ^78460    ^78470              ^78490    ^78500    ^78510    ^78520    ^78530    ^78540    ^78550              ^78570    ^78580    ^78590    ^78600    ^78610    ^78620    ^78630              ^78650    ^78660    ^78670    ^78680    ^78690    ^78700    ^78710              ^78730    ^78740    ^78750    ^78760    ^78770    ^78780    ^78790              ^78810    ^78820    ^78830    ^78840    ^78850    ^78860    ^78870              ^78890    ^78900    ^78910    ^78920    ^78930    ^78940    ^78950              ^78970    ^78980    ^78990    ^79000    ^79010    ^79020    ^79030              ^79050    ^79060    ^79070    ^79080    ^79090    ^79100    ^79110              ^79130    ^79140    ^79150    ^79160    ^79170    ^79180    ^79190              ^79210    ^79220    ^79230    ^79240    ^79250    ^79260    ^79270              ^79290    ^79300    ^79310    ^79320    ^79330    ^79340    ^79350              ^79370    ^79380    ^79390    ^79400    ^79410    ^79420    ^79430              ^79450    ^79460    ^79470    ^79480    ^79490    ^79500    ^79510              ^79530    ^79540    ^79550    ^79560    ^79570    ^79580    ^79590              ^79610    ^79620    ^79630    ^79640    ^79650    ^79660    ^79670              ^79690    ^79700    ^79710    ^79720    ^79730    ^79740    ^79750              ^79770    ^79780    ^79790    ^79800    ^79810    ^79820    ^79830              ^79850    ^79860    ^79870    ^79880    ^79890    ^79900    ^79910              ^79930    ^79940    ^79950    ^79960    ^79970    ^79980    ^79990              ^80010    ^80020    ^80030    ^80040    ^80050    ^80060    ^80070              ^80090    ^80100    ^80110    ^80120    ^80130    ^80140    ^80150              ^80170    ^80180    ^80190    ^80200    ^80210    ^80220    ^80230              ^80250    ^80260    ^80270    ^80280    ^80290    ^80300    ^80310              ^80330    ^80340    ^80350    ^80360    ^80370    ^80380    ^80390              ^80410    ^80420    ^80430    ^80440    ^80450    ^80460    ^80470              ^80490    ^80500    ^80510    ^80520    ^80530    ^80540    ^80550              ^80570    ^80580    ^80590    ^80600    ^80610    ^80620    ^80630              ^80650    ^80660    ^80670    ^80680    ^80690    ^80700    ^80710              ^80730    ^80740    ^80750    ^80760    ^80770    ^80780    ^80790              ^80810    ^80820    ^80830    ^80840    ^80850    ^80860    ^80870              ^80890    ^80900    ^80910    ^80920    ^80930    ^80940    ^80950              ^80970    ^80980    ^80990    ^81000    ^81010    ^81020    ^81030              ^81050    ^81060    ^81070    ^81080    ^81090    ^81100    ^81110              ^81130    ^81140    ^81150    ^81160    ^81170    ^81180    ^81190              ^81210    ^81220    ^81230    ^81240    ^81250    ^81260    ^81270              ^81290    ^81300    ^81310    ^81320    ^81330    ^81340    ^81350              ^81370    ^81380    ^81390    ^81400    ^81410    ^81420    ^81430              ^81450    ^81460    ^81470    ^81480    ^81490    ^81500    ^81510              ^81530    ^81540    ^81550    ^81560    ^81570    ^81580    ^81590              ^81610    ^81620    ^81630    ^81640    ^81650    ^81660    ^81670              ^81690    ^81700    ^81710    ^81720    ^81730    ^81740    ^81750              ^81770    ^81780    ^81790    ^81800    ^81810    ^81820    ^81830              ^81850    ^81860    ^81870    ^81880    ^81890    ^81900    ^81910              ^81930    ^81940    ^81950    ^81960    ^81970    ^81980    ^81990              ^82010    ^82020    ^82030    ^82040    ^82050    ^82060    ^82070              ^82090    ^82100    ^82110    ^82120    ^82130    ^82140    ^82150              ^82170    ^82180    ^82190    ^82200    ^82210    ^82220    ^82230              ^82250    ^82260    ^82270    ^82280    ^82290    ^82300    ^82310              ^82330    ^82340    ^82350    ^82360    ^82370    ^82380    ^82390              ^82410    ^82420    ^82430    ^82440    ^82450    ^82460    ^82470              ^82490    ^82500    ^82510    ^82520    ^82530    ^82540    ^82550              ^82570    ^82580    ^82590    ^82600    ^82610    ^82620    ^82630              ^82650    ^82660    ^82670    ^82680    ^82690    ^82700    ^82710              ^82730    ^82740    ^82750    ^82760    ^82770    ^82780    ^82790              ^82810    ^82820    ^82830    ^82840    ^82850    ^82860    ^82870              ^82890    ^82900    ^82910    ^82920    ^82930    ^82940    ^82950              ^82970    ^82980    ^82990    ^83000    ^83010    ^83020    ^83030              ^83050    ^83060    ^83070    ^83080    ^83090    ^83100    ^83110              ^83130    ^83140    ^83150    ^83160    ^83170    ^83180    ^83190              ^83210    ^83220    ^83230    ^83240    ^83250    ^83260    ^83270              ^83290    ^83300    ^83310    ^83320    ^83330    ^83340    ^83350              ^83370    ^83380    ^83390    ^83400    ^83410    ^83420    ^83430              ^83450    ^83460    ^83470    ^83480    ^83490    ^83500    ^83510              ^83530    ^83540    ^83550    ^83560    ^83570    ^83580    ^83590              ^83610    ^83620    ^83630    ^83640    ^83650    ^83660    ^83670              ^83690    ^83700    ^83710    ^83720    ^83730    ^83740    ^83750              ^83770    ^83780    ^83790    ^83800    ^83810    ^83820    ^83830              ^83850    ^83860    ^83870    ^83880    ^83890    ^83900    ^83910              ^83930    ^83940    ^83950    ^83960    ^83970    ^83980    ^83990              ^84010    ^84020    ^84030    ^84040    ^84050    ^84060    ^84070              ^84090    ^84100    ^84110    ^84120    ^84130    ^84140    ^84150              ^84170    ^84180    ^84190    ^84200    ^84210    ^84220    ^84230              ^84250    ^84260    ^84270    ^84280    ^84290    ^84300    ^84310              ^84330    ^84340    ^84350    ^84360    ^84370    ^84380    ^84390              ^84410    ^84420    ^84430    ^84440    ^84450    ^84460    ^84470              ^84490    ^84500    ^84510    ^84520    ^84530    ^84540    ^84550              ^84570    ^84580    ^84590    ^84600    ^84610    ^84620    ^84630              ^84650    ^84660    ^84670    ^84680    ^84690    ^84700    ^84710              ^84730    ^84740    ^84750    ^84760    ^84770    ^84780    ^84790              ^84810    ^84820    ^84830    ^84840    ^84850    ^84860    ^84870              ^84890    ^84900    ^84910    ^84920    ^84930    ^84940    ^84950              ^84970    ^84980    ^84990    ^85000    ^85010    ^85020    ^85030              ^85050    ^85060    ^85070    ^85080    ^85090    ^85100    ^85110              ^85130    ^85140    ^85150    ^85160    ^85170    ^85180    ^85190              ^85210    ^85220    ^85230    ^85240    ^85250    ^85260    ^85270              ^85290    ^85300    ^85310    ^85320    ^85330    ^85340    ^85350              ^85370    ^85380    ^85390    ^85400    ^85410    ^85420    ^85430              ^85450    ^85460    ^85470    ^85480    ^85490    ^85500    ^85510              ^85530    ^85540    ^85550    ^85560    ^85570    ^85580    ^85590              ^85610    ^85620    ^85630    ^85640    ^85650    ^85660    ^85670              ^85690    ^85700    ^85710    ^85720    ^85730    ^85740    ^85750              ^85770    ^85780    ^85790    ^85800    ^85810    ^85820    ^85830              ^85850    ^85860    ^85870    ^85880    ^85890    ^85900    ^85910              ^85930    ^85940    ^85950    ^85960    ^85970    ^85980    ^85990              ^86010    ^86020    ^86030    ^86040    ^86050    ^86060    ^86070              ^86090    ^86100    ^86110    ^86120    ^86130    ^86140    ^86150              ^86170    ^86180    ^86190    ^86200    ^86210    ^86220    ^86230              ^86250    ^86260    ^86270    ^86280    ^86290    ^86300    ^86310              ^86330    ^86340    ^86350    ^86360    ^86370    ^86380    ^86390              ^86410    ^86420    ^86430    ^86440    ^86450    ^86460    ^86470              ^86490    ^86500    ^86510    ^86520    ^86530    ^86540    ^86550              ^86570    ^86580    ^86590    ^86600    ^86610    ^86620    ^86630              ^86650    ^86660    ^86670    ^86680    ^86690    ^86700    ^86710              ^86730    ^86740    ^86750    ^86760    ^86770    ^86780    ^86790              ^86810    ^86820    ^86830    ^86840    ^86850    ^86860    ^86870              ^86890    ^86900    ^86910    ^86920    ^86930    ^86940    ^86950              ^86970    ^86980    ^86990    ^87000    ^87010    ^87020    ^87030              ^87050    ^87060    ^87070    ^87080    ^87090    ^87100    ^87110              ^87130    ^87140    ^87150    ^87160    ^87170    ^87180    ^87190              ^87210    ^87220    ^87230    ^87240    ^87250    ^87260    ^87270              ^87290    ^87300    ^87310    ^87320    ^87330    ^87340    ^87350              ^87370    ^87380    ^87390    ^87400    ^87410    ^87420    ^87430              ^87450    ^87460    ^87470    ^87480    ^87490    ^87500    ^87510              ^87530    ^87540    ^87550    ^87560    ^87570    ^87580    ^87590              ^87610    ^87620    ^87630    ^87640    ^87650    ^87660    ^87670              ^87690    ^87700    ^87710    ^87720    ^87730    ^87740    ^87750              ^87770    ^87780    ^87790    ^87800    ^87810    ^87820    ^87830              ^87850    ^87860    ^87870    ^87880    ^87890    ^87900    ^87910              ^87930    ^87940    ^87950    ^87960    ^87970    ^87980    ^87990              ^88010    ^88020    ^88030    ^88040    ^88050    ^88060    ^88070              ^88090    ^88100    ^88110    ^88120    ^88130    ^88140    ^88150              ^88170    ^88180    ^88190    ^88200    ^88210    ^88220    ^88230              ^88250    ^88260    ^88270    ^88280    ^88290    ^88300    ^88310              ^88330    ^88340    ^88350    ^88360    ^88370    ^88380    ^88390              ^88410    ^88420    ^88430    ^88440    ^88450    ^88460    ^88470              ^88490    ^88500    ^88510    ^88520    ^88530    ^88540    ^88550              ^88570    ^88580    ^88590    ^88600    ^88610    ^88620    ^88630              ^88650    ^88660    ^88670    ^88680    ^88690    ^88700    ^88710              ^88730    ^88740    ^88750    ^88760    ^88770    ^88780    ^88790              ^88810    ^88820    ^88830    ^88840    ^88850    ^88860    ^88870              ^88890    ^88900    ^88910    ^88920    ^88930    ^88940    ^88950              ^88970    ^88980    ^88990    ^89000    ^89010    ^89020    ^89030              ^89050    ^89060    ^89070    ^89080    ^89090    ^89100    ^89110              ^89130    ^89140    ^89150    ^89160    ^89170    ^89180    ^89190              ^89210    ^89220    ^89230    ^89240    ^89250    ^89260    ^89270              ^89290    ^89300    ^89310    ^89320    ^89330    ^89340    ^89350              ^89370    ^89380    ^89390    ^89400    ^89410    ^89420    ^89430              ^89450    ^89460    ^89470    ^89480    ^89490    ^89500    ^89510              ^89530    ^89540    ^89550    ^89560    ^89570    ^89580    ^89590              ^89610    ^89620    ^89630    ^89640    ^89650    ^89660    ^89670              ^89690    ^89700    ^89710    ^89720    ^89730    ^89740    ^89750              ^89770    ^89780    ^89790    ^89800    ^89810    ^89820    ^89830              ^89850    ^89860    ^89870    ^89880    ^89890    ^89900    ^89910              ^89930    ^89940    ^89950    ^89960    ^89970    ^89980    ^89990              ^90010    ^90020    ^90030    ^90040    ^90050    ^90060    ^90070              ^90090    ^90100    ^90110    ^90120    ^90130    ^90140    ^90150              ^90170    ^90180    ^90190    ^90200    ^90210    ^90220    ^90230              ^90250    ^90260    ^90270    ^90280    ^90290    ^90300    ^90310              ^90330    ^90340    ^90350    ^90360    ^90370    ^90380    ^90390              ^90410    ^90420    ^90430    ^90440    ^90450    ^90460    ^90470              ^90490    ^90500    ^90510    ^90520    ^90530    ^90540    ^90550              ^90570    ^90580    ^90590    ^90600    ^90610    ^90620    ^90630              ^90650    ^90660    ^90670    ^90680    ^90690    ^90700    ^90710              ^90730    ^90740    ^90750    ^90760    ^90770    ^90780    ^90790              ^90810    ^90820    ^90830    ^90840    ^90850    ^90860    ^90870              ^90890    ^90900    ^90910    ^90920    ^90930    ^90940    ^90950              ^90970    ^90980    ^90990    ^91000    ^91010    ^91020    ^91030              ^91050    ^91060    ^91070    ^91080    ^91090    ^91100    ^91110              ^91130    ^91140    ^91150    ^91160    ^91170    ^91180    ^91190              ^91210    ^91220    ^91230    ^91240    ^91250    ^91260    ^91270              ^91290    ^91300    ^91310    ^91320    ^91330    ^91340    ^91350              ^91370    ^91380    ^91390    ^91400    ^91410    ^91420    ^91430              ^91450    ^91460    ^91470    ^91480    ^91490    ^91500    ^91510              ^91530    ^91540    ^91550    ^91560    ^91570    ^91580    ^91590              ^91610    ^91620    ^91630    ^91640    ^91650    ^91660    ^91670              ^91690    ^91700    ^91710    ^91720    ^91730    ^91740    ^91750              ^91770    ^91780    ^91790    ^91800    ^91810    ^91820    ^91830              ^91850    ^91860    ^91870    ^91880    ^91890    ^91900    ^91910              ^91930    ^91940    ^91950    ^91960    ^91970    ^91980    ^91990              ^92010    ^92020    ^92030    ^92040    ^92050    ^92060    ^92070              ^92090    ^92100    ^92110    ^92120    ^92130    ^92140    ^92150              ^92170    ^92180    ^92190    ^92200    ^92210    ^92220    ^92230              ^92250    ^92260    ^92270    ^92280    ^92290    ^92300    ^92310              ^92330    ^92340    ^92350    ^92360    ^92370    ^92380    ^92390              ^92410    ^92420    ^92430    ^92440    ^92450    ^92460    ^92470              ^92490    ^92500    ^92510    ^92520    ^92530    ^92540    ^92550              ^92570    ^92580    ^92590    ^92600    ^92610    ^92620    ^92630              ^92650    ^92660    ^92670    ^92680    ^92690    ^92700    ^92710              ^92730    ^92740    ^92750    ^92760    ^92770    ^92780    ^92790              ^92810    ^92820    ^92830    ^92840    ^92850    ^92860    ^92870              ^92890    ^92900    ^92910    ^92920    ^92930    ^92940    ^92950              ^92970    ^92980    ^92990    ^93000    ^93010    ^93020    ^93030              ^93050    ^93060    ^93070    ^93080    ^93090    ^93100    ^93110              ^93130    ^93140    ^93150    ^93160    ^93170    ^93180    ^93190              ^93210    ^93220    ^93230    ^93240    ^93250    ^93260    ^93270              ^93290    ^93300    ^93310    ^93320    ^93330    ^93340    ^93350              ^93370    ^93380    ^93390    ^93400    ^93410    ^93420    ^93430              ^93450    ^93460    ^93470    ^93480    ^93490    ^93500    ^93510              ^93530    ^93540    ^93550    ^93560    ^93570    ^93580    ^93590              ^93610    ^93620    ^93630    ^93640    ^93650    ^93660    ^93670              ^93690    ^93700    ^93710    ^93720    ^93730    ^93740    ^93750              ^93770    ^93780    ^93790    ^93800    ^93810    ^93820    ^93830              ^93850    ^93860    ^93870    ^93880    ^93890    ^93900    ^93910              ^93930    ^93940    ^93950    ^93960    ^93970    ^93980    ^93990              ^94010    ^94020    ^94030    ^94040    ^94050    ^94060    ^94070              ^94090    ^94100    ^94110    ^94120    ^94130    ^94140    ^94150              ^94170    ^94180    ^94190    ^94200    ^94210    ^94220    ^94230              ^94250    ^94260    ^94270    ^94280    ^94290    ^94300    ^94310              ^94330    ^94340    ^94350    ^94360    ^94370    ^94380    ^94390              ^94410    ^94420    ^94430    ^94440    ^94450    ^94460    ^94470              ^94490    ^94500    ^94510    ^94520    ^94530    ^94540    ^94550              ^94570    ^94580    ^94590    ^94600    ^94610    ^94620    ^94630              ^94650    ^94660    ^94670    ^94680    ^94690    ^94700    ^94710              ^94730    ^94740    ^94750    ^94760    ^94770    ^94780    ^94790              ^94810    ^94820    ^94830    ^94840    ^94850    ^94860    ^94870              ^94890    ^94900    ^94910    ^94920    ^94930    ^94940    ^94950              ^94970    ^94980    ^94990    ^95000    ^95010    ^95020    ^95030              ^95050    ^95060    ^95070    ^95080    ^95090    ^95100    ^95110              ^95130    ^95140    ^95150    ^95160    ^95170    ^95180    ^95190              ^95210    ^95220    ^95230    ^95240    ^95250    ^95260    ^95270              ^95290    ^95300    ^95310    ^95320    ^95330    ^95340    ^95350              ^95370    ^95380    ^95390    ^95400    ^95410    ^95420    ^95430              ^95450    ^95460    ^95470    ^95480    ^95490    ^95500    ^95510              ^95530    ^95540    ^95550    ^95560    ^95570    ^95580    ^95590              ^95610    ^95620    ^95630    ^95640    ^95650    ^95660    ^95670              ^95690    ^95700    ^95710    ^95720    ^95730    ^95740    ^95750              ^95770    ^95780    ^95790    ^95800    ^95810    ^95820    ^95830              ^95850    ^95860    ^95870    ^95880    ^95890    ^95900    ^95910              ^95930    ^95940    ^95950    ^95960    ^95970    ^95980    ^95990              ^96010    ^96020    ^96030    ^96040    ^96050    ^96060    ^96070              ^96090    ^96100    ^96110    ^96120    ^96130    ^96140    ^96150              ^96170    ^96180    ^96190    ^96200    ^96210    ^96220    ^96230              ^96250    ^96260    ^96270    ^96280    ^96290    ^96300    ^96310              ^96330    ^96340    ^96350    ^96360    ^96370    ^96380    ^96390              ^96410    ^96420    ^96430    ^96440    ^96450    ^96460    ^96470              ^96490    ^96500    ^96510    ^96520    ^96530    ^96540    ^96550              ^96570    ^96580    ^96590    ^96600    ^96610    ^96620    ^96630              ^96650    ^96660    ^96670    ^96680    ^96690    ^96700    ^96710              ^96730    ^96740    ^96750    ^96760    ^96770    ^96780    ^96790              ^96810    ^96820    ^96830    ^96840    ^96850    ^96860    ^96870              ^96890    ^96900    ^96910    ^96920    ^96930    ^96940    ^96950              ^96970    ^96980    ^96990    ^97000    ^97010    ^97020    ^97030              ^97050    ^97060    ^97070    ^97080    ^97090    ^97100    ^97110              ^97130    ^97140    ^97150    ^97160    ^97170    ^97180    ^97190              ^97210    ^97220    ^97230    ^97240    ^97250    ^97260    ^97270              ^97290    ^97300    ^97310    ^97320    ^97330    ^97340    ^97350              ^97370    ^97380    ^97390    ^97400    ^97410    ^97420    ^97430              ^97450    ^97460    ^97470    ^97480    ^97490    ^97500    ^97510              ^97530    ^97540    ^97550    ^97560    ^97570    ^97580    ^97590              ^97610    ^97620    ^97630    ^97640    ^97650    ^97660    ^97670              ^97690    ^97700    ^97710    ^97720    ^97730    ^97740    ^97750              ^97770    ^97780    ^97790    ^97800    ^97810    ^97820    ^97830              ^97850    ^97860    ^97870    ^97880    ^97890    ^97900    ^97910              ^97930    ^97940    ^97950    ^97960    ^97970    ^97980    ^97990              ^98010    ^98020    ^98030    ^98040    ^98050    ^98060    ^98070              ^98090    ^98100    ^98110    ^98120    ^98130    ^98140    ^98150              ^98170    ^98180    ^98190    ^98200    ^98210    ^98220    ^98230              ^98250    ^98260    ^98270    ^98280    ^98290    ^98300    ^98310              ^98330    ^98340    ^98350    ^98360    ^98370    ^98380    ^98390              ^98410    ^98420    ^98430    ^98440    ^98450    ^98460    ^98470              ^98490    ^98500    ^98510    ^98520    ^98530    ^98540    ^98550              ^98570    ^98580    ^98590    ^98600    ^98610    ^98620    ^98630              ^98650    ^98660    ^98670    ^98680    ^98690    ^98700    ^98710              ^98730    ^98740    ^98750    ^98760    ^98770    ^98780    ^98790              ^98810    ^98820    ^98830    ^98840    ^98850    ^98860    ^98870              ^98890    ^98900    ^98910    ^98920    ^98930    ^98940    ^98950              ^98970    ^98980    ^98990    ^99000    ^99010    ^99020    ^99030              ^99050    ^99060    ^99070    ^99080    ^99090    ^99100    ^99110              ^99130    ^99140    ^99150    ^99160    ^99170    ^99180    ^99190              ^99210    ^99220    ^99230    ^99240    ^99250    ^99260    ^99270              ^99290    ^99300    ^99310    ^99320    ^99330    ^99340    ^99350              ^99370    ^99380    ^99390    ^99400    ^99410    ^99420    ^99430              ^99450    ^99460    ^99470    ^99480    ^99490    ^99500    ^99510              ^99530    ^99540    ^99550    ^99560    ^99570    ^99580    ^99590              ^99610    ^99620    ^99630    ^99640    ^99650    ^99660    ^99670              ^99690    ^99700    ^99710    ^99720    ^99730    ^99740    ^99750              ^99770    ^99780    ^99790    ^99800    ^99810    ^99820    ^99830              ^99850    ^99860    ^99870    ^99880    ^99890    ^99900    ^99910              ^99930    ^99940    ^99950    ^99960    ^99970    ^99980    ^99990     ';
   }
   elsif ($basePerLine == 100) {
      return '         ^10       ^20       ^30       ^40       ^50       ^60       ^70       ^80       ^90                 ^110      ^120      ^130      ^140      ^150      ^160      ^170      ^180      ^190                ^210      ^220      ^230      ^240      ^250      ^260      ^270      ^280      ^290                ^310      ^320      ^330      ^340      ^350      ^360      ^370      ^380      ^390                ^410      ^420      ^430      ^440      ^450      ^460      ^470      ^480      ^490                ^510      ^520      ^530      ^540      ^550      ^560      ^570      ^580      ^590                ^610      ^620      ^630      ^640      ^650      ^660      ^670      ^680      ^690                ^710      ^720      ^730      ^740      ^750      ^760      ^770      ^780      ^790                ^810      ^820      ^830      ^840      ^850      ^860      ^870      ^880      ^890                ^910      ^920      ^930      ^940      ^950      ^960      ^970      ^980      ^990                ^1010     ^1020     ^1030     ^1040     ^1050     ^1060     ^1070     ^1080     ^1090               ^1110     ^1120     ^1130     ^1140     ^1150     ^1160     ^1170     ^1180     ^1190               ^1210     ^1220     ^1230     ^1240     ^1250     ^1260     ^1270     ^1280     ^1290               ^1310     ^1320     ^1330     ^1340     ^1350     ^1360     ^1370     ^1380     ^1390               ^1410     ^1420     ^1430     ^1440     ^1450     ^1460     ^1470     ^1480     ^1490               ^1510     ^1520     ^1530     ^1540     ^1550     ^1560     ^1570     ^1580     ^1590               ^1610     ^1620     ^1630     ^1640     ^1650     ^1660     ^1670     ^1680     ^1690               ^1710     ^1720     ^1730     ^1740     ^1750     ^1760     ^1770     ^1780     ^1790               ^1810     ^1820     ^1830     ^1840     ^1850     ^1860     ^1870     ^1880     ^1890               ^1910     ^1920     ^1930     ^1940     ^1950     ^1960     ^1970     ^1980     ^1990               ^2010     ^2020     ^2030     ^2040     ^2050     ^2060     ^2070     ^2080     ^2090               ^2110     ^2120     ^2130     ^2140     ^2150     ^2160     ^2170     ^2180     ^2190               ^2210     ^2220     ^2230     ^2240     ^2250     ^2260     ^2270     ^2280     ^2290               ^2310     ^2320     ^2330     ^2340     ^2350     ^2360     ^2370     ^2380     ^2390               ^2410     ^2420     ^2430     ^2440     ^2450     ^2460     ^2470     ^2480     ^2490               ^2510     ^2520     ^2530     ^2540     ^2550     ^2560     ^2570     ^2580     ^2590               ^2610     ^2620     ^2630     ^2640     ^2650     ^2660     ^2670     ^2680     ^2690               ^2710     ^2720     ^2730     ^2740     ^2750     ^2760     ^2770     ^2780     ^2790               ^2810     ^2820     ^2830     ^2840     ^2850     ^2860     ^2870     ^2880     ^2890               ^2910     ^2920     ^2930     ^2940     ^2950     ^2960     ^2970     ^2980     ^2990               ^3010     ^3020     ^3030     ^3040     ^3050     ^3060     ^3070     ^3080     ^3090               ^3110     ^3120     ^3130     ^3140     ^3150     ^3160     ^3170     ^3180     ^3190               ^3210     ^3220     ^3230     ^3240     ^3250     ^3260     ^3270     ^3280     ^3290               ^3310     ^3320     ^3330     ^3340     ^3350     ^3360     ^3370     ^3380     ^3390               ^3410     ^3420     ^3430     ^3440     ^3450     ^3460     ^3470     ^3480     ^3490               ^3510     ^3520     ^3530     ^3540     ^3550     ^3560     ^3570     ^3580     ^3590               ^3610     ^3620     ^3630     ^3640     ^3650     ^3660     ^3670     ^3680     ^3690               ^3710     ^3720     ^3730     ^3740     ^3750     ^3760     ^3770     ^3780     ^3790               ^3810     ^3820     ^3830     ^3840     ^3850     ^3860     ^3870     ^3880     ^3890               ^3910     ^3920     ^3930     ^3940     ^3950     ^3960     ^3970     ^3980     ^3990               ^4010     ^4020     ^4030     ^4040     ^4050     ^4060     ^4070     ^4080     ^4090               ^4110     ^4120     ^4130     ^4140     ^4150     ^4160     ^4170     ^4180     ^4190               ^4210     ^4220     ^4230     ^4240     ^4250     ^4260     ^4270     ^4280     ^4290               ^4310     ^4320     ^4330     ^4340     ^4350     ^4360     ^4370     ^4380     ^4390               ^4410     ^4420     ^4430     ^4440     ^4450     ^4460     ^4470     ^4480     ^4490               ^4510     ^4520     ^4530     ^4540     ^4550     ^4560     ^4570     ^4580     ^4590               ^4610     ^4620     ^4630     ^4640     ^4650     ^4660     ^4670     ^4680     ^4690               ^4710     ^4720     ^4730     ^4740     ^4750     ^4760     ^4770     ^4780     ^4790               ^4810     ^4820     ^4830     ^4840     ^4850     ^4860     ^4870     ^4880     ^4890               ^4910     ^4920     ^4930     ^4940     ^4950     ^4960     ^4970     ^4980     ^4990               ^5010     ^5020     ^5030     ^5040     ^5050     ^5060     ^5070     ^5080     ^5090               ^5110     ^5120     ^5130     ^5140     ^5150     ^5160     ^5170     ^5180     ^5190               ^5210     ^5220     ^5230     ^5240     ^5250     ^5260     ^5270     ^5280     ^5290               ^5310     ^5320     ^5330     ^5340     ^5350     ^5360     ^5370     ^5380     ^5390               ^5410     ^5420     ^5430     ^5440     ^5450     ^5460     ^5470     ^5480     ^5490               ^5510     ^5520     ^5530     ^5540     ^5550     ^5560     ^5570     ^5580     ^5590               ^5610     ^5620     ^5630     ^5640     ^5650     ^5660     ^5670     ^5680     ^5690               ^5710     ^5720     ^5730     ^5740     ^5750     ^5760     ^5770     ^5780     ^5790               ^5810     ^5820     ^5830     ^5840     ^5850     ^5860     ^5870     ^5880     ^5890               ^5910     ^5920     ^5930     ^5940     ^5950     ^5960     ^5970     ^5980     ^5990               ^6010     ^6020     ^6030     ^6040     ^6050     ^6060     ^6070     ^6080     ^6090               ^6110     ^6120     ^6130     ^6140     ^6150     ^6160     ^6170     ^6180     ^6190               ^6210     ^6220     ^6230     ^6240     ^6250     ^6260     ^6270     ^6280     ^6290               ^6310     ^6320     ^6330     ^6340     ^6350     ^6360     ^6370     ^6380     ^6390               ^6410     ^6420     ^6430     ^6440     ^6450     ^6460     ^6470     ^6480     ^6490               ^6510     ^6520     ^6530     ^6540     ^6550     ^6560     ^6570     ^6580     ^6590               ^6610     ^6620     ^6630     ^6640     ^6650     ^6660     ^6670     ^6680     ^6690               ^6710     ^6720     ^6730     ^6740     ^6750     ^6760     ^6770     ^6780     ^6790               ^6810     ^6820     ^6830     ^6840     ^6850     ^6860     ^6870     ^6880     ^6890               ^6910     ^6920     ^6930     ^6940     ^6950     ^6960     ^6970     ^6980     ^6990               ^7010     ^7020     ^7030     ^7040     ^7050     ^7060     ^7070     ^7080     ^7090               ^7110     ^7120     ^7130     ^7140     ^7150     ^7160     ^7170     ^7180     ^7190               ^7210     ^7220     ^7230     ^7240     ^7250     ^7260     ^7270     ^7280     ^7290               ^7310     ^7320     ^7330     ^7340     ^7350     ^7360     ^7370     ^7380     ^7390               ^7410     ^7420     ^7430     ^7440     ^7450     ^7460     ^7470     ^7480     ^7490               ^7510     ^7520     ^7530     ^7540     ^7550     ^7560     ^7570     ^7580     ^7590               ^7610     ^7620     ^7630     ^7640     ^7650     ^7660     ^7670     ^7680     ^7690               ^7710     ^7720     ^7730     ^7740     ^7750     ^7760     ^7770     ^7780     ^7790               ^7810     ^7820     ^7830     ^7840     ^7850     ^7860     ^7870     ^7880     ^7890               ^7910     ^7920     ^7930     ^7940     ^7950     ^7960     ^7970     ^7980     ^7990               ^8010     ^8020     ^8030     ^8040     ^8050     ^8060     ^8070     ^8080     ^8090               ^8110     ^8120     ^8130     ^8140     ^8150     ^8160     ^8170     ^8180     ^8190               ^8210     ^8220     ^8230     ^8240     ^8250     ^8260     ^8270     ^8280     ^8290               ^8310     ^8320     ^8330     ^8340     ^8350     ^8360     ^8370     ^8380     ^8390               ^8410     ^8420     ^8430     ^8440     ^8450     ^8460     ^8470     ^8480     ^8490               ^8510     ^8520     ^8530     ^8540     ^8550     ^8560     ^8570     ^8580     ^8590               ^8610     ^8620     ^8630     ^8640     ^8650     ^8660     ^8670     ^8680     ^8690               ^8710     ^8720     ^8730     ^8740     ^8750     ^8760     ^8770     ^8780     ^8790               ^8810     ^8820     ^8830     ^8840     ^8850     ^8860     ^8870     ^8880     ^8890               ^8910     ^8920     ^8930     ^8940     ^8950     ^8960     ^8970     ^8980     ^8990               ^9010     ^9020     ^9030     ^9040     ^9050     ^9060     ^9070     ^9080     ^9090               ^9110     ^9120     ^9130     ^9140     ^9150     ^9160     ^9170     ^9180     ^9190               ^9210     ^9220     ^9230     ^9240     ^9250     ^9260     ^9270     ^9280     ^9290               ^9310     ^9320     ^9330     ^9340     ^9350     ^9360     ^9370     ^9380     ^9390               ^9410     ^9420     ^9430     ^9440     ^9450     ^9460     ^9470     ^9480     ^9490               ^9510     ^9520     ^9530     ^9540     ^9550     ^9560     ^9570     ^9580     ^9590               ^9610     ^9620     ^9630     ^9640     ^9650     ^9660     ^9670     ^9680     ^9690               ^9710     ^9720     ^9730     ^9740     ^9750     ^9760     ^9770     ^9780     ^9790               ^9810     ^9820     ^9830     ^9840     ^9850     ^9860     ^9870     ^9880     ^9890               ^9910     ^9920     ^9930     ^9940     ^9950     ^9960     ^9970     ^9980     ^9990               ^10010    ^10020    ^10030    ^10040    ^10050    ^10060    ^10070    ^10080    ^10090              ^10110    ^10120    ^10130    ^10140    ^10150    ^10160    ^10170    ^10180    ^10190              ^10210    ^10220    ^10230    ^10240    ^10250    ^10260    ^10270    ^10280    ^10290              ^10310    ^10320    ^10330    ^10340    ^10350    ^10360    ^10370    ^10380    ^10390              ^10410    ^10420    ^10430    ^10440    ^10450    ^10460    ^10470    ^10480    ^10490              ^10510    ^10520    ^10530    ^10540    ^10550    ^10560    ^10570    ^10580    ^10590              ^10610    ^10620    ^10630    ^10640    ^10650    ^10660    ^10670    ^10680    ^10690              ^10710    ^10720    ^10730    ^10740    ^10750    ^10760    ^10770    ^10780    ^10790              ^10810    ^10820    ^10830    ^10840    ^10850    ^10860    ^10870    ^10880    ^10890              ^10910    ^10920    ^10930    ^10940    ^10950    ^10960    ^10970    ^10980    ^10990              ^11010    ^11020    ^11030    ^11040    ^11050    ^11060    ^11070    ^11080    ^11090              ^11110    ^11120    ^11130    ^11140    ^11150    ^11160    ^11170    ^11180    ^11190              ^11210    ^11220    ^11230    ^11240    ^11250    ^11260    ^11270    ^11280    ^11290              ^11310    ^11320    ^11330    ^11340    ^11350    ^11360    ^11370    ^11380    ^11390              ^11410    ^11420    ^11430    ^11440    ^11450    ^11460    ^11470    ^11480    ^11490              ^11510    ^11520    ^11530    ^11540    ^11550    ^11560    ^11570    ^11580    ^11590              ^11610    ^11620    ^11630    ^11640    ^11650    ^11660    ^11670    ^11680    ^11690              ^11710    ^11720    ^11730    ^11740    ^11750    ^11760    ^11770    ^11780    ^11790              ^11810    ^11820    ^11830    ^11840    ^11850    ^11860    ^11870    ^11880    ^11890              ^11910    ^11920    ^11930    ^11940    ^11950    ^11960    ^11970    ^11980    ^11990              ^12010    ^12020    ^12030    ^12040    ^12050    ^12060    ^12070    ^12080    ^12090              ^12110    ^12120    ^12130    ^12140    ^12150    ^12160    ^12170    ^12180    ^12190              ^12210    ^12220    ^12230    ^12240    ^12250    ^12260    ^12270    ^12280    ^12290              ^12310    ^12320    ^12330    ^12340    ^12350    ^12360    ^12370    ^12380    ^12390              ^12410    ^12420    ^12430    ^12440    ^12450    ^12460    ^12470    ^12480    ^12490              ^12510    ^12520    ^12530    ^12540    ^12550    ^12560    ^12570    ^12580    ^12590              ^12610    ^12620    ^12630    ^12640    ^12650    ^12660    ^12670    ^12680    ^12690              ^12710    ^12720    ^12730    ^12740    ^12750    ^12760    ^12770    ^12780    ^12790              ^12810    ^12820    ^12830    ^12840    ^12850    ^12860    ^12870    ^12880    ^12890              ^12910    ^12920    ^12930    ^12940    ^12950    ^12960    ^12970    ^12980    ^12990              ^13010    ^13020    ^13030    ^13040    ^13050    ^13060    ^13070    ^13080    ^13090              ^13110    ^13120    ^13130    ^13140    ^13150    ^13160    ^13170    ^13180    ^13190              ^13210    ^13220    ^13230    ^13240    ^13250    ^13260    ^13270    ^13280    ^13290              ^13310    ^13320    ^13330    ^13340    ^13350    ^13360    ^13370    ^13380    ^13390              ^13410    ^13420    ^13430    ^13440    ^13450    ^13460    ^13470    ^13480    ^13490              ^13510    ^13520    ^13530    ^13540    ^13550    ^13560    ^13570    ^13580    ^13590              ^13610    ^13620    ^13630    ^13640    ^13650    ^13660    ^13670    ^13680    ^13690              ^13710    ^13720    ^13730    ^13740    ^13750    ^13760    ^13770    ^13780    ^13790              ^13810    ^13820    ^13830    ^13840    ^13850    ^13860    ^13870    ^13880    ^13890              ^13910    ^13920    ^13930    ^13940    ^13950    ^13960    ^13970    ^13980    ^13990              ^14010    ^14020    ^14030    ^14040    ^14050    ^14060    ^14070    ^14080    ^14090              ^14110    ^14120    ^14130    ^14140    ^14150    ^14160    ^14170    ^14180    ^14190              ^14210    ^14220    ^14230    ^14240    ^14250    ^14260    ^14270    ^14280    ^14290              ^14310    ^14320    ^14330    ^14340    ^14350    ^14360    ^14370    ^14380    ^14390              ^14410    ^14420    ^14430    ^14440    ^14450    ^14460    ^14470    ^14480    ^14490              ^14510    ^14520    ^14530    ^14540    ^14550    ^14560    ^14570    ^14580    ^14590              ^14610    ^14620    ^14630    ^14640    ^14650    ^14660    ^14670    ^14680    ^14690              ^14710    ^14720    ^14730    ^14740    ^14750    ^14760    ^14770    ^14780    ^14790              ^14810    ^14820    ^14830    ^14840    ^14850    ^14860    ^14870    ^14880    ^14890              ^14910    ^14920    ^14930    ^14940    ^14950    ^14960    ^14970    ^14980    ^14990              ^15010    ^15020    ^15030    ^15040    ^15050    ^15060    ^15070    ^15080    ^15090              ^15110    ^15120    ^15130    ^15140    ^15150    ^15160    ^15170    ^15180    ^15190              ^15210    ^15220    ^15230    ^15240    ^15250    ^15260    ^15270    ^15280    ^15290              ^15310    ^15320    ^15330    ^15340    ^15350    ^15360    ^15370    ^15380    ^15390              ^15410    ^15420    ^15430    ^15440    ^15450    ^15460    ^15470    ^15480    ^15490              ^15510    ^15520    ^15530    ^15540    ^15550    ^15560    ^15570    ^15580    ^15590              ^15610    ^15620    ^15630    ^15640    ^15650    ^15660    ^15670    ^15680    ^15690              ^15710    ^15720    ^15730    ^15740    ^15750    ^15760    ^15770    ^15780    ^15790              ^15810    ^15820    ^15830    ^15840    ^15850    ^15860    ^15870    ^15880    ^15890              ^15910    ^15920    ^15930    ^15940    ^15950    ^15960    ^15970    ^15980    ^15990              ^16010    ^16020    ^16030    ^16040    ^16050    ^16060    ^16070    ^16080    ^16090              ^16110    ^16120    ^16130    ^16140    ^16150    ^16160    ^16170    ^16180    ^16190              ^16210    ^16220    ^16230    ^16240    ^16250    ^16260    ^16270    ^16280    ^16290              ^16310    ^16320    ^16330    ^16340    ^16350    ^16360    ^16370    ^16380    ^16390              ^16410    ^16420    ^16430    ^16440    ^16450    ^16460    ^16470    ^16480    ^16490              ^16510    ^16520    ^16530    ^16540    ^16550    ^16560    ^16570    ^16580    ^16590              ^16610    ^16620    ^16630    ^16640    ^16650    ^16660    ^16670    ^16680    ^16690              ^16710    ^16720    ^16730    ^16740    ^16750    ^16760    ^16770    ^16780    ^16790              ^16810    ^16820    ^16830    ^16840    ^16850    ^16860    ^16870    ^16880    ^16890              ^16910    ^16920    ^16930    ^16940    ^16950    ^16960    ^16970    ^16980    ^16990              ^17010    ^17020    ^17030    ^17040    ^17050    ^17060    ^17070    ^17080    ^17090              ^17110    ^17120    ^17130    ^17140    ^17150    ^17160    ^17170    ^17180    ^17190              ^17210    ^17220    ^17230    ^17240    ^17250    ^17260    ^17270    ^17280    ^17290              ^17310    ^17320    ^17330    ^17340    ^17350    ^17360    ^17370    ^17380    ^17390              ^17410    ^17420    ^17430    ^17440    ^17450    ^17460    ^17470    ^17480    ^17490              ^17510    ^17520    ^17530    ^17540    ^17550    ^17560    ^17570    ^17580    ^17590              ^17610    ^17620    ^17630    ^17640    ^17650    ^17660    ^17670    ^17680    ^17690              ^17710    ^17720    ^17730    ^17740    ^17750    ^17760    ^17770    ^17780    ^17790              ^17810    ^17820    ^17830    ^17840    ^17850    ^17860    ^17870    ^17880    ^17890              ^17910    ^17920    ^17930    ^17940    ^17950    ^17960    ^17970    ^17980    ^17990              ^18010    ^18020    ^18030    ^18040    ^18050    ^18060    ^18070    ^18080    ^18090              ^18110    ^18120    ^18130    ^18140    ^18150    ^18160    ^18170    ^18180    ^18190              ^18210    ^18220    ^18230    ^18240    ^18250    ^18260    ^18270    ^18280    ^18290              ^18310    ^18320    ^18330    ^18340    ^18350    ^18360    ^18370    ^18380    ^18390              ^18410    ^18420    ^18430    ^18440    ^18450    ^18460    ^18470    ^18480    ^18490              ^18510    ^18520    ^18530    ^18540    ^18550    ^18560    ^18570    ^18580    ^18590              ^18610    ^18620    ^18630    ^18640    ^18650    ^18660    ^18670    ^18680    ^18690              ^18710    ^18720    ^18730    ^18740    ^18750    ^18760    ^18770    ^18780    ^18790              ^18810    ^18820    ^18830    ^18840    ^18850    ^18860    ^18870    ^18880    ^18890              ^18910    ^18920    ^18930    ^18940    ^18950    ^18960    ^18970    ^18980    ^18990              ^19010    ^19020    ^19030    ^19040    ^19050    ^19060    ^19070    ^19080    ^19090              ^19110    ^19120    ^19130    ^19140    ^19150    ^19160    ^19170    ^19180    ^19190              ^19210    ^19220    ^19230    ^19240    ^19250    ^19260    ^19270    ^19280    ^19290              ^19310    ^19320    ^19330    ^19340    ^19350    ^19360    ^19370    ^19380    ^19390              ^19410    ^19420    ^19430    ^19440    ^19450    ^19460    ^19470    ^19480    ^19490              ^19510    ^19520    ^19530    ^19540    ^19550    ^19560    ^19570    ^19580    ^19590              ^19610    ^19620    ^19630    ^19640    ^19650    ^19660    ^19670    ^19680    ^19690              ^19710    ^19720    ^19730    ^19740    ^19750    ^19760    ^19770    ^19780    ^19790              ^19810    ^19820    ^19830    ^19840    ^19850    ^19860    ^19870    ^19880    ^19890              ^19910    ^19920    ^19930    ^19940    ^19950    ^19960    ^19970    ^19980    ^19990              ^20010    ^20020    ^20030    ^20040    ^20050    ^20060    ^20070    ^20080    ^20090              ^20110    ^20120    ^20130    ^20140    ^20150    ^20160    ^20170    ^20180    ^20190              ^20210    ^20220    ^20230    ^20240    ^20250    ^20260    ^20270    ^20280    ^20290              ^20310    ^20320    ^20330    ^20340    ^20350    ^20360    ^20370    ^20380    ^20390              ^20410    ^20420    ^20430    ^20440    ^20450    ^20460    ^20470    ^20480    ^20490              ^20510    ^20520    ^20530    ^20540    ^20550    ^20560    ^20570    ^20580    ^20590              ^20610    ^20620    ^20630    ^20640    ^20650    ^20660    ^20670    ^20680    ^20690              ^20710    ^20720    ^20730    ^20740    ^20750    ^20760    ^20770    ^20780    ^20790              ^20810    ^20820    ^20830    ^20840    ^20850    ^20860    ^20870    ^20880    ^20890              ^20910    ^20920    ^20930    ^20940    ^20950    ^20960    ^20970    ^20980    ^20990              ^21010    ^21020    ^21030    ^21040    ^21050    ^21060    ^21070    ^21080    ^21090              ^21110    ^21120    ^21130    ^21140    ^21150    ^21160    ^21170    ^21180    ^21190              ^21210    ^21220    ^21230    ^21240    ^21250    ^21260    ^21270    ^21280    ^21290              ^21310    ^21320    ^21330    ^21340    ^21350    ^21360    ^21370    ^21380    ^21390              ^21410    ^21420    ^21430    ^21440    ^21450    ^21460    ^21470    ^21480    ^21490              ^21510    ^21520    ^21530    ^21540    ^21550    ^21560    ^21570    ^21580    ^21590              ^21610    ^21620    ^21630    ^21640    ^21650    ^21660    ^21670    ^21680    ^21690              ^21710    ^21720    ^21730    ^21740    ^21750    ^21760    ^21770    ^21780    ^21790              ^21810    ^21820    ^21830    ^21840    ^21850    ^21860    ^21870    ^21880    ^21890              ^21910    ^21920    ^21930    ^21940    ^21950    ^21960    ^21970    ^21980    ^21990              ^22010    ^22020    ^22030    ^22040    ^22050    ^22060    ^22070    ^22080    ^22090              ^22110    ^22120    ^22130    ^22140    ^22150    ^22160    ^22170    ^22180    ^22190              ^22210    ^22220    ^22230    ^22240    ^22250    ^22260    ^22270    ^22280    ^22290              ^22310    ^22320    ^22330    ^22340    ^22350    ^22360    ^22370    ^22380    ^22390              ^22410    ^22420    ^22430    ^22440    ^22450    ^22460    ^22470    ^22480    ^22490              ^22510    ^22520    ^22530    ^22540    ^22550    ^22560    ^22570    ^22580    ^22590              ^22610    ^22620    ^22630    ^22640    ^22650    ^22660    ^22670    ^22680    ^22690              ^22710    ^22720    ^22730    ^22740    ^22750    ^22760    ^22770    ^22780    ^22790              ^22810    ^22820    ^22830    ^22840    ^22850    ^22860    ^22870    ^22880    ^22890              ^22910    ^22920    ^22930    ^22940    ^22950    ^22960    ^22970    ^22980    ^22990              ^23010    ^23020    ^23030    ^23040    ^23050    ^23060    ^23070    ^23080    ^23090              ^23110    ^23120    ^23130    ^23140    ^23150    ^23160    ^23170    ^23180    ^23190              ^23210    ^23220    ^23230    ^23240    ^23250    ^23260    ^23270    ^23280    ^23290              ^23310    ^23320    ^23330    ^23340    ^23350    ^23360    ^23370    ^23380    ^23390              ^23410    ^23420    ^23430    ^23440    ^23450    ^23460    ^23470    ^23480    ^23490              ^23510    ^23520    ^23530    ^23540    ^23550    ^23560    ^23570    ^23580    ^23590              ^23610    ^23620    ^23630    ^23640    ^23650    ^23660    ^23670    ^23680    ^23690              ^23710    ^23720    ^23730    ^23740    ^23750    ^23760    ^23770    ^23780    ^23790              ^23810    ^23820    ^23830    ^23840    ^23850    ^23860    ^23870    ^23880    ^23890              ^23910    ^23920    ^23930    ^23940    ^23950    ^23960    ^23970    ^23980    ^23990              ^24010    ^24020    ^24030    ^24040    ^24050    ^24060    ^24070    ^24080    ^24090              ^24110    ^24120    ^24130    ^24140    ^24150    ^24160    ^24170    ^24180    ^24190              ^24210    ^24220    ^24230    ^24240    ^24250    ^24260    ^24270    ^24280    ^24290              ^24310    ^24320    ^24330    ^24340    ^24350    ^24360    ^24370    ^24380    ^24390              ^24410    ^24420    ^24430    ^24440    ^24450    ^24460    ^24470    ^24480    ^24490              ^24510    ^24520    ^24530    ^24540    ^24550    ^24560    ^24570    ^24580    ^24590              ^24610    ^24620    ^24630    ^24640    ^24650    ^24660    ^24670    ^24680    ^24690              ^24710    ^24720    ^24730    ^24740    ^24750    ^24760    ^24770    ^24780    ^24790              ^24810    ^24820    ^24830    ^24840    ^24850    ^24860    ^24870    ^24880    ^24890              ^24910    ^24920    ^24930    ^24940    ^24950    ^24960    ^24970    ^24980    ^24990              ^25010    ^25020    ^25030    ^25040    ^25050    ^25060    ^25070    ^25080    ^25090              ^25110    ^25120    ^25130    ^25140    ^25150    ^25160    ^25170    ^25180    ^25190              ^25210    ^25220    ^25230    ^25240    ^25250    ^25260    ^25270    ^25280    ^25290              ^25310    ^25320    ^25330    ^25340    ^25350    ^25360    ^25370    ^25380    ^25390              ^25410    ^25420    ^25430    ^25440    ^25450    ^25460    ^25470    ^25480    ^25490              ^25510    ^25520    ^25530    ^25540    ^25550    ^25560    ^25570    ^25580    ^25590              ^25610    ^25620    ^25630    ^25640    ^25650    ^25660    ^25670    ^25680    ^25690              ^25710    ^25720    ^25730    ^25740    ^25750    ^25760    ^25770    ^25780    ^25790              ^25810    ^25820    ^25830    ^25840    ^25850    ^25860    ^25870    ^25880    ^25890              ^25910    ^25920    ^25930    ^25940    ^25950    ^25960    ^25970    ^25980    ^25990              ^26010    ^26020    ^26030    ^26040    ^26050    ^26060    ^26070    ^26080    ^26090              ^26110    ^26120    ^26130    ^26140    ^26150    ^26160    ^26170    ^26180    ^26190              ^26210    ^26220    ^26230    ^26240    ^26250    ^26260    ^26270    ^26280    ^26290              ^26310    ^26320    ^26330    ^26340    ^26350    ^26360    ^26370    ^26380    ^26390              ^26410    ^26420    ^26430    ^26440    ^26450    ^26460    ^26470    ^26480    ^26490              ^26510    ^26520    ^26530    ^26540    ^26550    ^26560    ^26570    ^26580    ^26590              ^26610    ^26620    ^26630    ^26640    ^26650    ^26660    ^26670    ^26680    ^26690              ^26710    ^26720    ^26730    ^26740    ^26750    ^26760    ^26770    ^26780    ^26790              ^26810    ^26820    ^26830    ^26840    ^26850    ^26860    ^26870    ^26880    ^26890              ^26910    ^26920    ^26930    ^26940    ^26950    ^26960    ^26970    ^26980    ^26990              ^27010    ^27020    ^27030    ^27040    ^27050    ^27060    ^27070    ^27080    ^27090              ^27110    ^27120    ^27130    ^27140    ^27150    ^27160    ^27170    ^27180    ^27190              ^27210    ^27220    ^27230    ^27240    ^27250    ^27260    ^27270    ^27280    ^27290              ^27310    ^27320    ^27330    ^27340    ^27350    ^27360    ^27370    ^27380    ^27390              ^27410    ^27420    ^27430    ^27440    ^27450    ^27460    ^27470    ^27480    ^27490              ^27510    ^27520    ^27530    ^27540    ^27550    ^27560    ^27570    ^27580    ^27590              ^27610    ^27620    ^27630    ^27640    ^27650    ^27660    ^27670    ^27680    ^27690              ^27710    ^27720    ^27730    ^27740    ^27750    ^27760    ^27770    ^27780    ^27790              ^27810    ^27820    ^27830    ^27840    ^27850    ^27860    ^27870    ^27880    ^27890              ^27910    ^27920    ^27930    ^27940    ^27950    ^27960    ^27970    ^27980    ^27990              ^28010    ^28020    ^28030    ^28040    ^28050    ^28060    ^28070    ^28080    ^28090              ^28110    ^28120    ^28130    ^28140    ^28150    ^28160    ^28170    ^28180    ^28190              ^28210    ^28220    ^28230    ^28240    ^28250    ^28260    ^28270    ^28280    ^28290              ^28310    ^28320    ^28330    ^28340    ^28350    ^28360    ^28370    ^28380    ^28390              ^28410    ^28420    ^28430    ^28440    ^28450    ^28460    ^28470    ^28480    ^28490              ^28510    ^28520    ^28530    ^28540    ^28550    ^28560    ^28570    ^28580    ^28590              ^28610    ^28620    ^28630    ^28640    ^28650    ^28660    ^28670    ^28680    ^28690              ^28710    ^28720    ^28730    ^28740    ^28750    ^28760    ^28770    ^28780    ^28790              ^28810    ^28820    ^28830    ^28840    ^28850    ^28860    ^28870    ^28880    ^28890              ^28910    ^28920    ^28930    ^28940    ^28950    ^28960    ^28970    ^28980    ^28990              ^29010    ^29020    ^29030    ^29040    ^29050    ^29060    ^29070    ^29080    ^29090              ^29110    ^29120    ^29130    ^29140    ^29150    ^29160    ^29170    ^29180    ^29190              ^29210    ^29220    ^29230    ^29240    ^29250    ^29260    ^29270    ^29280    ^29290              ^29310    ^29320    ^29330    ^29340    ^29350    ^29360    ^29370    ^29380    ^29390              ^29410    ^29420    ^29430    ^29440    ^29450    ^29460    ^29470    ^29480    ^29490              ^29510    ^29520    ^29530    ^29540    ^29550    ^29560    ^29570    ^29580    ^29590              ^29610    ^29620    ^29630    ^29640    ^29650    ^29660    ^29670    ^29680    ^29690              ^29710    ^29720    ^29730    ^29740    ^29750    ^29760    ^29770    ^29780    ^29790              ^29810    ^29820    ^29830    ^29840    ^29850    ^29860    ^29870    ^29880    ^29890              ^29910    ^29920    ^29930    ^29940    ^29950    ^29960    ^29970    ^29980    ^29990              ^30010    ^30020    ^30030    ^30040    ^30050    ^30060    ^30070    ^30080    ^30090              ^30110    ^30120    ^30130    ^30140    ^30150    ^30160    ^30170    ^30180    ^30190              ^30210    ^30220    ^30230    ^30240    ^30250    ^30260    ^30270    ^30280    ^30290              ^30310    ^30320    ^30330    ^30340    ^30350    ^30360    ^30370    ^30380    ^30390              ^30410    ^30420    ^30430    ^30440    ^30450    ^30460    ^30470    ^30480    ^30490              ^30510    ^30520    ^30530    ^30540    ^30550    ^30560    ^30570    ^30580    ^30590              ^30610    ^30620    ^30630    ^30640    ^30650    ^30660    ^30670    ^30680    ^30690              ^30710    ^30720    ^30730    ^30740    ^30750    ^30760    ^30770    ^30780    ^30790              ^30810    ^30820    ^30830    ^30840    ^30850    ^30860    ^30870    ^30880    ^30890              ^30910    ^30920    ^30930    ^30940    ^30950    ^30960    ^30970    ^30980    ^30990              ^31010    ^31020    ^31030    ^31040    ^31050    ^31060    ^31070    ^31080    ^31090              ^31110    ^31120    ^31130    ^31140    ^31150    ^31160    ^31170    ^31180    ^31190              ^31210    ^31220    ^31230    ^31240    ^31250    ^31260    ^31270    ^31280    ^31290              ^31310    ^31320    ^31330    ^31340    ^31350    ^31360    ^31370    ^31380    ^31390              ^31410    ^31420    ^31430    ^31440    ^31450    ^31460    ^31470    ^31480    ^31490              ^31510    ^31520    ^31530    ^31540    ^31550    ^31560    ^31570    ^31580    ^31590              ^31610    ^31620    ^31630    ^31640    ^31650    ^31660    ^31670    ^31680    ^31690              ^31710    ^31720    ^31730    ^31740    ^31750    ^31760    ^31770    ^31780    ^31790              ^31810    ^31820    ^31830    ^31840    ^31850    ^31860    ^31870    ^31880    ^31890              ^31910    ^31920    ^31930    ^31940    ^31950    ^31960    ^31970    ^31980    ^31990              ^32010    ^32020    ^32030    ^32040    ^32050    ^32060    ^32070    ^32080    ^32090              ^32110    ^32120    ^32130    ^32140    ^32150    ^32160    ^32170    ^32180    ^32190              ^32210    ^32220    ^32230    ^32240    ^32250    ^32260    ^32270    ^32280    ^32290              ^32310    ^32320    ^32330    ^32340    ^32350    ^32360    ^32370    ^32380    ^32390              ^32410    ^32420    ^32430    ^32440    ^32450    ^32460    ^32470    ^32480    ^32490              ^32510    ^32520    ^32530    ^32540    ^32550    ^32560    ^32570    ^32580    ^32590              ^32610    ^32620    ^32630    ^32640    ^32650    ^32660    ^32670    ^32680    ^32690              ^32710    ^32720    ^32730    ^32740    ^32750    ^32760    ^32770    ^32780    ^32790              ^32810    ^32820    ^32830    ^32840    ^32850    ^32860    ^32870    ^32880    ^32890              ^32910    ^32920    ^32930    ^32940    ^32950    ^32960    ^32970    ^32980    ^32990              ^33010    ^33020    ^33030    ^33040    ^33050    ^33060    ^33070    ^33080    ^33090              ^33110    ^33120    ^33130    ^33140    ^33150    ^33160    ^33170    ^33180    ^33190              ^33210    ^33220    ^33230    ^33240    ^33250    ^33260    ^33270    ^33280    ^33290              ^33310    ^33320    ^33330    ^33340    ^33350    ^33360    ^33370    ^33380    ^33390              ^33410    ^33420    ^33430    ^33440    ^33450    ^33460    ^33470    ^33480    ^33490              ^33510    ^33520    ^33530    ^33540    ^33550    ^33560    ^33570    ^33580    ^33590              ^33610    ^33620    ^33630    ^33640    ^33650    ^33660    ^33670    ^33680    ^33690              ^33710    ^33720    ^33730    ^33740    ^33750    ^33760    ^33770    ^33780    ^33790              ^33810    ^33820    ^33830    ^33840    ^33850    ^33860    ^33870    ^33880    ^33890              ^33910    ^33920    ^33930    ^33940    ^33950    ^33960    ^33970    ^33980    ^33990              ^34010    ^34020    ^34030    ^34040    ^34050    ^34060    ^34070    ^34080    ^34090              ^34110    ^34120    ^34130    ^34140    ^34150    ^34160    ^34170    ^34180    ^34190              ^34210    ^34220    ^34230    ^34240    ^34250    ^34260    ^34270    ^34280    ^34290              ^34310    ^34320    ^34330    ^34340    ^34350    ^34360    ^34370    ^34380    ^34390              ^34410    ^34420    ^34430    ^34440    ^34450    ^34460    ^34470    ^34480    ^34490              ^34510    ^34520    ^34530    ^34540    ^34550    ^34560    ^34570    ^34580    ^34590              ^34610    ^34620    ^34630    ^34640    ^34650    ^34660    ^34670    ^34680    ^34690              ^34710    ^34720    ^34730    ^34740    ^34750    ^34760    ^34770    ^34780    ^34790              ^34810    ^34820    ^34830    ^34840    ^34850    ^34860    ^34870    ^34880    ^34890              ^34910    ^34920    ^34930    ^34940    ^34950    ^34960    ^34970    ^34980    ^34990              ^35010    ^35020    ^35030    ^35040    ^35050    ^35060    ^35070    ^35080    ^35090              ^35110    ^35120    ^35130    ^35140    ^35150    ^35160    ^35170    ^35180    ^35190              ^35210    ^35220    ^35230    ^35240    ^35250    ^35260    ^35270    ^35280    ^35290              ^35310    ^35320    ^35330    ^35340    ^35350    ^35360    ^35370    ^35380    ^35390              ^35410    ^35420    ^35430    ^35440    ^35450    ^35460    ^35470    ^35480    ^35490              ^35510    ^35520    ^35530    ^35540    ^35550    ^35560    ^35570    ^35580    ^35590              ^35610    ^35620    ^35630    ^35640    ^35650    ^35660    ^35670    ^35680    ^35690              ^35710    ^35720    ^35730    ^35740    ^35750    ^35760    ^35770    ^35780    ^35790              ^35810    ^35820    ^35830    ^35840    ^35850    ^35860    ^35870    ^35880    ^35890              ^35910    ^35920    ^35930    ^35940    ^35950    ^35960    ^35970    ^35980    ^35990              ^36010    ^36020    ^36030    ^36040    ^36050    ^36060    ^36070    ^36080    ^36090              ^36110    ^36120    ^36130    ^36140    ^36150    ^36160    ^36170    ^36180    ^36190              ^36210    ^36220    ^36230    ^36240    ^36250    ^36260    ^36270    ^36280    ^36290              ^36310    ^36320    ^36330    ^36340    ^36350    ^36360    ^36370    ^36380    ^36390              ^36410    ^36420    ^36430    ^36440    ^36450    ^36460    ^36470    ^36480    ^36490              ^36510    ^36520    ^36530    ^36540    ^36550    ^36560    ^36570    ^36580    ^36590              ^36610    ^36620    ^36630    ^36640    ^36650    ^36660    ^36670    ^36680    ^36690              ^36710    ^36720    ^36730    ^36740    ^36750    ^36760    ^36770    ^36780    ^36790              ^36810    ^36820    ^36830    ^36840    ^36850    ^36860    ^36870    ^36880    ^36890              ^36910    ^36920    ^36930    ^36940    ^36950    ^36960    ^36970    ^36980    ^36990              ^37010    ^37020    ^37030    ^37040    ^37050    ^37060    ^37070    ^37080    ^37090              ^37110    ^37120    ^37130    ^37140    ^37150    ^37160    ^37170    ^37180    ^37190              ^37210    ^37220    ^37230    ^37240    ^37250    ^37260    ^37270    ^37280    ^37290              ^37310    ^37320    ^37330    ^37340    ^37350    ^37360    ^37370    ^37380    ^37390              ^37410    ^37420    ^37430    ^37440    ^37450    ^37460    ^37470    ^37480    ^37490              ^37510    ^37520    ^37530    ^37540    ^37550    ^37560    ^37570    ^37580    ^37590              ^37610    ^37620    ^37630    ^37640    ^37650    ^37660    ^37670    ^37680    ^37690              ^37710    ^37720    ^37730    ^37740    ^37750    ^37760    ^37770    ^37780    ^37790              ^37810    ^37820    ^37830    ^37840    ^37850    ^37860    ^37870    ^37880    ^37890              ^37910    ^37920    ^37930    ^37940    ^37950    ^37960    ^37970    ^37980    ^37990              ^38010    ^38020    ^38030    ^38040    ^38050    ^38060    ^38070    ^38080    ^38090              ^38110    ^38120    ^38130    ^38140    ^38150    ^38160    ^38170    ^38180    ^38190              ^38210    ^38220    ^38230    ^38240    ^38250    ^38260    ^38270    ^38280    ^38290              ^38310    ^38320    ^38330    ^38340    ^38350    ^38360    ^38370    ^38380    ^38390              ^38410    ^38420    ^38430    ^38440    ^38450    ^38460    ^38470    ^38480    ^38490              ^38510    ^38520    ^38530    ^38540    ^38550    ^38560    ^38570    ^38580    ^38590              ^38610    ^38620    ^38630    ^38640    ^38650    ^38660    ^38670    ^38680    ^38690              ^38710    ^38720    ^38730    ^38740    ^38750    ^38760    ^38770    ^38780    ^38790              ^38810    ^38820    ^38830    ^38840    ^38850    ^38860    ^38870    ^38880    ^38890              ^38910    ^38920    ^38930    ^38940    ^38950    ^38960    ^38970    ^38980    ^38990              ^39010    ^39020    ^39030    ^39040    ^39050    ^39060    ^39070    ^39080    ^39090              ^39110    ^39120    ^39130    ^39140    ^39150    ^39160    ^39170    ^39180    ^39190              ^39210    ^39220    ^39230    ^39240    ^39250    ^39260    ^39270    ^39280    ^39290              ^39310    ^39320    ^39330    ^39340    ^39350    ^39360    ^39370    ^39380    ^39390              ^39410    ^39420    ^39430    ^39440    ^39450    ^39460    ^39470    ^39480    ^39490              ^39510    ^39520    ^39530    ^39540    ^39550    ^39560    ^39570    ^39580    ^39590              ^39610    ^39620    ^39630    ^39640    ^39650    ^39660    ^39670    ^39680    ^39690              ^39710    ^39720    ^39730    ^39740    ^39750    ^39760    ^39770    ^39780    ^39790              ^39810    ^39820    ^39830    ^39840    ^39850    ^39860    ^39870    ^39880    ^39890              ^39910    ^39920    ^39930    ^39940    ^39950    ^39960    ^39970    ^39980    ^39990              ^40010    ^40020    ^40030    ^40040    ^40050    ^40060    ^40070    ^40080    ^40090              ^40110    ^40120    ^40130    ^40140    ^40150    ^40160    ^40170    ^40180    ^40190              ^40210    ^40220    ^40230    ^40240    ^40250    ^40260    ^40270    ^40280    ^40290              ^40310    ^40320    ^40330    ^40340    ^40350    ^40360    ^40370    ^40380    ^40390              ^40410    ^40420    ^40430    ^40440    ^40450    ^40460    ^40470    ^40480    ^40490              ^40510    ^40520    ^40530    ^40540    ^40550    ^40560    ^40570    ^40580    ^40590              ^40610    ^40620    ^40630    ^40640    ^40650    ^40660    ^40670    ^40680    ^40690              ^40710    ^40720    ^40730    ^40740    ^40750    ^40760    ^40770    ^40780    ^40790              ^40810    ^40820    ^40830    ^40840    ^40850    ^40860    ^40870    ^40880    ^40890              ^40910    ^40920    ^40930    ^40940    ^40950    ^40960    ^40970    ^40980    ^40990              ^41010    ^41020    ^41030    ^41040    ^41050    ^41060    ^41070    ^41080    ^41090              ^41110    ^41120    ^41130    ^41140    ^41150    ^41160    ^41170    ^41180    ^41190              ^41210    ^41220    ^41230    ^41240    ^41250    ^41260    ^41270    ^41280    ^41290              ^41310    ^41320    ^41330    ^41340    ^41350    ^41360    ^41370    ^41380    ^41390              ^41410    ^41420    ^41430    ^41440    ^41450    ^41460    ^41470    ^41480    ^41490              ^41510    ^41520    ^41530    ^41540    ^41550    ^41560    ^41570    ^41580    ^41590              ^41610    ^41620    ^41630    ^41640    ^41650    ^41660    ^41670    ^41680    ^41690              ^41710    ^41720    ^41730    ^41740    ^41750    ^41760    ^41770    ^41780    ^41790              ^41810    ^41820    ^41830    ^41840    ^41850    ^41860    ^41870    ^41880    ^41890              ^41910    ^41920    ^41930    ^41940    ^41950    ^41960    ^41970    ^41980    ^41990              ^42010    ^42020    ^42030    ^42040    ^42050    ^42060    ^42070    ^42080    ^42090              ^42110    ^42120    ^42130    ^42140    ^42150    ^42160    ^42170    ^42180    ^42190              ^42210    ^42220    ^42230    ^42240    ^42250    ^42260    ^42270    ^42280    ^42290              ^42310    ^42320    ^42330    ^42340    ^42350    ^42360    ^42370    ^42380    ^42390              ^42410    ^42420    ^42430    ^42440    ^42450    ^42460    ^42470    ^42480    ^42490              ^42510    ^42520    ^42530    ^42540    ^42550    ^42560    ^42570    ^42580    ^42590              ^42610    ^42620    ^42630    ^42640    ^42650    ^42660    ^42670    ^42680    ^42690              ^42710    ^42720    ^42730    ^42740    ^42750    ^42760    ^42770    ^42780    ^42790              ^42810    ^42820    ^42830    ^42840    ^42850    ^42860    ^42870    ^42880    ^42890              ^42910    ^42920    ^42930    ^42940    ^42950    ^42960    ^42970    ^42980    ^42990              ^43010    ^43020    ^43030    ^43040    ^43050    ^43060    ^43070    ^43080    ^43090              ^43110    ^43120    ^43130    ^43140    ^43150    ^43160    ^43170    ^43180    ^43190              ^43210    ^43220    ^43230    ^43240    ^43250    ^43260    ^43270    ^43280    ^43290              ^43310    ^43320    ^43330    ^43340    ^43350    ^43360    ^43370    ^43380    ^43390              ^43410    ^43420    ^43430    ^43440    ^43450    ^43460    ^43470    ^43480    ^43490              ^43510    ^43520    ^43530    ^43540    ^43550    ^43560    ^43570    ^43580    ^43590              ^43610    ^43620    ^43630    ^43640    ^43650    ^43660    ^43670    ^43680    ^43690              ^43710    ^43720    ^43730    ^43740    ^43750    ^43760    ^43770    ^43780    ^43790              ^43810    ^43820    ^43830    ^43840    ^43850    ^43860    ^43870    ^43880    ^43890              ^43910    ^43920    ^43930    ^43940    ^43950    ^43960    ^43970    ^43980    ^43990              ^44010    ^44020    ^44030    ^44040    ^44050    ^44060    ^44070    ^44080    ^44090              ^44110    ^44120    ^44130    ^44140    ^44150    ^44160    ^44170    ^44180    ^44190              ^44210    ^44220    ^44230    ^44240    ^44250    ^44260    ^44270    ^44280    ^44290              ^44310    ^44320    ^44330    ^44340    ^44350    ^44360    ^44370    ^44380    ^44390              ^44410    ^44420    ^44430    ^44440    ^44450    ^44460    ^44470    ^44480    ^44490              ^44510    ^44520    ^44530    ^44540    ^44550    ^44560    ^44570    ^44580    ^44590              ^44610    ^44620    ^44630    ^44640    ^44650    ^44660    ^44670    ^44680    ^44690              ^44710    ^44720    ^44730    ^44740    ^44750    ^44760    ^44770    ^44780    ^44790              ^44810    ^44820    ^44830    ^44840    ^44850    ^44860    ^44870    ^44880    ^44890              ^44910    ^44920    ^44930    ^44940    ^44950    ^44960    ^44970    ^44980    ^44990              ^45010    ^45020    ^45030    ^45040    ^45050    ^45060    ^45070    ^45080    ^45090              ^45110    ^45120    ^45130    ^45140    ^45150    ^45160    ^45170    ^45180    ^45190              ^45210    ^45220    ^45230    ^45240    ^45250    ^45260    ^45270    ^45280    ^45290              ^45310    ^45320    ^45330    ^45340    ^45350    ^45360    ^45370    ^45380    ^45390              ^45410    ^45420    ^45430    ^45440    ^45450    ^45460    ^45470    ^45480    ^45490              ^45510    ^45520    ^45530    ^45540    ^45550    ^45560    ^45570    ^45580    ^45590              ^45610    ^45620    ^45630    ^45640    ^45650    ^45660    ^45670    ^45680    ^45690              ^45710    ^45720    ^45730    ^45740    ^45750    ^45760    ^45770    ^45780    ^45790              ^45810    ^45820    ^45830    ^45840    ^45850    ^45860    ^45870    ^45880    ^45890              ^45910    ^45920    ^45930    ^45940    ^45950    ^45960    ^45970    ^45980    ^45990              ^46010    ^46020    ^46030    ^46040    ^46050    ^46060    ^46070    ^46080    ^46090              ^46110    ^46120    ^46130    ^46140    ^46150    ^46160    ^46170    ^46180    ^46190              ^46210    ^46220    ^46230    ^46240    ^46250    ^46260    ^46270    ^46280    ^46290              ^46310    ^46320    ^46330    ^46340    ^46350    ^46360    ^46370    ^46380    ^46390              ^46410    ^46420    ^46430    ^46440    ^46450    ^46460    ^46470    ^46480    ^46490              ^46510    ^46520    ^46530    ^46540    ^46550    ^46560    ^46570    ^46580    ^46590              ^46610    ^46620    ^46630    ^46640    ^46650    ^46660    ^46670    ^46680    ^46690              ^46710    ^46720    ^46730    ^46740    ^46750    ^46760    ^46770    ^46780    ^46790              ^46810    ^46820    ^46830    ^46840    ^46850    ^46860    ^46870    ^46880    ^46890              ^46910    ^46920    ^46930    ^46940    ^46950    ^46960    ^46970    ^46980    ^46990              ^47010    ^47020    ^47030    ^47040    ^47050    ^47060    ^47070    ^47080    ^47090              ^47110    ^47120    ^47130    ^47140    ^47150    ^47160    ^47170    ^47180    ^47190              ^47210    ^47220    ^47230    ^47240    ^47250    ^47260    ^47270    ^47280    ^47290              ^47310    ^47320    ^47330    ^47340    ^47350    ^47360    ^47370    ^47380    ^47390              ^47410    ^47420    ^47430    ^47440    ^47450    ^47460    ^47470    ^47480    ^47490              ^47510    ^47520    ^47530    ^47540    ^47550    ^47560    ^47570    ^47580    ^47590              ^47610    ^47620    ^47630    ^47640    ^47650    ^47660    ^47670    ^47680    ^47690              ^47710    ^47720    ^47730    ^47740    ^47750    ^47760    ^47770    ^47780    ^47790              ^47810    ^47820    ^47830    ^47840    ^47850    ^47860    ^47870    ^47880    ^47890              ^47910    ^47920    ^47930    ^47940    ^47950    ^47960    ^47970    ^47980    ^47990              ^48010    ^48020    ^48030    ^48040    ^48050    ^48060    ^48070    ^48080    ^48090              ^48110    ^48120    ^48130    ^48140    ^48150    ^48160    ^48170    ^48180    ^48190              ^48210    ^48220    ^48230    ^48240    ^48250    ^48260    ^48270    ^48280    ^48290              ^48310    ^48320    ^48330    ^48340    ^48350    ^48360    ^48370    ^48380    ^48390              ^48410    ^48420    ^48430    ^48440    ^48450    ^48460    ^48470    ^48480    ^48490              ^48510    ^48520    ^48530    ^48540    ^48550    ^48560    ^48570    ^48580    ^48590              ^48610    ^48620    ^48630    ^48640    ^48650    ^48660    ^48670    ^48680    ^48690              ^48710    ^48720    ^48730    ^48740    ^48750    ^48760    ^48770    ^48780    ^48790              ^48810    ^48820    ^48830    ^48840    ^48850    ^48860    ^48870    ^48880    ^48890              ^48910    ^48920    ^48930    ^48940    ^48950    ^48960    ^48970    ^48980    ^48990              ^49010    ^49020    ^49030    ^49040    ^49050    ^49060    ^49070    ^49080    ^49090              ^49110    ^49120    ^49130    ^49140    ^49150    ^49160    ^49170    ^49180    ^49190              ^49210    ^49220    ^49230    ^49240    ^49250    ^49260    ^49270    ^49280    ^49290              ^49310    ^49320    ^49330    ^49340    ^49350    ^49360    ^49370    ^49380    ^49390              ^49410    ^49420    ^49430    ^49440    ^49450    ^49460    ^49470    ^49480    ^49490              ^49510    ^49520    ^49530    ^49540    ^49550    ^49560    ^49570    ^49580    ^49590              ^49610    ^49620    ^49630    ^49640    ^49650    ^49660    ^49670    ^49680    ^49690              ^49710    ^49720    ^49730    ^49740    ^49750    ^49760    ^49770    ^49780    ^49790              ^49810    ^49820    ^49830    ^49840    ^49850    ^49860    ^49870    ^49880    ^49890              ^49910    ^49920    ^49930    ^49940    ^49950    ^49960    ^49970    ^49980    ^49990              ^50010    ^50020    ^50030    ^50040    ^50050    ^50060    ^50070    ^50080    ^50090              ^50110    ^50120    ^50130    ^50140    ^50150    ^50160    ^50170    ^50180    ^50190              ^50210    ^50220    ^50230    ^50240    ^50250    ^50260    ^50270    ^50280    ^50290              ^50310    ^50320    ^50330    ^50340    ^50350    ^50360    ^50370    ^50380    ^50390              ^50410    ^50420    ^50430    ^50440    ^50450    ^50460    ^50470    ^50480    ^50490              ^50510    ^50520    ^50530    ^50540    ^50550    ^50560    ^50570    ^50580    ^50590              ^50610    ^50620    ^50630    ^50640    ^50650    ^50660    ^50670    ^50680    ^50690              ^50710    ^50720    ^50730    ^50740    ^50750    ^50760    ^50770    ^50780    ^50790              ^50810    ^50820    ^50830    ^50840    ^50850    ^50860    ^50870    ^50880    ^50890              ^50910    ^50920    ^50930    ^50940    ^50950    ^50960    ^50970    ^50980    ^50990              ^51010    ^51020    ^51030    ^51040    ^51050    ^51060    ^51070    ^51080    ^51090              ^51110    ^51120    ^51130    ^51140    ^51150    ^51160    ^51170    ^51180    ^51190              ^51210    ^51220    ^51230    ^51240    ^51250    ^51260    ^51270    ^51280    ^51290              ^51310    ^51320    ^51330    ^51340    ^51350    ^51360    ^51370    ^51380    ^51390              ^51410    ^51420    ^51430    ^51440    ^51450    ^51460    ^51470    ^51480    ^51490              ^51510    ^51520    ^51530    ^51540    ^51550    ^51560    ^51570    ^51580    ^51590              ^51610    ^51620    ^51630    ^51640    ^51650    ^51660    ^51670    ^51680    ^51690              ^51710    ^51720    ^51730    ^51740    ^51750    ^51760    ^51770    ^51780    ^51790              ^51810    ^51820    ^51830    ^51840    ^51850    ^51860    ^51870    ^51880    ^51890              ^51910    ^51920    ^51930    ^51940    ^51950    ^51960    ^51970    ^51980    ^51990              ^52010    ^52020    ^52030    ^52040    ^52050    ^52060    ^52070    ^52080    ^52090              ^52110    ^52120    ^52130    ^52140    ^52150    ^52160    ^52170    ^52180    ^52190              ^52210    ^52220    ^52230    ^52240    ^52250    ^52260    ^52270    ^52280    ^52290              ^52310    ^52320    ^52330    ^52340    ^52350    ^52360    ^52370    ^52380    ^52390              ^52410    ^52420    ^52430    ^52440    ^52450    ^52460    ^52470    ^52480    ^52490              ^52510    ^52520    ^52530    ^52540    ^52550    ^52560    ^52570    ^52580    ^52590              ^52610    ^52620    ^52630    ^52640    ^52650    ^52660    ^52670    ^52680    ^52690              ^52710    ^52720    ^52730    ^52740    ^52750    ^52760    ^52770    ^52780    ^52790              ^52810    ^52820    ^52830    ^52840    ^52850    ^52860    ^52870    ^52880    ^52890              ^52910    ^52920    ^52930    ^52940    ^52950    ^52960    ^52970    ^52980    ^52990              ^53010    ^53020    ^53030    ^53040    ^53050    ^53060    ^53070    ^53080    ^53090              ^53110    ^53120    ^53130    ^53140    ^53150    ^53160    ^53170    ^53180    ^53190              ^53210    ^53220    ^53230    ^53240    ^53250    ^53260    ^53270    ^53280    ^53290              ^53310    ^53320    ^53330    ^53340    ^53350    ^53360    ^53370    ^53380    ^53390              ^53410    ^53420    ^53430    ^53440    ^53450    ^53460    ^53470    ^53480    ^53490              ^53510    ^53520    ^53530    ^53540    ^53550    ^53560    ^53570    ^53580    ^53590              ^53610    ^53620    ^53630    ^53640    ^53650    ^53660    ^53670    ^53680    ^53690              ^53710    ^53720    ^53730    ^53740    ^53750    ^53760    ^53770    ^53780    ^53790              ^53810    ^53820    ^53830    ^53840    ^53850    ^53860    ^53870    ^53880    ^53890              ^53910    ^53920    ^53930    ^53940    ^53950    ^53960    ^53970    ^53980    ^53990              ^54010    ^54020    ^54030    ^54040    ^54050    ^54060    ^54070    ^54080    ^54090              ^54110    ^54120    ^54130    ^54140    ^54150    ^54160    ^54170    ^54180    ^54190              ^54210    ^54220    ^54230    ^54240    ^54250    ^54260    ^54270    ^54280    ^54290              ^54310    ^54320    ^54330    ^54340    ^54350    ^54360    ^54370    ^54380    ^54390              ^54410    ^54420    ^54430    ^54440    ^54450    ^54460    ^54470    ^54480    ^54490              ^54510    ^54520    ^54530    ^54540    ^54550    ^54560    ^54570    ^54580    ^54590              ^54610    ^54620    ^54630    ^54640    ^54650    ^54660    ^54670    ^54680    ^54690              ^54710    ^54720    ^54730    ^54740    ^54750    ^54760    ^54770    ^54780    ^54790              ^54810    ^54820    ^54830    ^54840    ^54850    ^54860    ^54870    ^54880    ^54890              ^54910    ^54920    ^54930    ^54940    ^54950    ^54960    ^54970    ^54980    ^54990              ^55010    ^55020    ^55030    ^55040    ^55050    ^55060    ^55070    ^55080    ^55090              ^55110    ^55120    ^55130    ^55140    ^55150    ^55160    ^55170    ^55180    ^55190              ^55210    ^55220    ^55230    ^55240    ^55250    ^55260    ^55270    ^55280    ^55290              ^55310    ^55320    ^55330    ^55340    ^55350    ^55360    ^55370    ^55380    ^55390              ^55410    ^55420    ^55430    ^55440    ^55450    ^55460    ^55470    ^55480    ^55490              ^55510    ^55520    ^55530    ^55540    ^55550    ^55560    ^55570    ^55580    ^55590              ^55610    ^55620    ^55630    ^55640    ^55650    ^55660    ^55670    ^55680    ^55690              ^55710    ^55720    ^55730    ^55740    ^55750    ^55760    ^55770    ^55780    ^55790              ^55810    ^55820    ^55830    ^55840    ^55850    ^55860    ^55870    ^55880    ^55890              ^55910    ^55920    ^55930    ^55940    ^55950    ^55960    ^55970    ^55980    ^55990              ^56010    ^56020    ^56030    ^56040    ^56050    ^56060    ^56070    ^56080    ^56090              ^56110    ^56120    ^56130    ^56140    ^56150    ^56160    ^56170    ^56180    ^56190              ^56210    ^56220    ^56230    ^56240    ^56250    ^56260    ^56270    ^56280    ^56290              ^56310    ^56320    ^56330    ^56340    ^56350    ^56360    ^56370    ^56380    ^56390              ^56410    ^56420    ^56430    ^56440    ^56450    ^56460    ^56470    ^56480    ^56490              ^56510    ^56520    ^56530    ^56540    ^56550    ^56560    ^56570    ^56580    ^56590              ^56610    ^56620    ^56630    ^56640    ^56650    ^56660    ^56670    ^56680    ^56690              ^56710    ^56720    ^56730    ^56740    ^56750    ^56760    ^56770    ^56780    ^56790              ^56810    ^56820    ^56830    ^56840    ^56850    ^56860    ^56870    ^56880    ^56890              ^56910    ^56920    ^56930    ^56940    ^56950    ^56960    ^56970    ^56980    ^56990              ^57010    ^57020    ^57030    ^57040    ^57050    ^57060    ^57070    ^57080    ^57090              ^57110    ^57120    ^57130    ^57140    ^57150    ^57160    ^57170    ^57180    ^57190              ^57210    ^57220    ^57230    ^57240    ^57250    ^57260    ^57270    ^57280    ^57290              ^57310    ^57320    ^57330    ^57340    ^57350    ^57360    ^57370    ^57380    ^57390              ^57410    ^57420    ^57430    ^57440    ^57450    ^57460    ^57470    ^57480    ^57490              ^57510    ^57520    ^57530    ^57540    ^57550    ^57560    ^57570    ^57580    ^57590              ^57610    ^57620    ^57630    ^57640    ^57650    ^57660    ^57670    ^57680    ^57690              ^57710    ^57720    ^57730    ^57740    ^57750    ^57760    ^57770    ^57780    ^57790              ^57810    ^57820    ^57830    ^57840    ^57850    ^57860    ^57870    ^57880    ^57890              ^57910    ^57920    ^57930    ^57940    ^57950    ^57960    ^57970    ^57980    ^57990              ^58010    ^58020    ^58030    ^58040    ^58050    ^58060    ^58070    ^58080    ^58090              ^58110    ^58120    ^58130    ^58140    ^58150    ^58160    ^58170    ^58180    ^58190              ^58210    ^58220    ^58230    ^58240    ^58250    ^58260    ^58270    ^58280    ^58290              ^58310    ^58320    ^58330    ^58340    ^58350    ^58360    ^58370    ^58380    ^58390              ^58410    ^58420    ^58430    ^58440    ^58450    ^58460    ^58470    ^58480    ^58490              ^58510    ^58520    ^58530    ^58540    ^58550    ^58560    ^58570    ^58580    ^58590              ^58610    ^58620    ^58630    ^58640    ^58650    ^58660    ^58670    ^58680    ^58690              ^58710    ^58720    ^58730    ^58740    ^58750    ^58760    ^58770    ^58780    ^58790              ^58810    ^58820    ^58830    ^58840    ^58850    ^58860    ^58870    ^58880    ^58890              ^58910    ^58920    ^58930    ^58940    ^58950    ^58960    ^58970    ^58980    ^58990              ^59010    ^59020    ^59030    ^59040    ^59050    ^59060    ^59070    ^59080    ^59090              ^59110    ^59120    ^59130    ^59140    ^59150    ^59160    ^59170    ^59180    ^59190              ^59210    ^59220    ^59230    ^59240    ^59250    ^59260    ^59270    ^59280    ^59290              ^59310    ^59320    ^59330    ^59340    ^59350    ^59360    ^59370    ^59380    ^59390              ^59410    ^59420    ^59430    ^59440    ^59450    ^59460    ^59470    ^59480    ^59490              ^59510    ^59520    ^59530    ^59540    ^59550    ^59560    ^59570    ^59580    ^59590              ^59610    ^59620    ^59630    ^59640    ^59650    ^59660    ^59670    ^59680    ^59690              ^59710    ^59720    ^59730    ^59740    ^59750    ^59760    ^59770    ^59780    ^59790              ^59810    ^59820    ^59830    ^59840    ^59850    ^59860    ^59870    ^59880    ^59890              ^59910    ^59920    ^59930    ^59940    ^59950    ^59960    ^59970    ^59980    ^59990              ^60010    ^60020    ^60030    ^60040    ^60050    ^60060    ^60070    ^60080    ^60090              ^60110    ^60120    ^60130    ^60140    ^60150    ^60160    ^60170    ^60180    ^60190              ^60210    ^60220    ^60230    ^60240    ^60250    ^60260    ^60270    ^60280    ^60290              ^60310    ^60320    ^60330    ^60340    ^60350    ^60360    ^60370    ^60380    ^60390              ^60410    ^60420    ^60430    ^60440    ^60450    ^60460    ^60470    ^60480    ^60490              ^60510    ^60520    ^60530    ^60540    ^60550    ^60560    ^60570    ^60580    ^60590              ^60610    ^60620    ^60630    ^60640    ^60650    ^60660    ^60670    ^60680    ^60690              ^60710    ^60720    ^60730    ^60740    ^60750    ^60760    ^60770    ^60780    ^60790              ^60810    ^60820    ^60830    ^60840    ^60850    ^60860    ^60870    ^60880    ^60890              ^60910    ^60920    ^60930    ^60940    ^60950    ^60960    ^60970    ^60980    ^60990              ^61010    ^61020    ^61030    ^61040    ^61050    ^61060    ^61070    ^61080    ^61090              ^61110    ^61120    ^61130    ^61140    ^61150    ^61160    ^61170    ^61180    ^61190              ^61210    ^61220    ^61230    ^61240    ^61250    ^61260    ^61270    ^61280    ^61290              ^61310    ^61320    ^61330    ^61340    ^61350    ^61360    ^61370    ^61380    ^61390              ^61410    ^61420    ^61430    ^61440    ^61450    ^61460    ^61470    ^61480    ^61490              ^61510    ^61520    ^61530    ^61540    ^61550    ^61560    ^61570    ^61580    ^61590              ^61610    ^61620    ^61630    ^61640    ^61650    ^61660    ^61670    ^61680    ^61690              ^61710    ^61720    ^61730    ^61740    ^61750    ^61760    ^61770    ^61780    ^61790              ^61810    ^61820    ^61830    ^61840    ^61850    ^61860    ^61870    ^61880    ^61890              ^61910    ^61920    ^61930    ^61940    ^61950    ^61960    ^61970    ^61980    ^61990              ^62010    ^62020    ^62030    ^62040    ^62050    ^62060    ^62070    ^62080    ^62090              ^62110    ^62120    ^62130    ^62140    ^62150    ^62160    ^62170    ^62180    ^62190              ^62210    ^62220    ^62230    ^62240    ^62250    ^62260    ^62270    ^62280    ^62290              ^62310    ^62320    ^62330    ^62340    ^62350    ^62360    ^62370    ^62380    ^62390              ^62410    ^62420    ^62430    ^62440    ^62450    ^62460    ^62470    ^62480    ^62490              ^62510    ^62520    ^62530    ^62540    ^62550    ^62560    ^62570    ^62580    ^62590              ^62610    ^62620    ^62630    ^62640    ^62650    ^62660    ^62670    ^62680    ^62690              ^62710    ^62720    ^62730    ^62740    ^62750    ^62760    ^62770    ^62780    ^62790              ^62810    ^62820    ^62830    ^62840    ^62850    ^62860    ^62870    ^62880    ^62890              ^62910    ^62920    ^62930    ^62940    ^62950    ^62960    ^62970    ^62980    ^62990              ^63010    ^63020    ^63030    ^63040    ^63050    ^63060    ^63070    ^63080    ^63090              ^63110    ^63120    ^63130    ^63140    ^63150    ^63160    ^63170    ^63180    ^63190              ^63210    ^63220    ^63230    ^63240    ^63250    ^63260    ^63270    ^63280    ^63290              ^63310    ^63320    ^63330    ^63340    ^63350    ^63360    ^63370    ^63380    ^63390              ^63410    ^63420    ^63430    ^63440    ^63450    ^63460    ^63470    ^63480    ^63490              ^63510    ^63520    ^63530    ^63540    ^63550    ^63560    ^63570    ^63580    ^63590              ^63610    ^63620    ^63630    ^63640    ^63650    ^63660    ^63670    ^63680    ^63690              ^63710    ^63720    ^63730    ^63740    ^63750    ^63760    ^63770    ^63780    ^63790              ^63810    ^63820    ^63830    ^63840    ^63850    ^63860    ^63870    ^63880    ^63890              ^63910    ^63920    ^63930    ^63940    ^63950    ^63960    ^63970    ^63980    ^63990              ^64010    ^64020    ^64030    ^64040    ^64050    ^64060    ^64070    ^64080    ^64090              ^64110    ^64120    ^64130    ^64140    ^64150    ^64160    ^64170    ^64180    ^64190              ^64210    ^64220    ^64230    ^64240    ^64250    ^64260    ^64270    ^64280    ^64290              ^64310    ^64320    ^64330    ^64340    ^64350    ^64360    ^64370    ^64380    ^64390              ^64410    ^64420    ^64430    ^64440    ^64450    ^64460    ^64470    ^64480    ^64490              ^64510    ^64520    ^64530    ^64540    ^64550    ^64560    ^64570    ^64580    ^64590              ^64610    ^64620    ^64630    ^64640    ^64650    ^64660    ^64670    ^64680    ^64690              ^64710    ^64720    ^64730    ^64740    ^64750    ^64760    ^64770    ^64780    ^64790              ^64810    ^64820    ^64830    ^64840    ^64850    ^64860    ^64870    ^64880    ^64890              ^64910    ^64920    ^64930    ^64940    ^64950    ^64960    ^64970    ^64980    ^64990              ^65010    ^65020    ^65030    ^65040    ^65050    ^65060    ^65070    ^65080    ^65090              ^65110    ^65120    ^65130    ^65140    ^65150    ^65160    ^65170    ^65180    ^65190              ^65210    ^65220    ^65230    ^65240    ^65250    ^65260    ^65270    ^65280    ^65290              ^65310    ^65320    ^65330    ^65340    ^65350    ^65360    ^65370    ^65380    ^65390              ^65410    ^65420    ^65430    ^65440    ^65450    ^65460    ^65470    ^65480    ^65490              ^65510    ^65520    ^65530    ^65540    ^65550    ^65560    ^65570    ^65580    ^65590              ^65610    ^65620    ^65630    ^65640    ^65650    ^65660    ^65670    ^65680    ^65690              ^65710    ^65720    ^65730    ^65740    ^65750    ^65760    ^65770    ^65780    ^65790              ^65810    ^65820    ^65830    ^65840    ^65850    ^65860    ^65870    ^65880    ^65890              ^65910    ^65920    ^65930    ^65940    ^65950    ^65960    ^65970    ^65980    ^65990              ^66010    ^66020    ^66030    ^66040    ^66050    ^66060    ^66070    ^66080    ^66090              ^66110    ^66120    ^66130    ^66140    ^66150    ^66160    ^66170    ^66180    ^66190              ^66210    ^66220    ^66230    ^66240    ^66250    ^66260    ^66270    ^66280    ^66290              ^66310    ^66320    ^66330    ^66340    ^66350    ^66360    ^66370    ^66380    ^66390              ^66410    ^66420    ^66430    ^66440    ^66450    ^66460    ^66470    ^66480    ^66490              ^66510    ^66520    ^66530    ^66540    ^66550    ^66560    ^66570    ^66580    ^66590              ^66610    ^66620    ^66630    ^66640    ^66650    ^66660    ^66670    ^66680    ^66690              ^66710    ^66720    ^66730    ^66740    ^66750    ^66760    ^66770    ^66780    ^66790              ^66810    ^66820    ^66830    ^66840    ^66850    ^66860    ^66870    ^66880    ^66890              ^66910    ^66920    ^66930    ^66940    ^66950    ^66960    ^66970    ^66980    ^66990              ^67010    ^67020    ^67030    ^67040    ^67050    ^67060    ^67070    ^67080    ^67090              ^67110    ^67120    ^67130    ^67140    ^67150    ^67160    ^67170    ^67180    ^67190              ^67210    ^67220    ^67230    ^67240    ^67250    ^67260    ^67270    ^67280    ^67290              ^67310    ^67320    ^67330    ^67340    ^67350    ^67360    ^67370    ^67380    ^67390              ^67410    ^67420    ^67430    ^67440    ^67450    ^67460    ^67470    ^67480    ^67490              ^67510    ^67520    ^67530    ^67540    ^67550    ^67560    ^67570    ^67580    ^67590              ^67610    ^67620    ^67630    ^67640    ^67650    ^67660    ^67670    ^67680    ^67690              ^67710    ^67720    ^67730    ^67740    ^67750    ^67760    ^67770    ^67780    ^67790              ^67810    ^67820    ^67830    ^67840    ^67850    ^67860    ^67870    ^67880    ^67890              ^67910    ^67920    ^67930    ^67940    ^67950    ^67960    ^67970    ^67980    ^67990              ^68010    ^68020    ^68030    ^68040    ^68050    ^68060    ^68070    ^68080    ^68090              ^68110    ^68120    ^68130    ^68140    ^68150    ^68160    ^68170    ^68180    ^68190              ^68210    ^68220    ^68230    ^68240    ^68250    ^68260    ^68270    ^68280    ^68290              ^68310    ^68320    ^68330    ^68340    ^68350    ^68360    ^68370    ^68380    ^68390              ^68410    ^68420    ^68430    ^68440    ^68450    ^68460    ^68470    ^68480    ^68490              ^68510    ^68520    ^68530    ^68540    ^68550    ^68560    ^68570    ^68580    ^68590              ^68610    ^68620    ^68630    ^68640    ^68650    ^68660    ^68670    ^68680    ^68690              ^68710    ^68720    ^68730    ^68740    ^68750    ^68760    ^68770    ^68780    ^68790              ^68810    ^68820    ^68830    ^68840    ^68850    ^68860    ^68870    ^68880    ^68890              ^68910    ^68920    ^68930    ^68940    ^68950    ^68960    ^68970    ^68980    ^68990              ^69010    ^69020    ^69030    ^69040    ^69050    ^69060    ^69070    ^69080    ^69090              ^69110    ^69120    ^69130    ^69140    ^69150    ^69160    ^69170    ^69180    ^69190              ^69210    ^69220    ^69230    ^69240    ^69250    ^69260    ^69270    ^69280    ^69290              ^69310    ^69320    ^69330    ^69340    ^69350    ^69360    ^69370    ^69380    ^69390              ^69410    ^69420    ^69430    ^69440    ^69450    ^69460    ^69470    ^69480    ^69490              ^69510    ^69520    ^69530    ^69540    ^69550    ^69560    ^69570    ^69580    ^69590              ^69610    ^69620    ^69630    ^69640    ^69650    ^69660    ^69670    ^69680    ^69690              ^69710    ^69720    ^69730    ^69740    ^69750    ^69760    ^69770    ^69780    ^69790              ^69810    ^69820    ^69830    ^69840    ^69850    ^69860    ^69870    ^69880    ^69890              ^69910    ^69920    ^69930    ^69940    ^69950    ^69960    ^69970    ^69980    ^69990              ^70010    ^70020    ^70030    ^70040    ^70050    ^70060    ^70070    ^70080    ^70090              ^70110    ^70120    ^70130    ^70140    ^70150    ^70160    ^70170    ^70180    ^70190              ^70210    ^70220    ^70230    ^70240    ^70250    ^70260    ^70270    ^70280    ^70290              ^70310    ^70320    ^70330    ^70340    ^70350    ^70360    ^70370    ^70380    ^70390              ^70410    ^70420    ^70430    ^70440    ^70450    ^70460    ^70470    ^70480    ^70490              ^70510    ^70520    ^70530    ^70540    ^70550    ^70560    ^70570    ^70580    ^70590              ^70610    ^70620    ^70630    ^70640    ^70650    ^70660    ^70670    ^70680    ^70690              ^70710    ^70720    ^70730    ^70740    ^70750    ^70760    ^70770    ^70780    ^70790              ^70810    ^70820    ^70830    ^70840    ^70850    ^70860    ^70870    ^70880    ^70890              ^70910    ^70920    ^70930    ^70940    ^70950    ^70960    ^70970    ^70980    ^70990              ^71010    ^71020    ^71030    ^71040    ^71050    ^71060    ^71070    ^71080    ^71090              ^71110    ^71120    ^71130    ^71140    ^71150    ^71160    ^71170    ^71180    ^71190              ^71210    ^71220    ^71230    ^71240    ^71250    ^71260    ^71270    ^71280    ^71290              ^71310    ^71320    ^71330    ^71340    ^71350    ^71360    ^71370    ^71380    ^71390              ^71410    ^71420    ^71430    ^71440    ^71450    ^71460    ^71470    ^71480    ^71490              ^71510    ^71520    ^71530    ^71540    ^71550    ^71560    ^71570    ^71580    ^71590              ^71610    ^71620    ^71630    ^71640    ^71650    ^71660    ^71670    ^71680    ^71690              ^71710    ^71720    ^71730    ^71740    ^71750    ^71760    ^71770    ^71780    ^71790              ^71810    ^71820    ^71830    ^71840    ^71850    ^71860    ^71870    ^71880    ^71890              ^71910    ^71920    ^71930    ^71940    ^71950    ^71960    ^71970    ^71980    ^71990              ^72010    ^72020    ^72030    ^72040    ^72050    ^72060    ^72070    ^72080    ^72090              ^72110    ^72120    ^72130    ^72140    ^72150    ^72160    ^72170    ^72180    ^72190              ^72210    ^72220    ^72230    ^72240    ^72250    ^72260    ^72270    ^72280    ^72290              ^72310    ^72320    ^72330    ^72340    ^72350    ^72360    ^72370    ^72380    ^72390              ^72410    ^72420    ^72430    ^72440    ^72450    ^72460    ^72470    ^72480    ^72490              ^72510    ^72520    ^72530    ^72540    ^72550    ^72560    ^72570    ^72580    ^72590              ^72610    ^72620    ^72630    ^72640    ^72650    ^72660    ^72670    ^72680    ^72690              ^72710    ^72720    ^72730    ^72740    ^72750    ^72760    ^72770    ^72780    ^72790              ^72810    ^72820    ^72830    ^72840    ^72850    ^72860    ^72870    ^72880    ^72890              ^72910    ^72920    ^72930    ^72940    ^72950    ^72960    ^72970    ^72980    ^72990              ^73010    ^73020    ^73030    ^73040    ^73050    ^73060    ^73070    ^73080    ^73090              ^73110    ^73120    ^73130    ^73140    ^73150    ^73160    ^73170    ^73180    ^73190              ^73210    ^73220    ^73230    ^73240    ^73250    ^73260    ^73270    ^73280    ^73290              ^73310    ^73320    ^73330    ^73340    ^73350    ^73360    ^73370    ^73380    ^73390              ^73410    ^73420    ^73430    ^73440    ^73450    ^73460    ^73470    ^73480    ^73490              ^73510    ^73520    ^73530    ^73540    ^73550    ^73560    ^73570    ^73580    ^73590              ^73610    ^73620    ^73630    ^73640    ^73650    ^73660    ^73670    ^73680    ^73690              ^73710    ^73720    ^73730    ^73740    ^73750    ^73760    ^73770    ^73780    ^73790              ^73810    ^73820    ^73830    ^73840    ^73850    ^73860    ^73870    ^73880    ^73890              ^73910    ^73920    ^73930    ^73940    ^73950    ^73960    ^73970    ^73980    ^73990              ^74010    ^74020    ^74030    ^74040    ^74050    ^74060    ^74070    ^74080    ^74090              ^74110    ^74120    ^74130    ^74140    ^74150    ^74160    ^74170    ^74180    ^74190              ^74210    ^74220    ^74230    ^74240    ^74250    ^74260    ^74270    ^74280    ^74290              ^74310    ^74320    ^74330    ^74340    ^74350    ^74360    ^74370    ^74380    ^74390              ^74410    ^74420    ^74430    ^74440    ^74450    ^74460    ^74470    ^74480    ^74490              ^74510    ^74520    ^74530    ^74540    ^74550    ^74560    ^74570    ^74580    ^74590              ^74610    ^74620    ^74630    ^74640    ^74650    ^74660    ^74670    ^74680    ^74690              ^74710    ^74720    ^74730    ^74740    ^74750    ^74760    ^74770    ^74780    ^74790              ^74810    ^74820    ^74830    ^74840    ^74850    ^74860    ^74870    ^74880    ^74890              ^74910    ^74920    ^74930    ^74940    ^74950    ^74960    ^74970    ^74980    ^74990              ^75010    ^75020    ^75030    ^75040    ^75050    ^75060    ^75070    ^75080    ^75090              ^75110    ^75120    ^75130    ^75140    ^75150    ^75160    ^75170    ^75180    ^75190              ^75210    ^75220    ^75230    ^75240    ^75250    ^75260    ^75270    ^75280    ^75290              ^75310    ^75320    ^75330    ^75340    ^75350    ^75360    ^75370    ^75380    ^75390              ^75410    ^75420    ^75430    ^75440    ^75450    ^75460    ^75470    ^75480    ^75490              ^75510    ^75520    ^75530    ^75540    ^75550    ^75560    ^75570    ^75580    ^75590              ^75610    ^75620    ^75630    ^75640    ^75650    ^75660    ^75670    ^75680    ^75690              ^75710    ^75720    ^75730    ^75740    ^75750    ^75760    ^75770    ^75780    ^75790              ^75810    ^75820    ^75830    ^75840    ^75850    ^75860    ^75870    ^75880    ^75890              ^75910    ^75920    ^75930    ^75940    ^75950    ^75960    ^75970    ^75980    ^75990              ^76010    ^76020    ^76030    ^76040    ^76050    ^76060    ^76070    ^76080    ^76090              ^76110    ^76120    ^76130    ^76140    ^76150    ^76160    ^76170    ^76180    ^76190              ^76210    ^76220    ^76230    ^76240    ^76250    ^76260    ^76270    ^76280    ^76290              ^76310    ^76320    ^76330    ^76340    ^76350    ^76360    ^76370    ^76380    ^76390              ^76410    ^76420    ^76430    ^76440    ^76450    ^76460    ^76470    ^76480    ^76490              ^76510    ^76520    ^76530    ^76540    ^76550    ^76560    ^76570    ^76580    ^76590              ^76610    ^76620    ^76630    ^76640    ^76650    ^76660    ^76670    ^76680    ^76690              ^76710    ^76720    ^76730    ^76740    ^76750    ^76760    ^76770    ^76780    ^76790              ^76810    ^76820    ^76830    ^76840    ^76850    ^76860    ^76870    ^76880    ^76890              ^76910    ^76920    ^76930    ^76940    ^76950    ^76960    ^76970    ^76980    ^76990              ^77010    ^77020    ^77030    ^77040    ^77050    ^77060    ^77070    ^77080    ^77090              ^77110    ^77120    ^77130    ^77140    ^77150    ^77160    ^77170    ^77180    ^77190              ^77210    ^77220    ^77230    ^77240    ^77250    ^77260    ^77270    ^77280    ^77290              ^77310    ^77320    ^77330    ^77340    ^77350    ^77360    ^77370    ^77380    ^77390              ^77410    ^77420    ^77430    ^77440    ^77450    ^77460    ^77470    ^77480    ^77490              ^77510    ^77520    ^77530    ^77540    ^77550    ^77560    ^77570    ^77580    ^77590              ^77610    ^77620    ^77630    ^77640    ^77650    ^77660    ^77670    ^77680    ^77690              ^77710    ^77720    ^77730    ^77740    ^77750    ^77760    ^77770    ^77780    ^77790              ^77810    ^77820    ^77830    ^77840    ^77850    ^77860    ^77870    ^77880    ^77890              ^77910    ^77920    ^77930    ^77940    ^77950    ^77960    ^77970    ^77980    ^77990              ^78010    ^78020    ^78030    ^78040    ^78050    ^78060    ^78070    ^78080    ^78090              ^78110    ^78120    ^78130    ^78140    ^78150    ^78160    ^78170    ^78180    ^78190              ^78210    ^78220    ^78230    ^78240    ^78250    ^78260    ^78270    ^78280    ^78290              ^78310    ^78320    ^78330    ^78340    ^78350    ^78360    ^78370    ^78380    ^78390              ^78410    ^78420    ^78430    ^78440    ^78450    ^78460    ^78470    ^78480    ^78490              ^78510    ^78520    ^78530    ^78540    ^78550    ^78560    ^78570    ^78580    ^78590              ^78610    ^78620    ^78630    ^78640    ^78650    ^78660    ^78670    ^78680    ^78690              ^78710    ^78720    ^78730    ^78740    ^78750    ^78760    ^78770    ^78780    ^78790              ^78810    ^78820    ^78830    ^78840    ^78850    ^78860    ^78870    ^78880    ^78890              ^78910    ^78920    ^78930    ^78940    ^78950    ^78960    ^78970    ^78980    ^78990              ^79010    ^79020    ^79030    ^79040    ^79050    ^79060    ^79070    ^79080    ^79090              ^79110    ^79120    ^79130    ^79140    ^79150    ^79160    ^79170    ^79180    ^79190              ^79210    ^79220    ^79230    ^79240    ^79250    ^79260    ^79270    ^79280    ^79290              ^79310    ^79320    ^79330    ^79340    ^79350    ^79360    ^79370    ^79380    ^79390              ^79410    ^79420    ^79430    ^79440    ^79450    ^79460    ^79470    ^79480    ^79490              ^79510    ^79520    ^79530    ^79540    ^79550    ^79560    ^79570    ^79580    ^79590              ^79610    ^79620    ^79630    ^79640    ^79650    ^79660    ^79670    ^79680    ^79690              ^79710    ^79720    ^79730    ^79740    ^79750    ^79760    ^79770    ^79780    ^79790              ^79810    ^79820    ^79830    ^79840    ^79850    ^79860    ^79870    ^79880    ^79890              ^79910    ^79920    ^79930    ^79940    ^79950    ^79960    ^79970    ^79980    ^79990              ^80010    ^80020    ^80030    ^80040    ^80050    ^80060    ^80070    ^80080    ^80090              ^80110    ^80120    ^80130    ^80140    ^80150    ^80160    ^80170    ^80180    ^80190              ^80210    ^80220    ^80230    ^80240    ^80250    ^80260    ^80270    ^80280    ^80290              ^80310    ^80320    ^80330    ^80340    ^80350    ^80360    ^80370    ^80380    ^80390              ^80410    ^80420    ^80430    ^80440    ^80450    ^80460    ^80470    ^80480    ^80490              ^80510    ^80520    ^80530    ^80540    ^80550    ^80560    ^80570    ^80580    ^80590              ^80610    ^80620    ^80630    ^80640    ^80650    ^80660    ^80670    ^80680    ^80690              ^80710    ^80720    ^80730    ^80740    ^80750    ^80760    ^80770    ^80780    ^80790              ^80810    ^80820    ^80830    ^80840    ^80850    ^80860    ^80870    ^80880    ^80890              ^80910    ^80920    ^80930    ^80940    ^80950    ^80960    ^80970    ^80980    ^80990              ^81010    ^81020    ^81030    ^81040    ^81050    ^81060    ^81070    ^81080    ^81090              ^81110    ^81120    ^81130    ^81140    ^81150    ^81160    ^81170    ^81180    ^81190              ^81210    ^81220    ^81230    ^81240    ^81250    ^81260    ^81270    ^81280    ^81290              ^81310    ^81320    ^81330    ^81340    ^81350    ^81360    ^81370    ^81380    ^81390              ^81410    ^81420    ^81430    ^81440    ^81450    ^81460    ^81470    ^81480    ^81490              ^81510    ^81520    ^81530    ^81540    ^81550    ^81560    ^81570    ^81580    ^81590              ^81610    ^81620    ^81630    ^81640    ^81650    ^81660    ^81670    ^81680    ^81690              ^81710    ^81720    ^81730    ^81740    ^81750    ^81760    ^81770    ^81780    ^81790              ^81810    ^81820    ^81830    ^81840    ^81850    ^81860    ^81870    ^81880    ^81890              ^81910    ^81920    ^81930    ^81940    ^81950    ^81960    ^81970    ^81980    ^81990              ^82010    ^82020    ^82030    ^82040    ^82050    ^82060    ^82070    ^82080    ^82090              ^82110    ^82120    ^82130    ^82140    ^82150    ^82160    ^82170    ^82180    ^82190              ^82210    ^82220    ^82230    ^82240    ^82250    ^82260    ^82270    ^82280    ^82290              ^82310    ^82320    ^82330    ^82340    ^82350    ^82360    ^82370    ^82380    ^82390              ^82410    ^82420    ^82430    ^82440    ^82450    ^82460    ^82470    ^82480    ^82490              ^82510    ^82520    ^82530    ^82540    ^82550    ^82560    ^82570    ^82580    ^82590              ^82610    ^82620    ^82630    ^82640    ^82650    ^82660    ^82670    ^82680    ^82690              ^82710    ^82720    ^82730    ^82740    ^82750    ^82760    ^82770    ^82780    ^82790              ^82810    ^82820    ^82830    ^82840    ^82850    ^82860    ^82870    ^82880    ^82890              ^82910    ^82920    ^82930    ^82940    ^82950    ^82960    ^82970    ^82980    ^82990              ^83010    ^83020    ^83030    ^83040    ^83050    ^83060    ^83070    ^83080    ^83090              ^83110    ^83120    ^83130    ^83140    ^83150    ^83160    ^83170    ^83180    ^83190              ^83210    ^83220    ^83230    ^83240    ^83250    ^83260    ^83270    ^83280    ^83290              ^83310    ^83320    ^83330    ^83340    ^83350    ^83360    ^83370    ^83380    ^83390              ^83410    ^83420    ^83430    ^83440    ^83450    ^83460    ^83470    ^83480    ^83490              ^83510    ^83520    ^83530    ^83540    ^83550    ^83560    ^83570    ^83580    ^83590              ^83610    ^83620    ^83630    ^83640    ^83650    ^83660    ^83670    ^83680    ^83690              ^83710    ^83720    ^83730    ^83740    ^83750    ^83760    ^83770    ^83780    ^83790              ^83810    ^83820    ^83830    ^83840    ^83850    ^83860    ^83870    ^83880    ^83890              ^83910    ^83920    ^83930    ^83940    ^83950    ^83960    ^83970    ^83980    ^83990              ^84010    ^84020    ^84030    ^84040    ^84050    ^84060    ^84070    ^84080    ^84090              ^84110    ^84120    ^84130    ^84140    ^84150    ^84160    ^84170    ^84180    ^84190              ^84210    ^84220    ^84230    ^84240    ^84250    ^84260    ^84270    ^84280    ^84290              ^84310    ^84320    ^84330    ^84340    ^84350    ^84360    ^84370    ^84380    ^84390              ^84410    ^84420    ^84430    ^84440    ^84450    ^84460    ^84470    ^84480    ^84490              ^84510    ^84520    ^84530    ^84540    ^84550    ^84560    ^84570    ^84580    ^84590              ^84610    ^84620    ^84630    ^84640    ^84650    ^84660    ^84670    ^84680    ^84690              ^84710    ^84720    ^84730    ^84740    ^84750    ^84760    ^84770    ^84780    ^84790              ^84810    ^84820    ^84830    ^84840    ^84850    ^84860    ^84870    ^84880    ^84890              ^84910    ^84920    ^84930    ^84940    ^84950    ^84960    ^84970    ^84980    ^84990              ^85010    ^85020    ^85030    ^85040    ^85050    ^85060    ^85070    ^85080    ^85090              ^85110    ^85120    ^85130    ^85140    ^85150    ^85160    ^85170    ^85180    ^85190              ^85210    ^85220    ^85230    ^85240    ^85250    ^85260    ^85270    ^85280    ^85290              ^85310    ^85320    ^85330    ^85340    ^85350    ^85360    ^85370    ^85380    ^85390              ^85410    ^85420    ^85430    ^85440    ^85450    ^85460    ^85470    ^85480    ^85490              ^85510    ^85520    ^85530    ^85540    ^85550    ^85560    ^85570    ^85580    ^85590              ^85610    ^85620    ^85630    ^85640    ^85650    ^85660    ^85670    ^85680    ^85690              ^85710    ^85720    ^85730    ^85740    ^85750    ^85760    ^85770    ^85780    ^85790              ^85810    ^85820    ^85830    ^85840    ^85850    ^85860    ^85870    ^85880    ^85890              ^85910    ^85920    ^85930    ^85940    ^85950    ^85960    ^85970    ^85980    ^85990              ^86010    ^86020    ^86030    ^86040    ^86050    ^86060    ^86070    ^86080    ^86090              ^86110    ^86120    ^86130    ^86140    ^86150    ^86160    ^86170    ^86180    ^86190              ^86210    ^86220    ^86230    ^86240    ^86250    ^86260    ^86270    ^86280    ^86290              ^86310    ^86320    ^86330    ^86340    ^86350    ^86360    ^86370    ^86380    ^86390              ^86410    ^86420    ^86430    ^86440    ^86450    ^86460    ^86470    ^86480    ^86490              ^86510    ^86520    ^86530    ^86540    ^86550    ^86560    ^86570    ^86580    ^86590              ^86610    ^86620    ^86630    ^86640    ^86650    ^86660    ^86670    ^86680    ^86690              ^86710    ^86720    ^86730    ^86740    ^86750    ^86760    ^86770    ^86780    ^86790              ^86810    ^86820    ^86830    ^86840    ^86850    ^86860    ^86870    ^86880    ^86890              ^86910    ^86920    ^86930    ^86940    ^86950    ^86960    ^86970    ^86980    ^86990              ^87010    ^87020    ^87030    ^87040    ^87050    ^87060    ^87070    ^87080    ^87090              ^87110    ^87120    ^87130    ^87140    ^87150    ^87160    ^87170    ^87180    ^87190              ^87210    ^87220    ^87230    ^87240    ^87250    ^87260    ^87270    ^87280    ^87290              ^87310    ^87320    ^87330    ^87340    ^87350    ^87360    ^87370    ^87380    ^87390              ^87410    ^87420    ^87430    ^87440    ^87450    ^87460    ^87470    ^87480    ^87490              ^87510    ^87520    ^87530    ^87540    ^87550    ^87560    ^87570    ^87580    ^87590              ^87610    ^87620    ^87630    ^87640    ^87650    ^87660    ^87670    ^87680    ^87690              ^87710    ^87720    ^87730    ^87740    ^87750    ^87760    ^87770    ^87780    ^87790              ^87810    ^87820    ^87830    ^87840    ^87850    ^87860    ^87870    ^87880    ^87890              ^87910    ^87920    ^87930    ^87940    ^87950    ^87960    ^87970    ^87980    ^87990              ^88010    ^88020    ^88030    ^88040    ^88050    ^88060    ^88070    ^88080    ^88090              ^88110    ^88120    ^88130    ^88140    ^88150    ^88160    ^88170    ^88180    ^88190              ^88210    ^88220    ^88230    ^88240    ^88250    ^88260    ^88270    ^88280    ^88290              ^88310    ^88320    ^88330    ^88340    ^88350    ^88360    ^88370    ^88380    ^88390              ^88410    ^88420    ^88430    ^88440    ^88450    ^88460    ^88470    ^88480    ^88490              ^88510    ^88520    ^88530    ^88540    ^88550    ^88560    ^88570    ^88580    ^88590              ^88610    ^88620    ^88630    ^88640    ^88650    ^88660    ^88670    ^88680    ^88690              ^88710    ^88720    ^88730    ^88740    ^88750    ^88760    ^88770    ^88780    ^88790              ^88810    ^88820    ^88830    ^88840    ^88850    ^88860    ^88870    ^88880    ^88890              ^88910    ^88920    ^88930    ^88940    ^88950    ^88960    ^88970    ^88980    ^88990              ^89010    ^89020    ^89030    ^89040    ^89050    ^89060    ^89070    ^89080    ^89090              ^89110    ^89120    ^89130    ^89140    ^89150    ^89160    ^89170    ^89180    ^89190              ^89210    ^89220    ^89230    ^89240    ^89250    ^89260    ^89270    ^89280    ^89290              ^89310    ^89320    ^89330    ^89340    ^89350    ^89360    ^89370    ^89380    ^89390              ^89410    ^89420    ^89430    ^89440    ^89450    ^89460    ^89470    ^89480    ^89490              ^89510    ^89520    ^89530    ^89540    ^89550    ^89560    ^89570    ^89580    ^89590              ^89610    ^89620    ^89630    ^89640    ^89650    ^89660    ^89670    ^89680    ^89690              ^89710    ^89720    ^89730    ^89740    ^89750    ^89760    ^89770    ^89780    ^89790              ^89810    ^89820    ^89830    ^89840    ^89850    ^89860    ^89870    ^89880    ^89890              ^89910    ^89920    ^89930    ^89940    ^89950    ^89960    ^89970    ^89980    ^89990              ^90010    ^90020    ^90030    ^90040    ^90050    ^90060    ^90070    ^90080    ^90090              ^90110    ^90120    ^90130    ^90140    ^90150    ^90160    ^90170    ^90180    ^90190              ^90210    ^90220    ^90230    ^90240    ^90250    ^90260    ^90270    ^90280    ^90290              ^90310    ^90320    ^90330    ^90340    ^90350    ^90360    ^90370    ^90380    ^90390              ^90410    ^90420    ^90430    ^90440    ^90450    ^90460    ^90470    ^90480    ^90490              ^90510    ^90520    ^90530    ^90540    ^90550    ^90560    ^90570    ^90580    ^90590              ^90610    ^90620    ^90630    ^90640    ^90650    ^90660    ^90670    ^90680    ^90690              ^90710    ^90720    ^90730    ^90740    ^90750    ^90760    ^90770    ^90780    ^90790              ^90810    ^90820    ^90830    ^90840    ^90850    ^90860    ^90870    ^90880    ^90890              ^90910    ^90920    ^90930    ^90940    ^90950    ^90960    ^90970    ^90980    ^90990              ^91010    ^91020    ^91030    ^91040    ^91050    ^91060    ^91070    ^91080    ^91090              ^91110    ^91120    ^91130    ^91140    ^91150    ^91160    ^91170    ^91180    ^91190              ^91210    ^91220    ^91230    ^91240    ^91250    ^91260    ^91270    ^91280    ^91290              ^91310    ^91320    ^91330    ^91340    ^91350    ^91360    ^91370    ^91380    ^91390              ^91410    ^91420    ^91430    ^91440    ^91450    ^91460    ^91470    ^91480    ^91490              ^91510    ^91520    ^91530    ^91540    ^91550    ^91560    ^91570    ^91580    ^91590              ^91610    ^91620    ^91630    ^91640    ^91650    ^91660    ^91670    ^91680    ^91690              ^91710    ^91720    ^91730    ^91740    ^91750    ^91760    ^91770    ^91780    ^91790              ^91810    ^91820    ^91830    ^91840    ^91850    ^91860    ^91870    ^91880    ^91890              ^91910    ^91920    ^91930    ^91940    ^91950    ^91960    ^91970    ^91980    ^91990              ^92010    ^92020    ^92030    ^92040    ^92050    ^92060    ^92070    ^92080    ^92090              ^92110    ^92120    ^92130    ^92140    ^92150    ^92160    ^92170    ^92180    ^92190              ^92210    ^92220    ^92230    ^92240    ^92250    ^92260    ^92270    ^92280    ^92290              ^92310    ^92320    ^92330    ^92340    ^92350    ^92360    ^92370    ^92380    ^92390              ^92410    ^92420    ^92430    ^92440    ^92450    ^92460    ^92470    ^92480    ^92490              ^92510    ^92520    ^92530    ^92540    ^92550    ^92560    ^92570    ^92580    ^92590              ^92610    ^92620    ^92630    ^92640    ^92650    ^92660    ^92670    ^92680    ^92690              ^92710    ^92720    ^92730    ^92740    ^92750    ^92760    ^92770    ^92780    ^92790              ^92810    ^92820    ^92830    ^92840    ^92850    ^92860    ^92870    ^92880    ^92890              ^92910    ^92920    ^92930    ^92940    ^92950    ^92960    ^92970    ^92980    ^92990              ^93010    ^93020    ^93030    ^93040    ^93050    ^93060    ^93070    ^93080    ^93090              ^93110    ^93120    ^93130    ^93140    ^93150    ^93160    ^93170    ^93180    ^93190              ^93210    ^93220    ^93230    ^93240    ^93250    ^93260    ^93270    ^93280    ^93290              ^93310    ^93320    ^93330    ^93340    ^93350    ^93360    ^93370    ^93380    ^93390              ^93410    ^93420    ^93430    ^93440    ^93450    ^93460    ^93470    ^93480    ^93490              ^93510    ^93520    ^93530    ^93540    ^93550    ^93560    ^93570    ^93580    ^93590              ^93610    ^93620    ^93630    ^93640    ^93650    ^93660    ^93670    ^93680    ^93690              ^93710    ^93720    ^93730    ^93740    ^93750    ^93760    ^93770    ^93780    ^93790              ^93810    ^93820    ^93830    ^93840    ^93850    ^93860    ^93870    ^93880    ^93890              ^93910    ^93920    ^93930    ^93940    ^93950    ^93960    ^93970    ^93980    ^93990              ^94010    ^94020    ^94030    ^94040    ^94050    ^94060    ^94070    ^94080    ^94090              ^94110    ^94120    ^94130    ^94140    ^94150    ^94160    ^94170    ^94180    ^94190              ^94210    ^94220    ^94230    ^94240    ^94250    ^94260    ^94270    ^94280    ^94290              ^94310    ^94320    ^94330    ^94340    ^94350    ^94360    ^94370    ^94380    ^94390              ^94410    ^94420    ^94430    ^94440    ^94450    ^94460    ^94470    ^94480    ^94490              ^94510    ^94520    ^94530    ^94540    ^94550    ^94560    ^94570    ^94580    ^94590              ^94610    ^94620    ^94630    ^94640    ^94650    ^94660    ^94670    ^94680    ^94690              ^94710    ^94720    ^94730    ^94740    ^94750    ^94760    ^94770    ^94780    ^94790              ^94810    ^94820    ^94830    ^94840    ^94850    ^94860    ^94870    ^94880    ^94890              ^94910    ^94920    ^94930    ^94940    ^94950    ^94960    ^94970    ^94980    ^94990              ^95010    ^95020    ^95030    ^95040    ^95050    ^95060    ^95070    ^95080    ^95090              ^95110    ^95120    ^95130    ^95140    ^95150    ^95160    ^95170    ^95180    ^95190              ^95210    ^95220    ^95230    ^95240    ^95250    ^95260    ^95270    ^95280    ^95290              ^95310    ^95320    ^95330    ^95340    ^95350    ^95360    ^95370    ^95380    ^95390              ^95410    ^95420    ^95430    ^95440    ^95450    ^95460    ^95470    ^95480    ^95490              ^95510    ^95520    ^95530    ^95540    ^95550    ^95560    ^95570    ^95580    ^95590              ^95610    ^95620    ^95630    ^95640    ^95650    ^95660    ^95670    ^95680    ^95690              ^95710    ^95720    ^95730    ^95740    ^95750    ^95760    ^95770    ^95780    ^95790              ^95810    ^95820    ^95830    ^95840    ^95850    ^95860    ^95870    ^95880    ^95890              ^95910    ^95920    ^95930    ^95940    ^95950    ^95960    ^95970    ^95980    ^95990              ^96010    ^96020    ^96030    ^96040    ^96050    ^96060    ^96070    ^96080    ^96090              ^96110    ^96120    ^96130    ^96140    ^96150    ^96160    ^96170    ^96180    ^96190              ^96210    ^96220    ^96230    ^96240    ^96250    ^96260    ^96270    ^96280    ^96290              ^96310    ^96320    ^96330    ^96340    ^96350    ^96360    ^96370    ^96380    ^96390              ^96410    ^96420    ^96430    ^96440    ^96450    ^96460    ^96470    ^96480    ^96490              ^96510    ^96520    ^96530    ^96540    ^96550    ^96560    ^96570    ^96580    ^96590              ^96610    ^96620    ^96630    ^96640    ^96650    ^96660    ^96670    ^96680    ^96690              ^96710    ^96720    ^96730    ^96740    ^96750    ^96760    ^96770    ^96780    ^96790              ^96810    ^96820    ^96830    ^96840    ^96850    ^96860    ^96870    ^96880    ^96890              ^96910    ^96920    ^96930    ^96940    ^96950    ^96960    ^96970    ^96980    ^96990              ^97010    ^97020    ^97030    ^97040    ^97050    ^97060    ^97070    ^97080    ^97090              ^97110    ^97120    ^97130    ^97140    ^97150    ^97160    ^97170    ^97180    ^97190              ^97210    ^97220    ^97230    ^97240    ^97250    ^97260    ^97270    ^97280    ^97290              ^97310    ^97320    ^97330    ^97340    ^97350    ^97360    ^97370    ^97380    ^97390              ^97410    ^97420    ^97430    ^97440    ^97450    ^97460    ^97470    ^97480    ^97490              ^97510    ^97520    ^97530    ^97540    ^97550    ^97560    ^97570    ^97580    ^97590              ^97610    ^97620    ^97630    ^97640    ^97650    ^97660    ^97670    ^97680    ^97690              ^97710    ^97720    ^97730    ^97740    ^97750    ^97760    ^97770    ^97780    ^97790              ^97810    ^97820    ^97830    ^97840    ^97850    ^97860    ^97870    ^97880    ^97890              ^97910    ^97920    ^97930    ^97940    ^97950    ^97960    ^97970    ^97980    ^97990              ^98010    ^98020    ^98030    ^98040    ^98050    ^98060    ^98070    ^98080    ^98090              ^98110    ^98120    ^98130    ^98140    ^98150    ^98160    ^98170    ^98180    ^98190              ^98210    ^98220    ^98230    ^98240    ^98250    ^98260    ^98270    ^98280    ^98290              ^98310    ^98320    ^98330    ^98340    ^98350    ^98360    ^98370    ^98380    ^98390              ^98410    ^98420    ^98430    ^98440    ^98450    ^98460    ^98470    ^98480    ^98490              ^98510    ^98520    ^98530    ^98540    ^98550    ^98560    ^98570    ^98580    ^98590              ^98610    ^98620    ^98630    ^98640    ^98650    ^98660    ^98670    ^98680    ^98690              ^98710    ^98720    ^98730    ^98740    ^98750    ^98760    ^98770    ^98780    ^98790              ^98810    ^98820    ^98830    ^98840    ^98850    ^98860    ^98870    ^98880    ^98890              ^98910    ^98920    ^98930    ^98940    ^98950    ^98960    ^98970    ^98980    ^98990              ^99010    ^99020    ^99030    ^99040    ^99050    ^99060    ^99070    ^99080    ^99090              ^99110    ^99120    ^99130    ^99140    ^99150    ^99160    ^99170    ^99180    ^99190              ^99210    ^99220    ^99230    ^99240    ^99250    ^99260    ^99270    ^99280    ^99290              ^99310    ^99320    ^99330    ^99340    ^99350    ^99360    ^99370    ^99380    ^99390              ^99410    ^99420    ^99430    ^99440    ^99450    ^99460    ^99470    ^99480    ^99490              ^99510    ^99520    ^99530    ^99540    ^99550    ^99560    ^99570    ^99580    ^99590              ^99610    ^99620    ^99630    ^99640    ^99650    ^99660    ^99670    ^99680    ^99690              ^99710    ^99720    ^99730    ^99740    ^99750    ^99760    ^99770    ^99780    ^99790              ^99810    ^99820    ^99830    ^99840    ^99850    ^99860    ^99870    ^99880    ^99890              ^99910    ^99920    ^99930    ^99940    ^99950    ^99960    ^99970    ^99980    ^99990     ';
   }
   else {
      die ("The number line for the selected bases per line value is not available.");
   }
}

sub getSpacerLine {
   my $spacerLine = '----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------';

   return $spacerLine;
}

sub getLookAhead { #this value determines how many bases are added to the ends of the linear sequence to emulate a circular molecule.
   return 50;
}

sub getMaxSeqLength { #this is the maximum number bases allowed in the template.
   return 100000;
}

sub getPrimersAllowed { #this is the maximum number of primers allowed.
   return 100;
}

sub getMatchesAllowed { #this is the maximum number of matches allowed for a single primer.
   return 50;
}

sub getRestrictionPatternsAllowed { #this is the maximum number of restriction patterns allowed.
   return 100;
}

sub getCdsLimit { #this is the maximum number of coding sequences allowed in GenBank and EMBL records.
   return 100;
}

sub getThreeFrameLimit { #this is the maximum number of bases allowed when the translations for reading frames one to three are shown.
   return 50000;
}

sub getSixFrameLimit { #this is the maximum number of bases allowed when the translations for reading frames one to six are shown.
   return 25000;
}

return 1;
